%**************************************************************************
%University of British Columbia
%Vanessa Alviarez
%Comparative Advantage
%Journal of International Economics 
%Last Update: 2019
%**************************************************************************

%==========================================================================
%Counterfactual: Effect on GT in a counterfactual where MP does not change 
%comparative advantage [Tradables only]
%==========================================================================

%---------------------------------------------------
%Previos Step: Define which scenario is the "equilibrium scenario" (in this
%case is really the "model's equilibrium". 
clear all
load 'equilibrium_full_model.mat' domestic_share  local_share domestic_share_nomp  
save('equilibrium_transit.mat'); 

clear all
load 'parameters_1a.mat' 
save 'parameters_welfare_a.mat'
load 'equilibrium_full_model.mat' T_sq_trade 
%---------------------------------------------------


factor=geomean(T_sq_trade(:,1:J),2)./geomean(T_mp(:,1:J),2);
T_sq_count=ones(N,J+1);
for j=1:J
T_sq_count(:,j)=T_mp(:,j).*factor;
end
T_sq_count(:,J+1)=T_sq_trade(:,J+1); %keeping Non-tradables as in the baseline
T_mp=T_sq_count;
%NOTE: What we need is to have a T_sq as steep as the original T in order to calculate the GT. Notice that this can be achieve
%by setting h=inf, since in this case in the model T=T_sq. Remeber that T_sq here will have the same CV that the original T.


h1=ones(N,N,J+1); 
for j=1:J+1
    for l=1:N
        for s=1:N
            if l~=s
    h1(l,s,j)=Inf;
            end
        end
    end
end
h=h1; 
h_mp=h;

save('parameters_welfare_a.mat', 'T_mp', 'h', 'h_mp', 'Atkinson_T', '-append');
save('Equilibrium_CAintact.mat', 'T_mp', 'T_sq_trade', 'T_sq_count', 'factor', 'Atkinson_T');

run Equilibrium_mp_complete_loop_CES.m;
wages_equi=wages_sim(:,end-1);
r_capital_equi=r_capital_sim(:,end-1);
PIndex_equi=PIndex;
save('Equilibrium_CAintact.mat', 'wages_equi', 'r_capital_equi', 'PIndex_equi', '-append');

run trade_mp_share.m;
load 'equilibrium_full_model.mat' output_share_all output_share_T beta_T_NT beta_all betas_nj D_multi_nolink D_multi D_uni si_multi;
save('Equilibrium_CAintact.mat', 'output_share_all', 'output_share_T', 'beta_T_NT', 'beta_all', 'betas_nj', 'D_multi_nolink', 'D_multi', 'D_uni', 'si_multi', 'Atkinson_mp', 'Atkinson_trade', 'domestic_share', 'domestic_share_tradable', 'domestic_share_sector', 'local_share', 'local_share_tradable', 'local_share_nontradable', 'local_share_sector', '-append');


%---------------------------------------------------------------
%Run the welfare analysis
%Index 1 (CES, capital), Index 2 (Cobb Douglas, capital), Index 3 (CES, without capital), Index 4 (Cobb Douglas, without capital)
%---------------------------------------------------------------
index=1; 
run welfare_analysis.m;
save('Equilibrium_CAintact.mat', 'GAINS_baseline', 'domestic_share_nomp', 'domestic_share_nomp_tradable', 'domestic_share_nomp_sector', '-append');


%---------------------------------------------------------------
%Model based welfare analysis 
%---------------------------------------------------------------
clear all 
load 'parameters_welfare_a.mat' 
load 'Equilibrium_CAintact.mat';  
run Model_based_formulas.m; 
save('Equilibrium_CAintact.mat', 'Atkinson_T', 'GAINS_baseline', 'GAINS_multi0', 'GAINS_multi1', 'GAINS_multi2', 'GAINS_multi3', 'GAINS_uni0', 'GAINS_uni1', 'GAINS_uni2', 'GAINS_uni3',  '-append');


%---------------------------------------------------------------
%Run OSSA exponents for welfare analysis 
%---------------------------------------------------------------
clear all 
load 'parameters_welfare_a.mat' 
load 'Equilibrium_CAintact.mat';  

wages_equi_CAintact=wages_equi;
r_capital_equi_CAintact=r_capital_equi;
PIndex_equi_CAintact=PIndex_equi;

Atkinson_T_CAintact=Atkinson_T;
Atkinson_trade_CAintact=Atkinson_trade;
Atkinson_mp_CAintact=Atkinson_mp;
GAINS_baseline_CAintact=GAINS_baseline;
GAINS_multi0_CAintact=GAINS_multi0;
GAINS_multi1_CAintact=GAINS_multi1;
GAINS_multi2_CAintact=GAINS_multi2;
GAINS_multi3_CAintact=GAINS_multi3;
GAINS_uni0_CAintact=GAINS_uni0;
domestic_share_CAintact=domestic_share;
domestic_share_tradable_CAintact=domestic_share_tradable;
domestic_share_sector_CAintact=domestic_share_sector;
domestic_share_nomp_CAintact=domestic_share_nomp;
domestic_share_nomp_sector_CAintact=domestic_share_nomp_sector;
local_share_CAintact=local_share;
local_share_tradable_CAintact=local_share_tradable;
local_share_nontradable_CAintact=local_share_nontradable;
local_share_sector_CAintact=local_share_sector;

clear Atkinson_T Atkinson_trade Atkinson_mp GAINS_baseline GAINS_uni0 GAINS_multi0 GAINS_multi1 GAINS_multi2 GAINS_multi2_ossa GAINS_multi3 GAINS_multi3_ossa   
clear domestic_share domestic_share_tradable domestic_share_sector local_share local_share_tradable  local_share_nontradable local_share_sector
clear wages_equi r_capital_lowh PIndex_equi
save('Equilibrium_CAintact.mat', 'wages_equi_CAintact', 'r_capital_equi_CAintact', 'PIndex_equi_CAintact', 'Atkinson_T_CAintact', 'Atkinson_trade_CAintact', 'Atkinson_mp_CAintact', 'GAINS_baseline_CAintact', 'GAINS_multi0_CAintact', 'GAINS_multi1_CAintact', 'GAINS_multi2_CAintact', 'GAINS_multi3_CAintact', 'GAINS_uni0_CAintact', 'domestic_share_CAintact', 'domestic_share_tradable_CAintact', 'domestic_share_sector_CAintact', 'domestic_share_nomp_CAintact', 'domestic_share_nomp_sector_CAintact', 'local_share_CAintact', 'local_share_tradable_CAintact', 'local_share_nontradable_CAintact', 'local_share_sector_CAintact');


%Analysis 
%-------------------------------------------------------------------------
clear all
load 'Equilibrium_CAintact.mat'
load 'equilibrium_full_model.mat'


%Trade
%-------------------------------------------------------
a1=[GAINS_multi2(:,1) GAINS_multi2_CAintact(:,1) GAINS_multi3_CAintact(:,1)];
a1_v2=(a1(:,3)-a1(:,1)); %conditional
a1_v3=(a1(:,2)-a1(:,1)); %unconditional
a1_cond=a1_v2;
a1_uncond=a1_v3;

a1_v2=(a1(:,3)-a1(:,1))./(abs(a1(:,1))); %conditional
a1_v3=(a1(:,2)-a1(:,1))./(abs(a1(:,1))); %unconditional
a2_cond=a1_v2;
a2_uncond=a1_v3;

a2=GAINS_multi2(:,1);
g_uncon_trade=[a2(:,1) a2_uncond a1_uncond]*100;
g_con_trade=[a2(:,1) a2_cond a1_cond]*100;

mean(g_con_trade)
median(g_con_trade)
mean(g_uncon_trade)
median(g_uncon_trade)

%-------------------------------------------------------
%Welfare 
%-------------------------------------------------------
a1=[GAINS_baseline(:,1) GAINS_baseline_CAintact(:,1)];
a1_v3=(a1(:,2)-a1(:,1)).*100; %unconditional
a1_uncond=a1_v3;

a1_v3=(a1(:,2)-a1(:,1))./(abs(a1(:,1))).*100; %unconditional
a2_uncond=a1_v3;

c1=Atkinson_T(:,1)- Atkinson_T(:,2); 
c2=a1_uncond;
figure
labels={'USA', 'AUS', 'AUT', 'BEL', 'BGR', 'CAN', 'CZE', 'DNK', 'EST', 'FIN', 'FRA', 'DEU', 'GRC', 'HUN', 'ITA', 'JPN', 'LVA', 'LTU', 'MEX', 'NLD', 'NZL', 'NOR', 'POL', 'PRT', 'ROM', 'RUS', 'SVK', 'ESP', 'SWE', 'TUR', 'UKR', 'GBR'};
scatter(c1, c2, 100, 'b', '.')
hold on 
labelpoints(c1,c2, labels, 'FontSize', 7);
lsline
XL = xlim();
plot(XL, [0 0], 'r --')
hold off
set(gcf,'color','w');
%xlabel('Atkinson $\hat{T}$ - Atkison T, Baseline');
xlabel('Atkinson $${T}$$ - Atkison $$\tilde{T}$$, Baseline','Interpreter','Latex')
ylabel('GT (Counterfactual) - GT (Baseline), pp');

%Graph in section 5.4 in the paper
saveas(gcf,'Counterfactual_CA_intact','eps')
saveas(gcf,'Counterfactual_CA_intact','png')
