%**************************************************************************
%University of British Columbia
%Vanessa Alviarez
%Comparative Advantage
%Journal of International Economics 
%Last Update: 2019
%**************************************************************************

%==========================================================================
%Counterfactual: Welfare effect of MP on Non-tradables 
%==========================================================================


%--------------------------------------------------------------------------
%Previos Step: Define which scenario is the "equilibrium scenario" (in this
%case is really the "model's equilibrium". 
clear all
load 'equilibrium_full_model.mat' domestic_share  local_share domestic_share_nomp  %Here I have to calculate the equilibrium with the real value of technology for non_tradables
save('equilibrium_transit.mat'); 
%--------------------------------------------------------------------------

%Counterfactual definition: What if we do not allow MP in non tradables 
clear all
load 'parameters_1a.mat' 
save 'parameters_welfare_a.mat'
load 'equilibrium_full_model.mat' T_sq_trade 

Atkinson_T_mp=1-(geomean(T_mp(:,1:J),2)./mean(T_mp(:,1:J),2));
Atkinson_T_sq=1-(geomean(T_sq_trade(:,1:J),2)./mean(T_sq_trade(:,1:J),2));
Atkinson_T=[Atkinson_T_mp Atkinson_T_sq];
h1=h; 
for l=1:N
        for s=1:N
            if l~=s
    h1(l,s,J+1)=1000;
            end
        end
end
h=h1; 
h_mp=h;
save('parameters_welfare_a.mat', 'T_mp', 'h', 'h_mp', 'Atkinson_T', '-append');
save('Equilibrium_NT.mat', 'T_mp', 'T_sq_trade', 'Atkinson_T');

run Equilibrium_mp_complete_loop_CES.m;
wages_equi=wages_sim(:,end-1);
r_capital_equi=r_capital_sim(:,end-1);
PIndex_equi=PIndex;
save('Equilibrium_NT.mat', 'wages_equi', 'r_capital_equi', 'PIndex_equi', 'P_tradable', 'P_tradable_si', 'P_nontradable', 'P_nontradable_si', '-append');

run trade_mp_share.m;
load 'equilibrium_full_model.mat' output_share_all output_share_T beta_T_NT beta_all betas_nj D_multi_nolink D_multi D_uni si_multi;
save('Equilibrium_NT.mat', 'output_share_all', 'output_share_T', 'beta_T_NT', 'beta_all', 'betas_nj', 'D_multi_nolink', 'D_multi', 'D_uni', 'si_multi', 'Atkinson_mp', 'Atkinson_trade', 'domestic_share', 'domestic_share_tradable', 'domestic_share_sector', 'local_share', 'local_share_tradable', 'local_share_nontradable', 'local_share_sector', '-append');


%---------------------------------------------------------------
%Run the welfare analysis
%Index 1 (CES, capital), Index 2 (Cobb Douglas, capital), Index 3 (CES, without capital), Index 4 (Cobb Douglas, without capital)
%---------------------------------------------------------------
index=1; 
run welfare_analysis.m;
save('Equilibrium_NT.mat', 'GAINS_baseline', 'domestic_share_nomp', 'domestic_share_nomp_tradable', 'domestic_share_nomp_sector', '-append');

%---------------------------------------------------------------
%Model based welfare analysis 
%---------------------------------------------------------------
clear all 
load 'parameters_welfare_a.mat' 
load 'Equilibrium_NT.mat';  
run Model_based_formulas.m; 
save('Equilibrium_NT.mat', 'Atkinson_T', 'GAINS_baseline', 'GAINS_multi0', 'GAINS_multi1', 'GAINS_multi2', 'GAINS_multi3', 'GAINS_uni0', 'GAINS_uni1', 'GAINS_uni2', 'GAINS_uni3',  '-append');


%---------------------------------------------------------------
%Run OSSA exponents for welfare analysis 
%---------------------------------------------------------------
clear all 
load 'parameters_welfare_a.mat' 
load 'Equilibrium_NT.mat';  

wages_equi_NT=wages_equi;
r_capital_equi_NT=r_capital_equi;
PIndex_equi_NT=PIndex_equi;
P_tradable_NT=P_tradable;
P_tradable_si_NT=P_tradable_si;
P_nontradable_NT=P_nontradable;
P_nontradable_si_NT=P_nontradable_si;
Atkinson_T_NT=Atkinson_T;
Atkinson_trade_NT=Atkinson_trade;
Atkinson_mp_NT=Atkinson_mp;
GAINS_baseline_NT=GAINS_baseline;
GAINS_multi0_NT=GAINS_multi0;
GAINS_multi1_NT=GAINS_multi1;
GAINS_multi2_NT=GAINS_multi2;
GAINS_multi3_NT=GAINS_multi3;
GAINS_uni0_NT=GAINS_uni0;
domestic_share_NT=domestic_share;
domestic_share_tradable_NT=domestic_share_tradable;
domestic_share_sector_NT=domestic_share_sector;
domestic_share_nomp_NT=domestic_share_nomp;
domestic_share_nomp_sector_NT=domestic_share_nomp_sector;
local_share_NT=local_share;
local_share_tradable_NT=local_share_tradable;
local_share_nontradable_NT=local_share_nontradable;
local_share_sector_NT=local_share_sector;

clear domestic_share domestic_share_tradable domestic_share_sector local_share local_share_tradable  local_share_nontradable local_share_sector
clear wages_equi r_capital_lowh PIndex_equi P_tradable P_tradable_si P_nontradable P_nontradable_si
save('Equilibrium_NT.mat', 'wages_equi_NT', 'r_capital_equi_NT', 'PIndex_equi_NT', 'P_tradable_NT', 'P_tradable_si_NT', 'P_nontradable_NT', 'P_nontradable_si_NT', 'Atkinson_T_NT', 'Atkinson_trade_NT', 'Atkinson_mp_NT', 'GAINS_baseline_NT', 'GAINS_multi0_NT', 'GAINS_multi1_NT', 'GAINS_multi2_NT', 'GAINS_multi3_NT', 'GAINS_uni0_NT', 'domestic_share_NT', 'domestic_share_tradable_NT', 'domestic_share_sector_NT', 'domestic_share_nomp_NT', 'domestic_share_nomp_sector_NT', 'local_share_NT', 'local_share_tradable_NT', 'local_share_nontradable_NT', 'local_share_sector_NT');


%Analysis 
%-------------------------------------------------------------------------
%Wnat is the effects of not allowing MP in non-tradables. Not only in that
%sector, but the change in Price index in the tradable and non-tradable
clear all
load 'Equilibrium_NT.mat'
load 'equilibrium_full_model.mat'

%-------------------------------------------------------
%Change in Real Wage: 
%-------------------------------------------------------
wages_real_NT=wages_equi_NT./PIndex_equi_NT; 
wages_real=wages_equi./PIndex; 
wages_real_comp=[wages_real_NT wages_real];
wages_real_count_change=(wages_real_comp(:,1)./wages_real_comp(:,2)-1)*100;


%-------------------------------------------------------
%MP
%-------------------------------------------------------
a1=[GAINS_multi2(:,2) GAINS_multi2_NT(:,2)];
a1_v3=(a1(:,2)-a1(:,1)); %unconditional
a1_uncond=a1_v3;


a1_v3=(a1(:,2)-a1(:,1))./(abs(a1(:,1))); %unconditional
a2_uncond=a1_v3;

a2=GAINS_multi2(:,2);
g_uncon_mp=[a2(:,1) a2_uncond a1_uncond]*100;

mean(g_uncon_mp)
median(g_uncon_mp)

%-------------------------------------------------------
%Trade
%-------------------------------------------------------
a1=[GAINS_multi2(:,1) GAINS_multi2_NT(:,1)];
a1_v3=(a1(:,2)-a1(:,1)); %unconditional
a1_uncond=a1_v3;

a1_v3=(a1(:,2)-a1(:,1))./(abs(a1(:,1))); %unconditional
a2_uncond=a1_v3;

a2=GAINS_multi2(:,1);
g_uncon_trade=[a2(:,1) a2_uncond a1_uncond]*100;

mean(g_uncon_trade)
median(g_uncon_trade)

%-------------------------------------------------------
%Openness
%-------------------------------------------------------
a1=[GAINS_multi2(:,3) GAINS_multi2_NT(:,3)];
a1_v3=(a1(:,2)-a1(:,1)); %unconditional
a1_uncond=a1_v3;

a1_v3=(a1(:,2)-a1(:,1))./(abs(a1(:,1))); %unconditional
a2_uncond=a1_v3;

a2=GAINS_multi2(:,3);
g_uncon_openness=[a2(:,1) a2_uncond a1_uncond]*100;

mean(g_uncon_openness)
median(g_uncon_openness)

NT_percentage=[g_uncon_mp(:,2) g_uncon_trade(:,2) g_uncon_openness(:,2)];
NT_pp=[g_uncon_mp(:,3) g_uncon_trade(:,3) g_uncon_openness(:,3)];


%-------------------------------------------------------
%Analysing the Price Index
%-------------------------------------------------------
%Decomposition 
load 'parameters_1a.mat' si
delta_PIndex=log(PIndex_equi_NT)-log(PIndex);
delta_P_tradable=log(P_tradable_NT)-log(P_tradable);
delta_P_nontradable=log(P_nontradable_NT)-log(P_nontradable);
tradable_weight=si.*delta_P_tradable;
nontradable_weight=(1-si).*delta_P_nontradable;

a=tradable_weight./delta_PIndex;
P_change=[delta_PIndex tradable_weight a]*100;
P_change2=[delta_PIndex delta_P_tradable delta_P_nontradable]*100;

%Table in Section 5.5 in the paper "Welfare Gains and Non-tradable Sector"
counter_NT=[P_change2 wages_real_count_change NT_percentage];








