%**************************************************************************
%University of British Columbia
%Vanessa Alviarez
%Comparative Advantage
%Journal of International Economics 
%Last Update: 2019
%**************************************************************************

%--------------------------------------------------------------------------
%Counterfactual: (T's as in equilibrium) and h X% percent lower (PROPOSITION 4 PART A AND B)  
%--------------------------------------------------------------------------

%--------------------------------------------------------------------------
%Previos Step: Define which scenario is the "equilibrium scenario" (in this
%case is really the "model's equilibrium". 
%Note: You have to run the baseline equilibrium right before 
clear all
addpath('L:\Dropbox (UBC-Umich)\MNC_CA\Data and Replication Files\matlab_code')
%--------------------------------------------------------------------------


clear all
load 'parameters_1a.mat' N J
vec=[0; 0.1; 0.15; 0.2; 0.25; 0.3; 0.35; 0.4; 0.45; 0.5; 0.55; 0.6; 0.65; 0.7; 0.75; 0.8; 0.85; 0.9; 0.95; 0.99; 1];
vec=[0; 0.1; 0.2; 0.5; 0.8; 0.9]; 
vec=[0; 0.1];
%vec=[0; 0.1; 0.3; 0.5]; 
%vec=[0; 0.05; 0.10; 0.15; 0.20; 0.25; 0.30; 0.50; 0.80]; 
vec=[0; 0.1; 0.15; 0.2; 0.25; 0.3; 0.35; 0.4; 0.45; 0.5; 0.55; 0.6; 0.65; 0.7; 0.75; 0.8; 0.85; 0.9; 0.95];

save 'vec_prov.mat' vec
Atkinson_T_lowh=ones(N,2,size(vec,1));
Atkinson_trade_lowh=ones(N,1,size(vec,1));
Atkinson_mp_lowh=ones(N,1,size(vec,1));

wages_equi_lowh=ones(N,1,size(vec,1));
r_capital_equi_lowh=ones(N,1,size(vec,1));
PIndex_equi_lowh=ones(N,1,size(vec,1));

GAINS_baseline_lowh=ones(N,3,size(vec,1));
GAINS_multi0_lowh=ones(N,3,size(vec,1));
GAINS_multi1_lowh=ones(N,3,size(vec,1));
GAINS_multi2_lowh=ones(N,3,size(vec,1));

GAINS_multi2_ossa_lowh=ones(N,3,size(vec,1));
GAINS_multi3_lowh=ones(N,3,size(vec,1));
GAINS_multi4_lowh=ones(N,3,size(vec,1));

GAINS_multi3_ossa_lowh=ones(N,3,size(vec,1));
beta_ossa_new_lowh=ones(N,3,size(vec,1));

GAINS_uni0_lowh=ones(N,3,size(vec,1));

domestic_share_lowh=ones(N,1,size(vec,1));
domestic_share_tradable_lowh=ones(N,1,size(vec,1));
domestic_share_sector_lowh=ones(N,J+1,size(vec,1));
domestic_share_nomp_lowh=ones(N,1,size(vec,1));
domestic_share_nomp_sector_lowh=ones(N,J+1,size(vec,1));
local_share_lowh=ones(N,1,size(vec,1));
local_share_tradable_lowh=ones(N,1,size(vec,1));
local_share_nontradable_lowh=ones(N,1,size(vec,1));
local_share_sector_lowh=ones(N,J+1,size(vec,1));
save 'Equilibrium_lowh_2.mat'
save 'Equilibrium_lowh.mat'

num_final=size(vec,1);
for num=1:num_final
    num 
save 'num_prov.mat' num
clear all
load 'parameters_1a.mat' 
save 'parameters_welfare_a.mat'

load 'num_prov.mat'
load 'vec_prov.mat'

h_tran=h; 
if num==21 %Free MP
h=ones(N,N,J+1); 
else  
h=((h-1)*(1-vec(num,1)))+1;
h(isnan(h)) = Inf;
end 


for i=1:N 
    for k=1:N
        for j=1:J+1
            if j==J+1
            h(i,k,j)=h_tran(i,k,j);  
            end
        end
    end
end


%-----------------------------------
%There is no discount in non-tradables (activate when needed for the
%conterfactual of removal of comparative advantage)
%for i=1:N
%    for n=1:N
%        if i==n
%h(i,n,J+1)=1;
%        else
%h(i,n,J+1)=100000;                  
%        end
%    end
%end
%-----------------------------------

h_mp=h;
h1=h.^(-theta);

T_sq_trade=ones(N,J+1); 
for j=1:J+1
T_sq_trade(:,j)=(h1(:,:,j))*T_mp(:,j);  
end
Atkinson_T_mp=1-(geomean(T_mp(:,1:J+1),2)./mean(T_mp(:,1:J+1),2)); %Note that the Atkinson index includes non-tradables 
Atkinson_T_sq=1-(geomean(T_sq_trade(:,1:J+1),2)./mean(T_sq_trade(:,1:J+1),2));
Atkinson_T=[Atkinson_T_mp Atkinson_T_sq];

save('parameters_welfare_a.mat', 'T_mp', 'h', 'h_mp', 'Atkinson_T', '-append');
save('Equilibrium_lowh.mat', 'Atkinson_T', '-append');

run Equilibrium_mp_complete_loop_CES.m;
wages_equi=wages_sim(:,end-1);
r_capital_equi=r_capital_sim(:,end-1);
PIndex_equi=PIndex;
save('Equilibrium_lowh.mat', 'wages_equi', 'r_capital_equi', 'PIndex_equi', '-append');

run trade_mp_share.m;
load 'equilibrium_full_model.mat' output_share_all output_share_T beta_T_NT beta_all betas_nj D_multi_nolink D_multi D_uni si_multi;
save('Equilibrium_lowh.mat', 'output_share_all', 'output_share_T', 'beta_T_NT', 'beta_all', 'betas_nj', 'D_multi_nolink', 'D_multi', 'D_uni', 'si_multi', 'Atkinson_mp', 'Atkinson_trade', 'domestic_share', 'domestic_share_tradable', 'domestic_share_sector', 'local_share', 'local_share_tradable', 'local_share_nontradable', 'local_share_sector', '-append');

%---------------------------------------------------------------
%Run the welfare analysis
%Index 1 (CES, capital), Index 2 (Cobb Douglas, capital), Index 3 (CES, without capital), Index 4 (Cobb Douglas, without capital)
%---------------------------------------------------------------
index=1; 
run welfare_analysis.m;
save('Equilibrium_lowh.mat', 'GAINS_baseline', 'domestic_share_nomp', 'domestic_share_nomp_tradable', 'domestic_share_nomp_sector', '-append');


%---------------------------------------------------------------
%Model based welfare analysis 
%---------------------------------------------------------------
clear all 
load 'parameters_welfare_a.mat' 
load 'Equilibrium_lowh.mat';  
run Model_based_formulas.m; 
save('Equilibrium_lowh.mat', 'Atkinson_T', 'GAINS_baseline', 'GAINS_multi0', 'GAINS_multi1', 'GAINS_multi2', 'GAINS_multi3', 'GAINS_uni0', 'GAINS_uni1', 'GAINS_uni2', 'GAINS_uni3',  '-append');
save('Equilibrium_lowh.mat', 'GAINS_multi4', '-append');


%---------------------------------------------------------------
%Run OSSA exponents for welfare analysis 
%---------------------------------------------------------------
clear all 
load 'parameters_welfare_a.mat' 
load 'Equilibrium_lowh.mat';  
run agg_betas_gammas_ossa_fv.m;

save('Equilibrium_lowh.mat', 'GAINS_multi2_ossa', 'GAINS_multi3_ossa', '-append');
save('Equilibrium_lowh.mat', 'beta_ossa_new',  '-append');


%Filling the Matrix 
%----------------------------------------------------------------
clear all
load 'Equilibrium_lowh.mat'
load 'Equilibrium_lowh_2.mat'
%I think you can load it because "_2" only contains storage matrices
load 'num_prov.mat' 

wages_equi_lowh(:,:,num)=wages_equi;
r_capital_equi_lowh(:,:,num)=r_capital_equi;
PIndex_equi_lowh(:,:,num)=PIndex_equi;

Atkinson_T_lowh(:,:,num)=Atkinson_T;
Atkinson_trade_lowh(:,:,num)=Atkinson_trade;
Atkinson_mp_lowh(:,:,num)=Atkinson_mp;
GAINS_baseline_lowh(:,:,num)=GAINS_baseline;
GAINS_multi0_lowh(:,:,num)=GAINS_multi0;
GAINS_multi1_lowh(:,:,num)=GAINS_multi1;
GAINS_multi2_lowh(:,:,num)=GAINS_multi2;
GAINS_multi2_ossa_lowh(:,:,num)=GAINS_multi2_ossa;
GAINS_multi3_lowh(:,:,num)=GAINS_multi3;
GAINS_multi4_lowh(:,:,num)=GAINS_multi4;


GAINS_uni0_lowh(:,:,num)=GAINS_uni0;
domestic_share_lowh(:,:,num)=domestic_share;
domestic_share_tradable_lowh(:,:,num)=domestic_share_tradable;
domestic_share_sector_lowh(:,:,num)=domestic_share_sector;
domestic_share_nomp_lowh(:,:,num)=domestic_share_nomp;
domestic_share_nomp_sector_lowh(:,:,num)=domestic_share_nomp_sector;
local_share_lowh(:,:,num)=local_share;
local_share_tradable_lowh(:,:,num)=local_share_tradable;
local_share_nontradable_lowh(:,:,num)=local_share_nontradable;
local_share_sector_lowh(:,:,num)=local_share_sector;

beta_ossa_new_lowh(:,:,num)=beta_ossa_new;

GAINS_multi3_ossa_lowh(:,:,num)=GAINS_multi3_ossa;

%----------------------------------------------------------------------
clear Atkinson_T Atkinson_trade Atkinson_mp GAINS_baseline GAINS_uni0 GAINS_multi0 GAINS_multi1 GAINS_multi2 GAINS_multi2_ossa GAINS_multi3 GAINS_multi3_ossa   
clear domestic_share domestic_share_tradable domestic_share_sector local_share local_share_tradable  local_share_nontradable local_share_sector
clear wages_equi r_capital_lowh PIndex_equi

save('Equilibrium_lowh_2.mat', 'wages_equi_lowh', 'r_capital_equi_lowh', 'PIndex_equi_lowh', 'Atkinson_T_lowh', 'Atkinson_trade_lowh', 'Atkinson_mp_lowh', 'GAINS_baseline_lowh', 'GAINS_multi0_lowh', 'GAINS_multi1_lowh', 'GAINS_multi2_lowh', 'GAINS_multi2_ossa_lowh', 'GAINS_multi3_lowh', 'GAINS_multi3_ossa_lowh', 'GAINS_uni0_lowh', 'domestic_share_lowh', 'domestic_share_tradable_lowh', 'domestic_share_sector_lowh', 'domestic_share_nomp_lowh', 'domestic_share_nomp_sector_lowh', 'local_share_lowh', 'local_share_tradable_lowh', 'local_share_nontradable_lowh', 'local_share_sector_lowh');
save('Equilibrium_lowh_2.mat', 'GAINS_multi4_lowh', '-append');
save('Equilibrium_lowh_2.mat', 'beta_ossa_new_lowh', '-append');
end



%==========================================================================
%Graphs
%==========================================================================
clear all
load 'Equilibrium_lowh_2.mat'
load 'equilibrium_full_model.mat' N J 
load 'vec_prov.mat' vec 
fin=12;

%GMP
%-------------------------------------------------------
num_final=size(vec,1); 
GMP_cond=ones(N,num_final);
GMP_uncond=ones(N,num_final);
for num=1:num_final
GMP_cond(:,num)=GAINS_multi3_ossa_lowh(:,2,num);
GMP_uncond(:,num)=GAINS_multi2_ossa_lowh(:,2,num);
end
mean(GMP_cond)
mean(GMP_uncond)

GMP_cond=mean(GMP_cond)*100';
GMP_uncond=mean(GMP_uncond)*100';
vec2=vec(1:fin);
GMP_cond=GMP_cond(:,1:fin);
GMP_uncond=GMP_uncond(:,1:fin);


%GT
%-------------------------------------------------------
num_final=size(vec,1); 
GT_cond=ones(N,num_final);
GT_uncond=ones(N,num_final);
for num=1:num_final
GT_cond(:,num)=GAINS_multi3_ossa_lowh(:,1,num);
GT_uncond(:,num)=GAINS_multi2_ossa_lowh(:,1,num);
end
mean(GT_cond)
mean(GT_uncond)

GT_cond=mean(GT_cond)*100';
GT_uncond=mean(GT_uncond)*100';
vec2=vec(1:12);
GT_cond=GT_cond(:,1:fin);
GT_uncond=GT_uncond(:,1:fin);


%GO
%-------------------------------------------------------
num_final=size(vec,1); 
GO_cond=ones(N,num_final);
GO_uncond=ones(N,num_final);
for num=1:num_final
GO_cond(:,num)=GAINS_multi3_ossa_lowh(:,3,num);
GO_uncond(:,num)=GAINS_multi2_ossa_lowh(:,3,num);
end
mean(GO_cond)
mean(GO_uncond)

GO_cond=mean(GO_cond)*100';
GO_uncond=mean(GO_uncond)*100';
vec2=vec(1:12);
GO_cond=GO_cond(:,1:fin);
GO_uncond=GO_uncond(:,1:fin);

%Atkinson GMP
%--------------
num_final=size(vec,1); 
At_MP=ones(N,num_final);
for num=1:num_final
At_MP(:,num)=Atkinson_mp_lowh(:,1,num);
end
mean(At_MP)

At_MP=mean(At_MP);
vec2=vec(1:fin);
At_MP=At_MP(:,1:fin);

%Atkinson Trade
%--------------
num_final=size(vec,1); 
At_trade=ones(N,num_final);
for num=1:num_final
At_trade(:,num)=Atkinson_trade_lowh(:,1,num);
end
mean(At_trade)

At_trade=mean(At_trade);
vec2=vec(1:fin);
At_trade=At_trade(:,1:fin);


%MP shares 
%--------------
num_final=size(vec,1); 
MP_share=ones(N,num_final);
for num=1:num_final
MP_share(:,num)=1-local_share_lowh(:,1,num);
end
mean(MP_share)

MP_share=mean(MP_share);
vec2=vec(1:fin);
MP_share=MP_share(:,1:fin);


%Trade shares 
%--------------
num_final=size(vec,1); 
trade_share=ones(N,num_final);
for num=1:num_final
trade_share(:,num)=1-domestic_share_lowh(:,1,num);
end
mean(trade_share)
median(trade_share)

trade_share=mean(trade_share);
vec2=vec(1:fin);
trade_share=trade_share(:,1:fin);



%-------------------------------------
%Welfare 
%-------------------------------------
figure

subplot(2,3,1) 
scatter(vec2, GMP_cond, 40, 'r', '*')
hold on 
scatter(vec2, GMP_uncond, 40, 'b')
hold off
set(gcf,'color','w');
xlabel('Discount');
ylabel('\DeltaGMP (%)');
xlim([0 0.6])
set(gca,'YTick',[5 10 15 20 25 30])
title('Gains from MP');

subplot(2,3,2) 
scatter(vec2, GT_cond, 40, 'r', '*')
hold on 
scatter(vec2, GT_uncond, 40, 'b')
hold off
set(gcf,'color','w');
xlabel('Discount');
ylabel('\DeltaGT (%)');
xlim([0 0.6])
title('Gains from Trade');


subplot(2,3,3) 
scatter(vec2, GO_cond, 40, 'r', '*')
hold on 
scatter(vec2, GO_uncond, 40, 'b')
hold off
set(gcf,'color','w');
xlabel('Discount');
ylabel('\DeltaGO (%)');
xlim([0 0.6])
set(gca,'YTick',[5 10 15 20 25 30 35 40 45 50 55])
legend({'Adjusted', 'Total'});
title('Gains from Openness');


subplot(2,3,4) 
scatter(vec2, At_MP, 40, 'b', '.')
set(gcf,'color','w');
xlabel('Discount');
xlim([0 0.6])
ylim([0.03 0.12])
title('Atkinson MP shares');


subplot(2,3,5) 
scatter(vec2, At_trade, 40, 'b', '.')
set(gcf,'color','w');
xlabel('Discount');
xlim([0 0.6])
ylim([0.03 0.12])
title('Atkinson Trade shares');


subplot(2,3,6) 
scatter(vec2, trade_share, 40, 'r', '.')
hold on 
scatter(vec2, MP_share, 40, 'b',  '.')
set(gca,'YTick',[0	0.04	0.08	0.12	0.16	0.2	0.24	0.28	0.32	0.36	0.4	0.44	0.48])
hold off
set(gcf,'color','w');
xlabel('Discount');
xlim([0 0.6])
%set(gca,'YTick',[0 0.05 0.10 0.15 0.20 0.25 0.30 0.35 0.40 0.45 0.50])
set(gca,'YTick',[0	0.04	0.08	0.12	0.16	0.2	0.24	0.28	0.32	0.36	0.4	0.44	0.48])
legend({'1-\pi_{nn}', '1-y_{nn}'});
title('MP and Trade shares');

%Graph in section 5.2 in the paper
saveas(gcf,'Counterfactual_gdiscount_total_adj','eps')
saveas(gcf,'Counterfactual_gdiscount_total_adj','png')







