%**************************************************************************
%University of British Columbia
%Vanessa Alviarez
%Comparative Advantage
%Journal of International Economics 
%Last Update: 2019
%**************************************************************************

%==========================================================================
%Model based formulas (See Table A.4: Comparison of Welfare Gains in a
%multisector Trade-MP model) 
%==========================================================================


%----------------------------------------------------------------------
%Uni-sectoral formula 
%----------------------------------------------------------------------

%Standard unisectoral model 
exp0=(-1./theta);
GT_uni0=((domestic_share).^(exp0))-1;
GMP_uni0=((local_share).^(exp0).*(domestic_share./domestic_share_nomp).^(exp0))-1;
GO_uni0=((local_share).^(exp0).*(domestic_share).^(exp0))-1;
GAINS_uni0=[GT_uni0 GMP_uni0 GO_uni0];
clear GT_uni0 GMP_uni0 GO_uni0


%Unisectoral model only considering tradable sectors  
exp0=(-1./theta);
GT_uni1=((domestic_share_tradable).^(exp0))-1;
GMP_uni1=((local_share_tradable).^(exp0).*(domestic_share_tradable./domestic_share_nomp_tradable).^(exp0))-1;
GO_uni1=((local_share_tradable).^(exp0).*(domestic_share_tradable).^(exp0))-1;
GAINS_uni1=[GT_uni1 GMP_uni1 GO_uni1];
clear GT_uni1 GMP_uni1 GO_uni1

%Unisectoral model only considering tradable sectors  
exp0=(-si./theta);
GT_uni1=((domestic_share_tradable).^(exp0))-1;
GMP_uni1=((local_share_tradable).^(exp0).*(domestic_share_tradable./domestic_share_nomp_tradable).^(exp0))-1;
GO_uni1=((local_share_tradable).^(exp0).*(domestic_share_tradable).^(exp0))-1;
GAINS_uni1_pref=[GT_uni1 GMP_uni1 GO_uni1];
clear GT_uni1 GMP_uni1 GO_uni1

%Unisectoral model considering tradable sectors only (and intermediates)
exp0=(-si./(beta_all*theta));
GT_uni1=((domestic_share_tradable).^(exp0))-1;
GMP_uni1=((local_share_tradable).^(exp0).*(domestic_share_tradable./domestic_share_nomp_tradable).^(exp0))-1;
GO_uni1=((local_share_tradable).^(exp0).*(domestic_share_tradable).^(exp0))-1;
GAINS_uni1_pref=[GT_uni1 GMP_uni1 GO_uni1];
clear GT_uni1 GMP_uni1 GO_uni1

%Eaton and Kortum 2002
exp0=(-0.13./(0.21*theta));
GT_uni2=((domestic_share_tradable).^(exp0))-1;
GMP_uni2=((local_share_tradable).^(exp0).*(domestic_share_tradable./domestic_share_nomp_tradable).^(exp0))-1;
GO_uni2=((local_share_tradable).^(exp0).*(domestic_share_tradable).^(exp0))-1;
GAINS_uni2=[GT_uni2 GMP_uni2 GO_uni2];
clear GT_uni2 GMP_uni2 GO_uni2

%Unisectoral model considering intermediate inputs (in all economy) 
exp1=(-1./(beta_all.*theta));
GT_uni3=((domestic_share).^(exp1))-1;
GMP_uni3=((local_share).^(exp1).*(domestic_share./domestic_share_nomp).^(exp1))-1;
GO_uni3=((local_share).^(exp1).*(domestic_share).^(exp1))-1;
GAINS_uni3=[GT_uni3 GMP_uni3 GO_uni3];

%Ossa (tradable and non-tradable) 
exp2=(-1/theta).*D_uni;
GT_uni4=((domestic_share_tradable).^(exp2(:,1)))-1;
GMP_uni4=((local_share_tradable).^(exp2(:,1)).*(local_share_nontradable).^(exp2(:,2)).*(domestic_share_tradable./domestic_share_nomp_tradable).^(exp2(:,1)))-1;
GO_uni4=((local_share_tradable).^(exp2(:,1)).*(local_share_nontradable).^(exp2(:,2)).*(domestic_share_tradable).^(exp2(:,1)))-1;
GAINS_uni4=[GT_uni4 GMP_uni4 GO_uni4];


%----------------------------------------------------------------------
%Multi-sectoral formula (Cobb-Douglas, no capital)
%----------------------------------------------------------------------

%No linkages and no intermediate inputs, only the preference parameters)
temp=domestic_share_sector.^(si_multi.*(-1/theta));
GT_multi0=prod(temp,2)-1;
clear temp 
temp1=local_share_sector.^(si_multi.*(-1/theta));
temp1b=prod(temp1,2);
temp2=(domestic_share_sector./domestic_share_nomp_sector).^(si_multi.*(-1/theta));
temp2b=prod(temp2,2);
temp3=(domestic_share_sector).^(si_multi.*(-1/theta));
temp3b=prod(temp3,2);
GMP_multi0=temp1b.*temp2b-1;
GO_multi0=temp1b.*temp3b-1;
clear temp1 temp2 temp3 temp1b temp2b temp3b
GAINS_multi0=[GT_multi0 GMP_multi0 GO_multi0];
clear GT_multi0 GMP_multi0 GO_multi0


%No linkages BUT intermediate inputs)
temp=domestic_share_sector.^(D_multi_nolink.*(-1/theta));
GT_multi1=prod(temp,2)-1;
clear temp 
temp1=local_share_sector.^(D_multi_nolink.*(-1/theta));
temp1b=prod(temp1,2);
temp2=(domestic_share_sector./domestic_share_nomp_sector).^(D_multi_nolink.*(-1/theta));
temp2b=prod(temp2,2);
temp3=(domestic_share_sector).^(D_multi_nolink.*(-1/theta));
temp3b=prod(temp3,2);
GMP_multi1=temp1b.*temp2b-1;
GO_multi1=temp1b.*temp3b-1;
clear temp1 temp2 temp3 temp1b temp2b temp3b
GAINS_multi1=[GT_multi1 GMP_multi1 GO_multi1];
clear GT_multi1 GMP_multi1 GO_multi1


%Full (linkages and intermediate inputs)
temp=domestic_share_sector.^(D_multi.*(-1/theta));
GT_multi2=prod(temp,2)-1;  %**%
clear temp 
local_share_sector2=local_share_sector(:,1:J+1);
temp1=local_share_sector2.^(D_multi.*(-1/theta));
temp1b=prod(temp1,2);
temp2=(domestic_share_sector./domestic_share_nomp_sector).^(D_multi.*(-1/theta));
temp2b=prod(temp2,2);
temp3=(domestic_share_sector).^(D_multi.*(-1/theta));
temp3b=prod(temp3,2);
GMP_multi2=temp1b.*temp2b-1; %**%
GO_multi2=temp1b.*temp3b-1; %**%
clear temp1 temp2 temp3 temp1b temp2b temp3b
GAINS_multi2=[GT_multi2 GMP_multi2 GO_multi2];
clear GT_multi2 GMP_multi2 GO_multi2


%------------------------------------------------------------------------------------------
%Now I am constructing the adjusted gains, using the baseline model as reference

domestic_share_ratio=ones(N,J+1); 
domestic_share2=geomean(domestic_share_sector,2);
for j=1:J
    domestic_share_ratio(:,j)=domestic_share2;
end 

local_share_ratio=ones(N,J+1); 
local_share2=geomean(local_share_sector,2);
for j=1:J+1
    local_share_ratio(:,j)=local_share2;
end 

domestic_share_nomp_ratio=ones(N,J+1); 
domestic_share_nomp2=geomean(domestic_share_nomp_sector,2);
for j=1:J
    domestic_share_nomp_ratio(:,j)=domestic_share_nomp2;
end 


temp=(domestic_share_ratio).^(D_multi.*(-1/theta));
GT_multi3=prod(temp,2)-1; 
clear temp 

temp1=(local_share_ratio).^(D_multi.*(-1/theta));
temp1b=prod(temp1,2);
temp2=((domestic_share_ratio)./domestic_share_nomp_ratio).^(D_multi.*(-1/theta));
temp2b=prod(temp2,2);
GMP_multi3=temp1b.*temp2b-1;

temp3=(domestic_share_ratio).^(D_multi.*(-1/theta));
temp3b=prod(temp3,2); 
GO_multi3=temp1b.*temp3b-1; 

clear temp1 temp2 temp3 temp1b temp2b temp3b
GAINS_multi3=[GT_multi3 GMP_multi3 GO_multi3];
clear GT_multi3 GMP_multi3 GO_multi3

GAINS_multi4=(GAINS_multi2)-(GAINS_multi3);



%------------------------------------------------------------------------------------------
%NOTE: I am using this formula in order to calculate what is the floor for
%gains from heterogeneity. 
%Multisector formula that uses the aggregate trade and local aggregate share in all tradable sectors 
%Full (linkages and intermediate inputs)
domestic_share_tradable_matrix=ones(N,J+1); 
for j=1:J
 domestic_share_tradable_matrix(:,j)=domestic_share_tradable;    
end
domestic_share_nomp_tradable_matrix=ones(N,J+1); 
for j=1:J
 domestic_share_nomp_tradable_matrix(:,j)=domestic_share_nomp_tradable;    
end
local_share_tradable_matrix=ones(N,J+1); 
for j=1:J+1
 local_share_tradable_matrix(:,j)=local_share;    
end

temp=domestic_share_tradable_matrix.^(D_multi.*(-1/theta));
GT_multi2_uni=prod(temp,2)-1; 
clear temp 
temp1=local_share_tradable_matrix.^(D_multi.*(-1/theta));
temp1b=prod(temp1,2);
temp2=(domestic_share_tradable_matrix./domestic_share_nomp_tradable_matrix).^(D_multi.*(-1/theta));
temp2b=prod(temp2,2);
temp3=(domestic_share_tradable_matrix).^(D_multi.*(-1/theta));
temp3b=prod(temp3,2);

GMP_multi2_uni=temp1b.*temp2b-1; 
GO_multi2_uni=temp1b.*temp3b-1; 
clear temp1 temp2 temp3 temp1b temp2b temp3b
GAINS_multi2_uni=[GT_multi2_uni GMP_multi2_uni GO_multi2_uni];
clear GT_multi2_uni GMP_multi2_uni GO_multi2_uni

