%**************************************************************************
%University of British Columbia
%Vanessa Alviarez
%Comparative Advantage
%Journal of International Economics 
%Last Update: 2019
%**************************************************************************


%==========================================================================
%Ossa extended to a model of trade and MP
%==========================================================================


%------------------------------------------------------------
%one for MP and one for trade (with and without MP). 
ratio_share_trade=ones(N,J+1);
for j=1:J+1
ratio_share_trade(:,j)=(log(domestic_share_sector(:,j)))./(log(domestic_share));
end

ratio_share_mp=ones(N,J+1);
for j=1:J+1
num=log((local_share_sector(:,j).*domestic_share_sector(:,j))./domestic_share_nomp_sector(:,j)); 
den=log((local_share.*domestic_share)./domestic_share_nomp); 
ratio_share_mp(:,j)=num./den;
clear num den
end

ratio_share_op=ones(N,J+1);
for j=1:J+1
num=log((local_share_sector(:,j).*domestic_share_sector(:,j))); 
den=log((local_share.*domestic_share)); 
ratio_share_op(:,j)=num./den;
clear num den
end


%------------------------------------------------------------
%For GT
%------------------------------------------------------------
gamma_multi_tran=gamma_a';
beta_multi_tran=(1-beta_1);

Bj=ones(J+1,J+1);
for j=1:J+1
Bj(:,j)=gamma_multi_tran(:,j).*beta_multi_tran(:,1);
end
Cj=inv(eye(J+1,J+1)-Bj);

si_multi=ones(N,J); 
for j=1:J
si_multi(:,j)=si.*omega(1,j);
end
si_multi=[si_multi (1-si)];
%Note: to construct expenditure shares on tradable goods, si, that are
%sector specific (sij), we multiply the original si by the omega (taste parameter
%in the model). Ideally we could use isntead data on GDP at the country-sector level
%to construct the si_multi matrix above. 

si_multi_2=ones(N,J+1,J+1);
for n=1:N
   for j=1:J+1
si_multi_2(n,:,j)=si_multi(n,:).*ratio_share_trade(n,j).*(-1/theta);     
   end
end

D_multi_trade_ossa=ones(N,J+1,J+1);
for j=1:J+1
    for k=1:J+1
D_multi_trade_ossa(:,k,j)=si_multi_2(:,k,j)*Cj(k,j);
    end
end
D_multi_trade_ossa=sum((sum(D_multi_trade_ossa,3)),2);


%------------------------------------------------------------
%For GMP
%------------------------------------------------------------
gamma_multi_tran=gamma_a';
beta_multi_tran=(1-beta_1);

Bj=ones(J+1,J+1);
for j=1:J+1
Bj(:,j)=gamma_multi_tran(:,j).*beta_multi_tran(:,1);
end
Cj=inv(eye(J+1,J+1)-Bj);

si_multi=ones(N,J);
for j=1:J
si_multi(:,j)=si.*omega(1,j);
end
si_multi=[si_multi (1-si)];

si_multi_2=ones(N,J+1,J+1);
for n=1:N
   for j=1:J+1
si_multi_2(n,:,j)=si_multi(n,:).*ratio_share_mp(n,j).*(-1/theta);     
   end
end

D_multi_mp_ossa=ones(N,J+1,J+1);
for j=1:J+1
    for k=1:J+1
D_multi_mp_ossa(:,k,j)=si_multi_2(:,k,j)*Cj(k,j);
    end
end
D_multi_mp_ossa=sum((sum(D_multi_mp_ossa,3)),2);



%------------------------------------------------------------
%For GO
%------------------------------------------------------------
gamma_multi_tran=gamma_a';
beta_multi_tran=(1-beta_1);

Bj=ones(J+1,J+1);
for j=1:J+1
Bj(:,j)=gamma_multi_tran(:,j).*beta_multi_tran(:,1);
end
Cj=inv(eye(J+1,J+1)-Bj);

si_multi=ones(N,J);
for j=1:J
si_multi(:,j)=si.*omega(1,j);

end
si_multi=[si_multi (1-si)];

si_multi_2=ones(N,J+1,J+1);
for n=1:N
   for j=1:J+1
si_multi_2(n,:,j)=si_multi(n,:).*ratio_share_op(n,j).*(-1/theta);     
   end
end

D_multi_op_ossa=ones(N,J+1,J+1);
for j=1:J+1
    for k=1:J+1
D_multi_op_ossa(:,k,j)=si_multi_2(:,k,j)*Cj(k,j);
    end
end
D_multi_op_ossa=sum((sum(D_multi_op_ossa,3)),2);
clear si_multi_2



%------------------------------------------------------------
%Welfare Unconditional
%------------------------------------------------------------

a1_mp=(domestic_share).^(D_multi_trade_ossa);
a2_mp=((local_share.*domestic_share)./domestic_share_nomp).^(D_multi_mp_ossa);
a3_mp=((local_share.*domestic_share)).^(D_multi_op_ossa);

GT_multi2_ossa=a1_mp-1;
GMP_multi2_ossa=a2_mp-1;
GO_multi2_ossa=a3_mp-1;
GAINS_multi2_ossa=[GT_multi2_ossa GMP_multi2_ossa GO_multi2_ossa];

clear a1_mp a2_mp a3_mp





%===================================================================================================================
%Ossa extended to a model of trade and MP (Adjustment Factor)
%===================================================================================================================

%------------------------------------------------------------
%Welfare Conditional. Note: prov, means provisional
%------------------------------------------------------------
%Now I am constructing the adjusted gains, using the baseline model as reference
domestic_share_prov=domestic_share; 
local_share_prov=local_share; 
domestic_share_nomp_prov=domestic_share_nomp; 
domestic_share_sector_prov=domestic_share_sector;
domestic_share_nomp_sector_prov=domestic_share_nomp_sector;
local_share_sector_prov=local_share_sector;
load 'equilibrium_transit.mat' domestic_share domestic_share_sector  domestic_share_nomp  domestic_share_nomp_sector local_share local_share_sector

domestic_share_ori=domestic_share;
local_share_ori=local_share;
domestic_share_nomp_ori=domestic_share_nomp;
domestic_share_nomp_sector_ori=domestic_share_nomp_sector;
domestic_share_sector_ori=domestic_share_sector;
local_share_sector_ori=local_share_sector;
clear domestic_share domestic_share_sector  domestic_share_nomp  domestic_share_nomp_sector local_share local_share_sector

domestic_share=domestic_share_prov;
local_share=local_share_prov; 
domestic_share_nomp=domestic_share_nomp_prov; 
domestic_share_nomp_sector=domestic_share_nomp_sector_prov;
domestic_share_sector=domestic_share_sector_prov;
local_share_sector=local_share_sector_prov;
clear domestic_share_prov domestic_share_sector_prov domestic_share_nomp_prov domestic_share_nomp_sector_prov local_share_prov local_share_sector_prov




%==========================================================================
%Ratios for domestic trade, MP shares and domestic trade (without MP) 
%==========================================================================

ratio_share_trade=ones(N,J+1);
for j=1:J+1
ratio_share_trade(:,j)=(log(((domestic_share_sector(:,j).*domestic_share_ori)./domestic_share))./log(domestic_share));
end

ratio_share_mp=ones(N,J+1);
a2=((local_share_ori.*domestic_share_ori)./domestic_share_nomp_ori);
a3=((local_share.*domestic_share)./domestic_share_nomp);
for j=1:J+1
a1=(domestic_share_sector(:,j).*local_share_sector(:,j))./domestic_share_nomp_sector(:,j); 
ratio_share_mp(:,j)=log((a1.*a2./a3))./log(a3);
clear a1 
end
clear a2 a3 

ratio_share_op=ones(N,J+1);
a2=((local_share_ori.*domestic_share_ori));
a3=((local_share.*domestic_share));
for j=1:J+1
a1=(domestic_share_sector(:,j).*local_share_sector(:,j)); 
ratio_share_op(:,j)=log((a1.*a2./a3))./log(a3);
clear a1 
end
clear a2 a3 



%------------------------------------------------------------
%PART I: For the domestic trade shares (pnn)
%------------------------------------------------------------
gamma_multi_tran=gamma_a';
beta_multi_tran=(1-beta_1);

Bj=ones(J+1,J+1);
for j=1:J+1
Bj(:,j)=gamma_multi_tran(:,j).*beta_multi_tran(:,1);
end
Cj=inv(eye(J+1,J+1)-Bj);

si_multi=ones(N,J);
for j=1:J
si_multi(:,j)=si.*omega(1,j);
end
si_multi=[si_multi (1-si)];

si_multi_2=ones(N,J+1,J+1);
for n=1:N
   for j=1:J+1
si_multi_2(n,:,j)=si_multi(n,:).*ratio_share_trade(n,j).*(-1/theta);     
   end
end

D_multi_trade_ossa_adj=ones(N,J+1,J+1);
for j=1:J+1
    for k=1:J+1
D_multi_trade_ossa_adj(:,k,j)=si_multi_2(:,k,j)*Cj(k,j);
    end
end
D_multi_trade_ossa_adj=sum((sum(D_multi_trade_ossa_adj,3)),2);



%------------------------------------------------------------
%PART II: For the MP shares (ynn)
%------------------------------------------------------------
gamma_multi_tran=gamma_a';
beta_multi_tran=(1-beta_1);

Bj=ones(J+1,J+1);
for j=1:J+1
Bj(:,j)=gamma_multi_tran(:,j).*beta_multi_tran(:,1);
end
Cj=inv(eye(J+1,J+1)-Bj);

si_multi=ones(N,J);
for j=1:J
si_multi(:,j)=si.*omega(1,j);
end
si_multi=[si_multi (1-si)];

si_multi_2=ones(N,J+1,J+1);
for n=1:N
   for j=1:J+1
si_multi_2(n,:,j)=si_multi(n,:).*ratio_share_mp(n,j).*(-1/theta);     
   end
end

D_multi_mp_ossa_adj=ones(N,J+1,J+1);
for j=1:J+1
    for k=1:J+1
D_multi_mp_ossa_adj(:,k,j)=si_multi_2(:,k,j)*Cj(k,j);
    end
end
D_multi_mp_ossa_adj=sum((sum(D_multi_mp_ossa_adj,3)),2);


%------------------------------------------------------------
%PART III: For the trade shares with no MP (pi_nn_bar)
%------------------------------------------------------------
gamma_multi_tran=gamma_a';
beta_multi_tran=(1-beta_1);

Bj=ones(J+1,J+1);
for j=1:J+1
Bj(:,j)=gamma_multi_tran(:,j).*beta_multi_tran(:,1);
end
Cj=inv(eye(J+1,J+1)-Bj);

si_multi=ones(N,J);
for j=1:J
si_multi(:,j)=si.*omega(1,j);

end
si_multi=[si_multi (1-si)];

si_multi_2=ones(N,J+1,J+1);
for n=1:N
   for j=1:J+1
si_multi_2(n,:,j)=si_multi(n,:).*ratio_share_op(n,j).*(-1/theta);     
   end
end

D_multi_op_ossa_adj=ones(N,J+1,J+1);
for j=1:J+1
    for k=1:J+1
D_multi_op_ossa_adj(:,k,j)=si_multi_2(:,k,j)*Cj(k,j);
    end
end
D_multi_op_ossa_adj=sum((sum(D_multi_op_ossa_adj,3)),2);
clear si_multi_2


%------------------------------------------------------------
%Adjusted Walfare Gain
%------------------------------------------------------------
a1_mp_adj=(domestic_share).^(D_multi_trade_ossa_adj);
a2_mp_adj=((local_share.*domestic_share)./domestic_share_nomp).^(D_multi_mp_ossa_adj);
a3_mp_adj=((local_share.*domestic_share)).^(D_multi_op_ossa_adj);
beta_ossa_new=[a1_mp_adj a2_mp_adj a3_mp_adj];

GT_multi3_ossa=a1_mp_adj-1;
GMP_multi3_ossa=a2_mp_adj-1; 
GO_multi3_ossa=a3_mp_adj-1; 
GAINS_multi3_ossa=[GT_multi3_ossa GMP_multi3_ossa GO_multi3_ossa];

clear a1_mp_adj a2_mp_adj a3_mp_adj
clear domestic_share_ori local_share_ori domestic_share_nomp_ori domestic_share_sector_ori local_share_sector_ori
clear si_multi_2 D_multi_trade_ossa_adj D_multi_mp_ossa_adj D_multi_op_ossa_adj



