%**************************************************************************
%University of British Columbia
%Vanessa Alviarez
%Comparative Advantage
%Journal of International Economics 
%Last Update: 2019
%**************************************************************************

%=======================================================================
%MODULE 1: Bring estimated parameters from Stata and calculate the
%equilibrium
%=======================================================================
%Given L, K, T(j), xi (for all N countries). Given epsilon, alpha, theta, beta, gamma(k), d(nxn), g(nxn) (for all sectors) 
%and eta we can now compute for the equilibrium of the model


%=========================================================================
%%%%                    9 SECTORS DECADE DATABASE                     %%%% 
%=========================================================================
clear all
addpath('L:\Dropbox (UBC-Umich)\MNC_CA\Data and Replication Files\matlab_code')
theta=6;
eta=2;
epsilon=4;
J=9;
omega=[0.209 0.103 0.025 0.114 0.071 0.014 0.187 0.175 0.065];
omega_sum=sum(omega);
omega_1=omega./omega_sum;
omega=omega_1;
clear omega_1
a=[1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32]';
N=size(a,1);


%-------------------------------------------------------------------------
%Trade Cost 
%-------------------------------------------------------------------------
%In STATA: outsheet sector_mp2 isiccodereporter isiccodepartner d using "parameters_d_final_wc", comma nonames nolabel replace
load parameters_d_final_wc.out

d=reshape(parameters_d_final_wc(:,4),N,N,J);
a=ones(N,N)*100000; 
for i=1:N
    for n=1:N
        if i==n
        a(i,n)=1; 
        end
    end
end
d(:,:,J+1)=a; 
clear parameters_d_final


%-------------------------------------------------------------------------
%MP Cost 
%-------------------------------------------------------------------------
load parameters_g_poisson_m_wc_final_adjusted.out
g_m_adj=reshape(parameters_g_poisson_m_wc_final_adjusted(:,4),N,N,J+1);
clear parameters_g_poisson_m_wc_final_adjusted
h=g_m_adj;


%MP only in tradables. Only activate for counterfactual of Costinot-comparative
%advantage 
%-------------------------------
%{
for i=1:N
    for n=1:N
        if i==n
h(i,n,J+1)=1;
        else
h(i,n,J+1)=100000;                  
        end
    end
end
%}


%-------------------------------------------------------------------------
%MP Technology
%-------------------------------------------------------------------------
load parameters_Tmp_m_poisson_final_adjusted_wc.out
T_mp_m_adj=reshape(parameters_Tmp_m_poisson_final_adjusted_wc(:,3),N,J+1);
clear parameters_Tmp_m_poisson_final_adjusted_wc


%ELECTION OF THE FINAL T
%--------------------------------------------------------
T_mp=T_mp_m_adj;
%{
for i=1:N
T_mp(i,J+1)=T_mp(1,J+1); %Only activate for counterfactual of Costinot-comparative
%advantage 
end
%}


%-------------------------------------------------------------------------
%Wages, Return to Capital, Labor and Capital 
%-------------------------------------------------------------------------
%In STATA: outsheet isiccodepartner wage wage_rel r1 r1_rel L K labor_rel capital_rel using "w_r_L_K", comma nonames nolabel replace
load w_r_L_K.out 
wages_rel_data=(w_r_L_K(:,3));
r_rel_data=(w_r_L_K(:,5));
labor=(w_r_L_K(:,6));
capital=(w_r_L_K(:,7));
clear w_r_L_K


%-------------------------------------------------------------------------
%Si
%-------------------------------------------------------------------------
%In STATA: outsheet isiccodepartner si using "si", comma nonames nolabel replace
load si.out
si=(si(:,2));
Bn=si.^(-si).*(1-si).^(1-si);


%-------------------------------------------------------------------------
%Alpha and Beta
%-------------------------------------------------------------------------
%In STATA: outsheet sector_mp2 alpha_mean beta_mean alpha_median beta_median using "alpha_beta", comma nonames nolabel replace
load alpha_beta.out
alpha_1=alpha_beta(:,2); 
beta_1=alpha_beta(:,3); 
clear alpha_beta

alpha_beta=alpha_1.*beta_1;
alpha_beta_1=kron(alpha_beta,ones(N,1));
alpha_beta_2=reshape(alpha_beta_1,N,1,J+1);
alpha_beta_3=ones(N,1,J+1,1); 
for i=1
   alpha_beta_3(:,1,:,i)=alpha_beta_2;
end

alpha_beta_4=(1-alpha_1).*beta_1;
alpha_beta_5=kron(alpha_beta_4,ones(N,1));
alpha_beta_6=reshape(alpha_beta_5,N,1,J+1);
alpha_beta_7=ones(N,1,J+1,1); 
for i=1
   alpha_beta_7(:,1,:,i)=alpha_beta_6;
end



%-------------------------------------------------------------------------
%Gamma
%-------------------------------------------------------------------------
load gamma_9sectors.out
gamma=gamma_9sectors; 
sum(gamma,1)



%d's and h's in Autarky
%-------------------------------------------------------------------------
d_autarky=100000.*ones(N,N,J+1);
for i=1:N
    for n=1:N
        if i==n
d_autarky(i,n,:)=1;
        end
    end
end

h_autarky=100000.*ones(N,N,J+1);
for i=1:N
    for n=1:N
        if i==n
h_autarky(i,n,:)=1;
        end
    end
end


%Calculate the T_sq
%-------------------------------------------------------------------------
h1=h.^(-theta);
T_sq_trade=ones(N,J+1); 
for j=1:J+1
T_sq_trade(:,j)=(h1(:,:,j))*T_mp(:,j);  
end
Atkinson_T_mp=1-(geomean(T_mp(:,1:J),2)./mean(T_mp(:,1:J),2));
Atkinson_T_sq=1-(geomean(T_sq_trade(:,1:J),2)./mean(T_sq_trade(:,1:J),2));
Atkinson_T=[Atkinson_T_mp Atkinson_T_sq];
mean(Atkinson_T,1)



%=========================================================================
%Step 1: Simulation 
%=========================================================================
N=size(a,1);
iter=100;
wages_sim=ones(N,iter+1);
wages_sim(:,1)=wages_rel_data;
r_capital_sim=ones(N,iter+1);
r_capital_sim(:,1)=r_rel_data;

theta=6;
rho=0;

p_sim=ones(N,1,J+1,iter+1);
gamma_a=gamma; 
gamma_arg=(theta+1-epsilon)/theta;
gamma_fun=gamma_arg;

d_trade=d;
h_mp=h;
T_store=T_mp; 

save 'parameters_1a.mat' 
save 'parameters_welfare_a.mat' %This is the mat file that will be use to run the welfare analysis. It is important to save the new parameters with the same name [WHAT THIS MEANS?]



%==========================================================================
%Main Equilibrium (CES, capital) 
%==========================================================================
clear all
load 'parameters_1a.mat' 
eta=2;
save 'parameters_welfare_a.mat'
run Equilibrium_mp_complete_loop_CES.m;

wages_equi=wages_sim(:,end-1);
r_capital_equi=r_capital_sim(:,end-1);
save('equilibrium_full_model.mat', 'wages_equi', 'r_capital_equi', 'P_tradable', 'P_tradable_si', 'P_nontradable', 'P_nontradable_si', 'PIndex');



%----------------------------------------------------------
%Evaluating Model Fit (activate to run the fit of the model) 
%----------------------------------------------------------
%run model_fit.m


%----------------------------------------------------------
%Calculating trade and MP shares to apply "based on observables" formula (in an open economy)
%----------------------------------------------------------
addpath('L:\Dropbox (UBC-Umich)\MNC_CA\Data and Replication Files\matlab_code')

run trade_mp_share.m;
save('equilibrium_full_model.mat', 'imports_nj', 'pq_sector', 'imports_nlj', 'mp_lsj', 'mp_imports_lj', 'production_sector', 'trade_share_sector', 'trade_share', 'trade_share_tradable', 'trade_nlj', 'mp_share_lj', 'mp_share_lsj', 'trade_share_nj', 'trade_share_nlj', 'inward_mp_share_sector', 'inward_mp_share', 'inward_mp_share_tradable', 'inward_mp_share_nontradable', 'mp_lsj', 'Atkinson_mp', 'Atkinson_trade', 'domestic_share', 'domestic_share_tradable', 'domestic_share_sector', 'local_share', 'local_share_tradable', 'local_share_nontradable', 'local_share_sector', '-append');


%--------------------------------------------------------------
%Calculate some aggregate parameters 
%--------------------------------------------------------------
run agg_betas_gammas.m;
save('equilibrium_full_model.mat', 'mp_ls_weight', 'trade_nl_weight', 'T_agg_all_T_savg', 'T_agg_all_savg', 'T_agg_all_T', 'T_agg_all', 'd_agg', 'd_agg_v2', 'h_agg','h_agg_v2', 'output_share_all', 'output_share_T', 'beta_T_NT', 'beta_all', 'betas_nj', 'D_multi_nolink', 'D_multi', 'D_uni', 'si_multi', '-append');


%---------------------------------------------------------------
%Run the welfare analysis
%---------------------------------------------------------------
%Index 1 (CES, capital), Index 2 (Cobb Douglas, capital), Index 3 (CES, without capital), Index 4 (Cobb Douglas, without capital)
%NOTE: it seems we can only use here 1 and 2 (I do not see the other do
%files)
index=1; 
run welfare_analysis.m; %RECALL it uses 'parameters_welfare_a.mat' file
save('equilibrium_full_model.mat', 'GAINS_baseline', 'domestic_share_nomp', 'domestic_share_nomp_tradable', 'domestic_share_nomp_sector', '-append');


%---------------------------------------------------
%Previos Step: Define which scenario is the "equilibrium scenario" (in this
%case is really the "model's equilibrium". 
clear all
load 'equilibrium_full_model.mat' 'domestic_share' 'domestic_share_nomp' 'domestic_share_sector'  'domestic_share_nomp_sector' 'local_share' 'local_share_sector' 
save('equilibrium_transit.mat'); 


%---------------------------------------------------------------
%Model based welfare analysis 
%---------------------------------------------------------------
clear all 
load 'parameters_welfare_a.mat' 
load 'equilibrium_full_model.mat';  
run Model_based_formulas.m;  
save('equilibrium_full_model.mat', 'N', 'J', 'T_mp', 'T_sq_trade', 'Atkinson_mp', 'Atkinson_trade', 'Atkinson_T', 'GAINS_baseline', 'GAINS_uni0', 'GAINS_uni1', 'GAINS_uni1_pref', 'GAINS_uni2', 'GAINS_uni3', 'GAINS_uni4', 'GAINS_multi0', 'GAINS_multi1', 'GAINS_multi2', 'GAINS_multi3', '-append');
save('equilibrium_full_model.mat', 'GAINS_multi4', '-append');


%---------------------------------------------------------------
%Run OSSA exponents for welfare analysis 
%---------------------------------------------------------------
clear all 
load 'parameters_welfare_a.mat' 
load 'equilibrium_full_model.mat';  

run agg_betas_gammas_ossa_fv.m;
save('equilibrium_full_model.mat', 'GAINS_multi2_ossa', '-append');


%---------------------------------------------------------------
%Table 4 in the paper: welfare gains (multi-sector and uni-sector) 
%---------------------------------------------------------------
gains_multi=[GAINS_baseline(:,2) GAINS_baseline(:,1) GAINS_baseline(:,3)]*100; 
gains_uni=[GAINS_uni0(:,2) GAINS_uni0(:,1) GAINS_uni0(:,3)]*100; 
GAINS_table4=[gains_multi gains_uni];
%where the order to countries are given by: 
labels={'USA', 'AUS', 'AUT', 'BEL', 'BGR', 'CAN', 'CZE', 'DNK', 'EST', 'FIN', 'FRA', 'DEU', 'GRC', 'HUN', 'ITA', 'JPN', 'LVA', 'LTU', 'MEX', 'NLD', 'NZL', 'NOR', 'POL', 'PRT', 'ROM', 'RUS', 'SVK', 'ESP', 'SWE', 'TUR', 'UKR', 'GBR'};




