%**************************************************************************
%University of British Columbia
%Vanessa Alviarez
%Comparative Advantage
%Journal of International Economics 
%Last Update: 2019
%**************************************************************************

%==========================================================================
%%Calculate Production, Value Added, Trade Shares
%==========================================================================


%-----------------------------------------------------------------------%
%Domestic Trade Share 
%-----------------------------------------------------------------------%
pq=p1(:,:,1:J+1).*Q(:,:,1:J+1);
pq=reshape(pq,N,1,1,J+1);
pq_sector=reshape(pq,N,J+1);

imports_1=ones(N,N,N,J+1); %this is xnlj. 
for l=1:N
    for s=1:N
imports_1(:,l,s,:)=pi(:,l,s,:).*pq(:,1,1,:);
    end
end
imports_2=sum(imports_1,3);
imports_nlj=reshape(imports_2,N,N,J+1);

%------------------------------------
imports_nj=ones(N,J+1);
for j=1:J+1
imports_nj(:,j)=sum(imports_nlj(:,:,j),2)-diag(imports_nlj(:,:,j));
end
%------------------------------------

trade_nlj=reshape(imports_2,N,N,J+1);
imports_3=sum(imports_2,4);
Xn=sum(imports_3,2);
temp=ones(N,N)-eye(N,N);
imports_4=imports_3.*temp;
import_5=sum(imports_4,2);
trade_share=import_5./Xn;
domestic_share=1-trade_share;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
pi_product_sum_3=trade_nlj; 
for j=1:J+1
for n=1:N
    for l=1:n
        if n==l
   pi_product_sum_3(n,l,j)=0    ;
        end
   end
end
end
pi_product_sum_3=sum(pi_product_sum_3,2);
b1=reshape(pi_product_sum_3,N,J+1);

trade_share_nlj=ones(N,N,J+1);
for j=1:J+1
for n=1:N
trade_share_nlj(:,n,j)=trade_nlj(:,n,j)./b1(:,j);
end
end
for n=1:N
for l=1:N
    if n==l
trade_share_nlj(n,l,:)=0;
    end
end
end
trade_share_nlj(isnan(trade_share_nlj)) = 0;

%--------------------------
%I need an trade_share_nj whose denominator does not include the diagonal elements
pi_product_sum_3=trade_nlj; 
for j=1:J+1
for n=1:N
    for l=1:n
        if n==l
   pi_product_sum_3(n,l,j)=0;
        end
   end
end
end
pi_product_sum_3=sum(pi_product_sum_3,2); %now this is the numerator
b1=reshape(pi_product_sum_3,N,J+1);

pi_product_sum_3=sum(pi_product_sum_3,3); %now this is the numerator
b2=pi_product_sum_3;

trade_share_nj=ones(N,J+1);
for j=1:J+1
for n=1:N
trade_share_nj(:,j)=b1(:,j)./b2(:,1);
end
end
trade_share_nj(isnan(trade_share_nj)) = 0;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%-----------------------------------------------------------------------%
%Domestic Trade Shares (for tradables only)
%-----------------------------------------------------------------------%
imports_1=ones(N,N,N,J); %this is xnlj. 
for l=1:N
    for s=1:N
imports_1(:,l,s,:)=pi(:,l,s,1:J).*pq(:,1,1,1:J);
    end
end
imports_2=sum(imports_1,3);
imports_3=reshape(imports_2,N,N,J);

%Domestic trade shares in each sector 
Xnn_sectoral=ones(N,J);
for j=1:J
Xnn_sectoral(:,j)=diag(imports_3(:,:,j));
end
Xn_sectoral=sum(imports_3,2);
Xn_sectoral=reshape(Xn_sectoral,N,J);
domestic_share_sector=Xnn_sectoral./Xn_sectoral;
Atkinson_trade=1-(geomean(domestic_share_sector,2)./mean(domestic_share_sector,2));
domestic_share_sector=[domestic_share_sector ones(N,1)];
trade_share_sector=1-domestic_share_sector;

%scatter(Atkinson_trade, Atkinson_T_sq_ori);

domestic_share_sector2=sum(pi,3);
domestic_share_sector2=reshape(domestic_share_sector2,N,N,J+1);
domestic_share_sector3=ones(N,J);
for j=1:J
domestic_share_sector3(:,j)=diag(domestic_share_sector2(:,:,j));
end


%Domestic trade shares (All Tradables)
imports_4=sum(imports_2,4);
Xnn=diag(imports_4);
Xn=sum(imports_4,2);
domestic_share_tradable=Xnn./Xn;
trade_share_tradable=1-domestic_share_tradable;
clear imports_1 imports_2 imports_3 imports_4

%-----------------------------------------------------------------------%
%Constructing the MP shares.  
%-----------------------------------------------------------------------%

%Total LOCAL Production (all economy, including tradable and non-tradables)
%----------------------------------------------------------
%Constructing P*Q
pq=p1(:,:,1:J+1).*Q(:,:,1:J+1);

pi_1=pi;

pi_product=ones(N,N,N,J+1);
for j=1:J+1
    for l=1:N
        for i=1:N
 pi_product(:,l,i,j)=pi_1(:,l,i,j).*pq(:,:,j);
        end
    end
end

%All production with self technologies (tradable and non-tradable together)
pi_product_sum=sum(pi_product,1);
mp_lsj=reshape(pi_product_sum,N,N,J+1);
pi_product_sum_agg=sum(pi_product_sum,4);
pi_product_sum_agg=reshape(pi_product_sum_agg,N,N);
pi_product_sum_agg=diag(pi_product_sum_agg);

%-----------------------------------------------
mp_imports_lj=ones(N,J+1);
for j=1:J+1
mp_imports_lj(:,j)=sum(mp_lsj(:,:,j),2)-diag(mp_lsj(:,:,j));   
end
production_sector=sum(mp_lsj,2);
production_sector=reshape(production_sector,N,J+1);
%-----------------------------------------------


%-----------------------------------------------------------------------%
%I need an mp_share_lsj whose denominator does not include the diagona elements
pi_product_sum_3=mp_lsj; 
for j=1:J+1
for l=1:N
    for s=1:n
        if l==s
   pi_product_sum_3(l,s,j)=0    ;
        end
   end
end
end
pi_product_sum_3=sum(pi_product_sum_3,2);
b1=reshape(pi_product_sum_3,N,J+1);

mp_share_lsj=ones(N,N,J+1);
for j=1:J+1
for n=1:N
mp_share_lsj(:,n,j)=mp_lsj(:,n,j)./b1(:,j);
end
end
for l=1:N
for s=1:N
    if l==s
mp_share_lsj(l,s,:)=0;
    end
end
end
mp_share_lsj(isnan(mp_share_lsj)) = 0;

%------------------------------------------------------------------------%
%I need an mp_share_lj whose denominator does not include the diagonal elements
%-----------------------------------------------------------------------%
pi_product_sum_3=mp_lsj; 
for j=1:J+1
for l=1:N
    for s=1:n
        if l==s
   pi_product_sum_3(l,s,j)=0;
        end
   end
end
end
pi_product_sum_3=sum(pi_product_sum_3,2); %now this is the numerator
b1=reshape(pi_product_sum_3,N,J+1);

pi_product_sum_3=sum(pi_product_sum_3,3); %now this is the numerator
b2=pi_product_sum_3;

mp_share_lj=ones(N,J+1);
for j=1:J+1
for n=1:N
mp_share_lj(:,j)=b1(:,j)./b2(:,1);
end
end
mp_share_lj(isnan(mp_share_lj)) = 0;

%-----------------------------------------------------------------------%
%All production with ALL technologies (tradable and non-tradable together)
%-----------------------------------------------------------------------%
pi_product_sum_1=sum(pi_product,1);
pi_product_sum_2=sum(pi_product_sum_1,3);
pi_product_sum_agg_2=sum(pi_product_sum_2,4);
pi_product_sum_agg_2=reshape(pi_product_sum_agg_2,N,1);

local_share=pi_product_sum_agg./pi_product_sum_agg_2;
inward_mp_share=1-local_share;


%-----------------------------------------------------------------------%
%All production with self technologies (each tradable sector separately)
%-----------------------------------------------------------------------%
temp=pi_product(:,:,:,1:J);
pi_product_sum=sum(temp,1);
pi_product_sum=reshape(pi_product_sum,N,N,J);
pi_product_sum_2=ones(N,J);
for j=1:J
pi_product_sum_2(:,j)=diag(pi_product_sum(:,:,j));
end
pi_product_sum_3=sum(pi_product_sum,2);
pi_product_sum_3=reshape(pi_product_sum_3,N,J);
local_share_sector=pi_product_sum_2./pi_product_sum_3;
Atkinson_mp=1-(geomean(local_share_sector,2)./mean(local_share_sector,2));


%-----------------------------------------------------------------------%
%Total LOCAL Production (for tradable and non-tradable separated)
%-----------------------------------------------------------------------%
%All production with self technologies (tradable sector only sector)
temp=pi_product(:,:,:,1:J);
pi_product_sum=sum(temp,1);
pi_product_sum_agg=sum(pi_product_sum,4);
pi_product_sum_agg=reshape(pi_product_sum_agg,N,N);
pi_product_sum_agg=diag(pi_product_sum_agg);

%All production with ALL technologies (tradable sector only)
pi_product_sum_1=sum(temp,1);
pi_product_sum_2=sum(pi_product_sum_1,3);
pi_product_sum_agg_2=sum(pi_product_sum_2,4);
pi_product_sum_agg_2=reshape(pi_product_sum_agg_2,N,1);

local_share_tradable=pi_product_sum_agg./pi_product_sum_agg_2;
inward_mp_share_tradable=1-local_share_tradable;


%All production with self technologies (NON-tradable sector only)
temp=pi_product(:,:,:,J+1);
pi_product_sum=sum(temp,1);
pi_product_sum_agg=sum(pi_product_sum,4);
pi_product_sum_agg=reshape(pi_product_sum_agg,N,N);
pi_product_sum_agg=diag(pi_product_sum_agg);

%All production with ALL technologies (tradable sector only)
temp=pi_product(:,:,:,J+1);
pi_product_sum_1=sum(temp,1);
pi_product_sum_2=sum(pi_product_sum_1,3);
pi_product_sum_agg_2=sum(pi_product_sum_2,4);
pi_product_sum_agg_2=reshape(pi_product_sum_agg_2,N,1);

local_share_nontradable=pi_product_sum_agg./pi_product_sum_agg_2;
inward_mp_share_nontradable=1-local_share_nontradable;

local_share_sector=[local_share_sector local_share_nontradable];
inward_mp_share_sector=1-local_share_sector; 


%===========================================================================================


