%**************************************************************************
%University of British Columbia
%Vanessa Alviarez
%Comparative Advantage
%Journal of International Economics 
%Last Update: 2019
%**************************************************************************


%==========================================================================
%Welfare Analysis
%==========================================================================
%Leyend
%index==1 (CES, capital) [run Equilibrium_mp_complete_loop_CES.m]
%index==2 (Cobb Douglas, capital) [run Equilibrium_mp_complete_loop_cobbdouglas.m]
%index==3 (CES, without capital) [run Equilibrium_mp_complete_loop_CES_woc.m]
%index==4 (Cobb Douglas, without capital) [run Equilibrium_mp_complete_loop_cobbdouglas_woc.m]


%----------------------------------------------------------
%index==1 (CES, capital)
%----------------------------------------------------------
if index==1;
%Welfare analysis (Gains from Trade, Gains from MP and Gains From openness)
%----------------------------------------------------------
capital_pc=capital./labor;
ry_t1=(wages_equi+capital_pc.*r_capital_equi)./PIndex;
GAINS=ones(N,3);

%Gains from oppennes 
load 'parameters_welfare_a.mat' 
d=d_autarky;
h=h_autarky;
p_sim=ones(N,1,J+1,iter+1);
wages_sim=ones(N,iter+1);
r_capital_sim=ones(N,iter+1);
clear PIndex
run Equilibrium_mp_complete_loop_CES.m;
wages_autarky=wages_sim(:,end-1);
r_capital_autarky=r_capital_sim(:,end-1);
ry_to_autarky=(wages_autarky+capital_pc.*r_capital_autarky)./PIndex;
GO=(ry_t1./ry_to_autarky)-1;

%Gains from trade 
load 'parameters_welfare_a.mat' 
d=d_autarky;
h=h_mp;
p_sim=ones(N,1,J+1,iter+1);
wages_sim=ones(N,iter+1);
r_capital_sim=ones(N,iter+1);
clear PIndex
run Equilibrium_mp_complete_loop_CES.m;
wages_trade=wages_sim(:,end-1);
r_capital_trade=r_capital_sim(:,end-1);
ry_to_trade=(wages_trade+capital_pc.*r_capital_trade)./PIndex;
GT=(ry_t1./ry_to_trade)-1;

%Gains from MP 
load 'parameters_welfare_a.mat' 
d=d_trade;
h=h_autarky;
p_sim=ones(N,1,J+1,iter+1);
wages_sim=ones(N,iter+1);
r_capital_sim=ones(N,iter+1);
clear PIndex
run Equilibrium_mp_complete_loop_CES.m;
wages_mp=wages_sim(:,end-1);
r_capital_mp=r_capital_sim(:,end-1);
ry_to_mp=(wages_mp+capital_pc.*r_capital_mp)./PIndex;
GMP=(ry_t1./ry_to_mp)-1;

%Summarizing
%--------------------------------
GAINS(:,1)=GT; 
GAINS(:,2)=GMP; 
GAINS(:,3)=GO;
GAINS_baseline=GAINS;
clear GAINS

%Calculate the trade share in the counterfactual equilibrium with trade but
%not MP; 
run trade_mp_share.m;
domestic_share_nomp=domestic_share;
domestic_share_nomp_tradable=domestic_share_tradable;
domestic_share_nomp_sector=domestic_share_sector;
end


%----------------------------------------------------------
%index==2 (Cobb Douglas, capital)
%----------------------------------------------------------
if index==2;
    
%Welfare analysis (Gains from Trade, Gains from MP and Gains From openness)
%----------------------------------------------------------
capital_pc=capital./labor;
ry_t1=(wages_equi+capital_pc.*r_capital_equi)./PIndex;
GAINS=ones(N,3);

%Gains from oppennes 
load 'parameters_welfare_a.mat' 
d=d_autarky;
h=h_autarky;
p_sim=ones(N,1,J+1,iter+1);
wages_sim=ones(N,iter+1);
r_capital_sim=ones(N,iter+1);
clear PIndex
run Equilibrium_mp_complete_loop_cobbdouglas.m;
wages_autarky=wages_sim(:,end-1);
r_capital_autarky=r_capital_sim(:,end-1);
ry_to_autarky=(wages_autarky+capital_pc.*r_capital_autarky)./PIndex;
GO=(ry_t1./ry_to_autarky)-1;

%Gains from trade 
load 'parameters_welfare_a.mat' 
d=d_autarky;
h=h_mp;
p_sim=ones(N,1,J+1,iter+1);
wages_sim=ones(N,iter+1);
r_capital_sim=ones(N,iter+1);
clear PIndex
run Equilibrium_mp_complete_loop_cobbdouglas.m;
wages_trade=wages_sim(:,end-1);
r_capital_trade=r_capital_sim(:,end-1);
ry_to_trade=(wages_trade+capital_pc.*r_capital_trade)./PIndex;
GT=(ry_t1./ry_to_trade)-1;

%Gains from MP 
load 'parameters_welfare_a.mat' 
d=d_trade;
h=h_autarky;
p_sim=ones(N,1,J+1,iter+1);
wages_sim=ones(N,iter+1);
r_capital_sim=ones(N,iter+1);
clear PIndex
run Equilibrium_mp_complete_loop_cobbdouglas.m;
wages_mp=wages_sim(:,end-1);
r_capital_mp=r_capital_sim(:,end-1);
ry_to_mp=(wages_mp+capital_pc.*r_capital_mp)./PIndex;
GMP=(ry_t1./ry_to_mp)-1;

%Summarizing
%--------------------------------
GAINS(:,1)=GT; 
GAINS(:,2)=GMP; 
GAINS(:,3)=GO;
GAINS_baseline=GAINS;
clear GAINS

%Calculate the trade share in the counterfactual equilibrium with trade but
%not MP; 
run trade_mp_share.m;
domestic_share_nomp=domestic_share;
domestic_share_nomp_tradable=domestic_share_tradable;
domestic_share_nomp_sector=domestic_share_sector;
end


%----------------------------------------------------------
%index==3 (CES, without capital)
%----------------------------------------------------------
if index==3;
    
%Welfare analysis (Gains from Trade, Gains from MP and Gains From openness)
%----------------------------------------------------------
capital_pc=capital./labor;
ry_t1=(wages_equi+capital_pc.*r_capital_equi)./PIndex;
GAINS=ones(N,3);

%Gains from oppennes 
load 'parameters_welfare_a.mat' 
d=d_autarky;
h=h_autarky;
p_sim=ones(N,1,J+1,iter+1);
wages_sim=ones(N,iter+1);
r_capital_sim=ones(N,iter+1);
clear PIndex
run Equilibrium_mp_complete_loop_CES_woc.m;
wages_autarky=wages_sim(:,end-1);
r_capital_autarky=r_capital_sim(:,end-1);
ry_to_autarky=(wages_autarky+capital_pc.*r_capital_autarky)./PIndex;
GO=(ry_t1./ry_to_autarky)-1;

%Gains from trade 
load 'parameters_welfare_a.mat' 
d=d_autarky;
h=h_mp;
p_sim=ones(N,1,J+1,iter+1);
wages_sim=ones(N,iter+1);
r_capital_sim=ones(N,iter+1);
clear PIndex
run Equilibrium_mp_complete_loop_CES_woc.m;
wages_trade=wages_sim(:,end-1);
r_capital_trade=r_capital_sim(:,end-1);
ry_to_trade=(wages_trade+capital_pc.*r_capital_trade)./PIndex;
GT=(ry_t1./ry_to_trade)-1;

%Gains from MP 
load 'parameters_welfare_a.mat' 
d=d_trade;
h=h_autarky;
p_sim=ones(N,1,J+1,iter+1);
wages_sim=ones(N,iter+1);
r_capital_sim=ones(N,iter+1);
clear PIndex
run Equilibrium_mp_complete_loop_CES_woc.m;
wages_mp=wages_sim(:,end-1);
r_capital_mp=r_capital_sim(:,end-1);
ry_to_mp=(wages_mp+capital_pc.*r_capital_mp)./PIndex;
GMP=(ry_t1./ry_to_mp)-1;

%Summarizing
%--------------------------------
GAINS(:,1)=GT; 
GAINS(:,2)=GMP; 
GAINS(:,3)=GO;
GAINS_baseline=GAINS;
clear GAINS

%Calculate the trade share in the counterfactual equilibrium with trade but
%not MP; 
run trade_mp_share.m;
domestic_share_nomp=domestic_share;
domestic_share_nomp_tradable=domestic_share_tradable;
domestic_share_nomp_sector=domestic_share_sector;
end

%----------------------------------------------------------
%index==4 (Cobb Douglas, without capital)
%----------------------------------------------------------
if index==4;
    
%Welfare analysis (Gains from Trade, Gains from MP and Gains From openness)
%----------------------------------------------------------
capital_pc=capital./labor;
ry_t1=(wages_equi+capital_pc.*r_capital_equi)./PIndex;
GAINS=ones(N,3);

%Gains from oppennes 
load 'parameters_welfare_a.mat' 
d=d_autarky;
h=h_autarky;
p_sim=ones(N,1,J+1,iter+1);
wages_sim=ones(N,iter+1);
r_capital_sim=ones(N,iter+1);
clear PIndex
run Equilibrium_mp_complete_loop_CD_nocapital.m;
wages_autarky=wages_sim(:,end-1);
r_capital_autarky=r_capital_sim(:,end-1);
ry_to_autarky=(wages_autarky+capital_pc.*r_capital_autarky)./PIndex;
GO=(ry_t1./ry_to_autarky)-1;

%Gains from trade 
load 'parameters_welfare_a.mat' 
d=d_autarky;
h=h_mp;
p_sim=ones(N,1,J+1,iter+1);
wages_sim=ones(N,iter+1);
r_capital_sim=ones(N,iter+1);
clear PIndex
run Equilibrium_mp_complete_loop_CD_nocapital.m;
wages_trade=wages_sim(:,end-1);
r_capital_trade=r_capital_sim(:,end-1);
ry_to_trade=(wages_trade+capital_pc.*r_capital_trade)./PIndex;
GT=(ry_t1./ry_to_trade)-1;

%Gains from MP 
load 'parameters_welfare_a.mat' 
d=d_trade;
h=h_autarky;
p_sim=ones(N,1,J+1,iter+1);
wages_sim=ones(N,iter+1);
r_capital_sim=ones(N,iter+1);
clear PIndex
run Equilibrium_mp_complete_loop_CD_nocapital.m;
wages_mp=wages_sim(:,end-1);
r_capital_mp=r_capital_sim(:,end-1);
ry_to_mp=(wages_mp+capital_pc.*r_capital_mp)./PIndex;
GMP=(ry_t1./ry_to_mp)-1;

%Summarizing
%--------------------------------
GAINS(:,1)=GT; 
GAINS(:,2)=GMP; 
GAINS(:,3)=GO;
GAINS_baseline=GAINS;
clear GAINS

%Calculate the trade share in the counterfactual equilibrium with trade but
%not MP; 
run trade_mp_share.m;
domestic_share_nomp=domestic_share;
domestic_share_nomp_tradable=domestic_share_tradable;
domestic_share_nomp_sector=domestic_share_sector;
end