*************************************************************************
*University of British Columbia
*Sauder School of Business  
*Vanessa Alviarez
*Multinationals and Comparative Advantage
*Journal of International Economics
*************************************************************************

*=======================================================================
*TITLE: Section 4 in "Mutinational Production and Comparative Advantage"
*DESCRIPTION: Estimation of MP barriers and productivity parameters. 
*=======================================================================

*------------------------------------------------------------------
*First create a dataset form
*------------------------------------------------------------------
clear all
set more off 
cd "L:\Dropbox (UBC-Umich)\MNC_CA\Data and Replication Files" 
*change to users directory*/
do "MP_CA_directory.do"
local num_prev=`num'-1



use "${MP_CA_data}/mp_trade_origin_location_sectors_mp.dta", clear

drop if sector_mp=="S_NT"
local num_countries=32
drop exp1-imp`num_countries'
tabulate isiccodereporter, gen(imp)
tabulate isiccodepartner, gen(exp)

display "`num'"
local method poisson
local theta=6
display "`method'"
local type m
display "`type'"

keep depvar1_reg depvar1_poisson origin location sector_mp isiccodereporter isiccodepartner exp1-exp`num_countries' ln_dist contig colony comlang_off RTA

merge m:1 isiccodereporter sector_mp using "${MP_CA_data}/gravity_mp/`method'/parameters_gT_master_`type'_`factor'.dta", keepusing(T_beta_`num_prev') 
drop _merge
rename T_beta_`num_prev' T_beta_location
replace T_beta_location=ln(T_beta_location)
merge m:1 isiccodepartner sector_mp using "${MP_CA_data}/gravity_mp/`method'/parameters_gT_master_`type'_`factor'.dta", keepusing(T_beta_`num_prev') 
drop _merge
rename T_beta_`num_prev' T_beta_origin
replace T_beta_origin=ln(T_beta_origin)
save "${MP_CA_data}/gravity_mp/`method'/database_interim_`factor'.dta", replace



*============================================================================
*Step 1: Run constraint regressions
*============================================================================
local sector2 S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 
disp "`sector2'"

foreach s of local sector2 {

display _newline(2) "Regression sector_`s'"
clear all
use "${MP_CA_data}/gravity_mp/`method'/database_interim_`factor'.dta" if sector_mp=="`s'", clear

constraint 1 T_beta_origin=1
constraint 2 T_beta_location=-1

*Running the poisson regressions
*----------------------------------------------
cnsreg depvar1_reg T_beta_origin T_beta_location exp2-exp`num_countries' ln_dist contig colony comlang_off RTA, vce(robust) constraint(1 2) 
predict xb_`method', xb
gen resid_`method'_ln=depvar1_reg-xb_`method'
keep resid_`method'_ln sector_mp isiccodereporter isiccodepartner  
save "${MP_CA_data}/gravity_mp/`method'/resid_interim_`method'_`s'_`factor'.dta", replace


*----------------------------------------------
*Saving the coefficients for gravity variables 
*----------------------------------------------
matrix b = e(b)
svmat b
local last=`num_countries'-1+2+6
keep b1-b`last'
keep if b1!=.
gen A=1
reshape long b, i(A) j(coef)
drop A
gen sector="`s'"

preserve 
keep if coef>=3 & coef<=`num_countries'-1+2
save "${MP_CA_data}/gravity_mp/`method'/xfe_interim_`method'_`s'_`factor'.dta", replace

restore
keep if coef>=`num_countries'-1+2+1
save "${MP_CA_data}/gravity_mp/`method'/barriers_interim_`method'_`s'_`factor'.dta", replace
clear all
}
*
*Appending files:
*--------------------------------------------------------------------------
clear all
set more off 
local sector2 S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 
disp "`sector2'"

foreach val in resid xfe barriers {
clear all
set obs 1
gen x=.	
   
 foreach s of local sector2 {
 append using "${MP_CA_data}/gravity_mp/`method'/`val'_interim_`method'_`s'_`factor'.dta"
 erase "${MP_CA_data}/gravity_mp/`method'/`val'_interim_`method'_`s'_`factor'.dta"
 compress 
   }
drop if _n==1
drop x
save "${MP_CA_data}/gravity_mp/`method'/`val'_interim_`method'_`factor'.dta", replace
}
*
 
    
*============================================================================
*Step 2: MP_barriers
*============================================================================
clear all
local sector2 S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 
disp "`sector2'"

clear all 
use "${MP_CA_data}/gravity_mp/`method'/barriers_interim_`method'_`factor'.dta", clear
reshape wide b, i(sector) j(coef) 
local num_countries=32


*Renaming the coefficients (ln_dist contig colony comlang_off RTA)
*-----------------------------------------------
local last=`num_countries'-1+2+1
rename b`last' beta_dist
local last=`last'+1
rename b`last' border
local last=`last'+1
rename b`last' colony
local last=`last'+1
rename b`last' language
local last=`last'+1
rename b`last' rta
local last=`last'+1
rename b`last' cte

foreach var in beta_dist border colony language rta cte {
gen `var'_theta=`var'/(-`theta')
}
*
drop beta_dist  border colony language rta cte
save "${MP_CA_data}/gravity_mp/`method'/barriers_interim_`method'_theta_`factor'.dta", replace


*============================================================================
*Step 3: Importer and Exporter Fixed Effect
*============================================================================  
clear all
local sector2 S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 
disp "`sector2'"

use "${MP_CA_data}/gravity_mp/`method'/xfe_interim_`method'_`factor'.dta", clear
replace coef=coef-1
rename b xfe


*Adding USA (by brutal force)
*-------------------------------------------------------
foreach var in S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37  {
local new = _N + 1
set obs `new' 
replace coef=1 if coef==.
replace sector="`var'" if sector==""
replace xfe=0 if xfe==. & coef==1
}
sort sector coef


*---------------------------------------------------------   
*Calculating the export barriers term (to calculate trade barriers later) 
*Note it is always calculated the same way, the issue is to wich side of the trasanction we do attribute this additional cost 
*---------------------------------------------------------
by sector, sort: egen a=median(xfe)
replace xfe=a if xfe==0 & coef!=1
drop a
gen exp_barr_theta=-(1/`theta')*(xfe)


*Merging the country codes with the coef using "gravity_trade/country_coef_codes.dta"
*--------------------------------------------------------
merge m:1 coef using "${MP_CA_data}/countrycode_match_gravity_coef.dta", keepusing(isiccodereporter) update
drop if _merge==2 
drop _merge
gen isiccodepartner=isiccodereporter
save "${MP_CA_data}/gravity_mp/`method'/parameters_interim_`method'_xfe_`factor'.dta", replace



*============================================================================
*Step 4: ERROR TERM
*============================================================================
use location origin isiccodereporter isiccodepartner sector_mp ln_dist contig colony comlang_off RTA depvar1_mp using "${MP_CA_data}/mp_trade_origin_location_sectors_mp.dta", clear

*Include the error term*
*-------------------------------------
merge 1:1 isiccodereporter isiccodepartner sector_mp using "${MP_CA_data}/gravity_mp/`method'/resid_interim_`method'_`factor'.dta"
keep if _merge==3
drop _merge

*Include the betas for the "distance" variables (with each theta respectively)
*-------------------------------------
gen sector=sector_mp
merge m:1 sector using "${MP_CA_data}/gravity_mp/`method'/barriers_interim_`method'_theta_`factor'.dta", keepusing(beta_dist_theta border_theta colony_theta language_theta rta_theta cte_theta)
keep if _merge==3
drop _merge


*----------------------------------------------------------------------
*Include the exporter and importer barriers* (notice that we always call it always EXPORT BARRIERS)
*----------------------------------------------------------------------
*It is S, but we matched it with the partner, becasue that is where we need it to be for the construction of the adjustment factor. 
merge m:1 isiccodepartner sector using "${MP_CA_data}/gravity_mp/`method'/parameters_interim_`method'_xfe_`factor'.dta", keepusing(exp_barr_theta)
drop if _merge==2
drop _merge

foreach var in exp_barr_theta {
rename `var' `var'_partner
}
foreach y in partner {
replace exp_barr_theta_`y'=0 if isiccode`y'==1 & exp_barr_theta_`y'==.
}
*

*Calculating the dij matrix* (D_`method'_`s'_partner is the trade barriers calculated with exporter effect and D_`method'_`s'_reporter is the trade barrirer calculated with importer effect) 
*-------------------------------------
gen resid_`method'_ln_theta=resid_`method'_ln/(-`theta')
foreach var in partner  {
gen D_`method'_theta_`var'=cte_theta + beta_dist_theta*ln_dist + border_theta*contig + colony_theta*colony+ language_theta*comlang_off + rta_theta*RTA + exp_barr_theta_`var' + resid_`method'_ln_theta
replace D_`method'_theta_`var'=exp(D_`method'_theta_`var')
sum D_`method'_theta_`var', d
*New
*-------------------
replace D_`method'_theta_`var'=0 if depvar1_mp==0
replace D_`method'_theta_`var'=1.40 if D_`method'_theta_`var'<1.40 & depvar1_mp!=0
}
save "${MP_CA_data}/gravity_mp/`method'/parameters_interim_`method'_transition_`factor'.dta", replace


*ONLY BARRERAS to MP*
*--------------------------------------------------------------------
clear all
use "${MP_CA_data}/gravity_mp/`method'/parameters_interim_`method'_transition_`factor'.dta", clear
keep origin location isiccodereporter isiccodepartner sector_mp D_`method'_theta_partner 
save "${MP_CA_data}/gravity_mp/`method'/parameters_interim_`method'_dmatrix_`factor'_last.dta", replace




 
*============================================================================
*Step 5: Arranging the g's and calculate the T_sq  
*============================================================================
clear all
local method poisson 
local theta=6
use "${MP_CA_data}/gravity_mp/`method'/parameters_interim_`method'_dmatrix_`factor'_last.dta", clear

fillin isiccodepartner isiccodereporter sector
drop _fillin
foreach var in D_`method'_theta_partner  {
replace `var'=1 if isiccodepartner==isiccodereporter
}
* 
foreach var in D_`method'_theta_partner  {
replace `var'=2000 if `var'==.
replace `var'=1000 if `var'==0
}
* 
by isiccodepartner, sort: egen a=mode(origin)
replace origin=a if origin==""
drop a
by isiccodereporter, sort: egen a=mode(location)
replace location=a if location==""
drop a

sort sector_mp isiccodereporter isiccodepartner
keep origin location sector_mp isiccodereporter isiccodepartner D_`method'_theta_partner

rename D_`method'_theta_partner g
replace g=g^(-`theta')
save "${MP_CA_data}/gravity_mp/`method'/parameters_interim_`method'_equation_gs_`factor'.dta", replace



********************************************************************
*Storage only (g matrix) 
*--------------------------------------------------------------------
preserve
use "${MP_CA_data}/gravity_mp/`method'/parameters_gs_master_`type'_`factor'.dta", clear
merge 1:1 isiccodereporter isiccodepartner sector_mp using "${MP_CA_data}/gravity_mp/`method'/parameters_interim_`method'_equation_gs_`factor'.dta", keepusing(g)
drop _merge
rename g g_`num'
save, replace
restore
********************************************************************
 


*---------------------------------------
*NOW Bring the last set the T_betas and compute the Tsq with the new set of g's (calculated above) 
*---------------------------------------
merge m:1 sector_mp isiccodepartner using "${MP_CA_data}/gravity_mp/`method'/parameters_gT_master_`type'_`factor'.dta", keepusing(T_beta_`num_prev')                                  
drop if _merge==2
drop _merge
sort sector_mp isiccodereporter
rename T_beta_`num_prev' T_beta
format %9.2fc T_beta

gen a=g*T_beta
by isiccodereporter sector_mp, sort: egen Tmp_sq=total(a)
drop a
by isiccodereporter sector_mp, sort: gen a=_n==1
keep if a==1
drop a
drop origin isiccodepartner
drop T_beta
drop g

*Now bring the teachnology of TRADE to each importer 
*----------------------------------------------------
merge m:1 sector_mp isiccodereporter using "${MP_CA_data}/gravity_mp/`method'/parameters_gT_master_`type'_`factor'.dta", keepusing(T_trade_reg_1)
keep if _merge==3
drop _merge
rename T_trade_reg_1 T_trade_reg
format %9.1fc Tmp_sq T_trade_reg 
order location sector_mp isiccodereporter Tmp_sq T_trade_reg



*============================================================================
*Step 6: Calculate the gap in levels
*============================================================================
gen gap=T_trade_reg-Tmp_sq

merge 1:1 sector_mp isiccodereporter using "${MP_CA_data}/gravity_mp/`method'/parameters_gT_master_`type'_`factor'.dta", keepusing(gap_`num_prev' Tmp_sq_`num_prev')
drop if _merge==2
drop _merge
rename gap_`num_prev' gap_prev 
rename Tmp_sq_`num_prev' Tmp_sq_prev


/*
*Notice: The gap for m is 0.01 and x is 0.005
*-------------------------------------------------------
local adjfactor=0.005
gen sign_gap=1
replace sign_gap=-1 if gap<0
gen ratio2=abs(gap)/Tmp_sq
gen gap2=Tmp_sq*`adjfactor'*sign_gap
*gen gap2=gap*0.01
gen ind=0
replace ind=1 if (gap<0 & gap_prev>=0) | (gap>0 & gap_prev<=0) /*Just passed the zero line (from one side to the next, regardless of the side) */


*RULES: 
*------------------------------------------
gen new_Tsq=.
*replace new_Tsq=Tmp_sq if ratio2<0.01              /**First Rule**/
replace new_Tsq=Tmp_sq_prev if new_Tsq==. & ind==1  /**Second Rule**/
replace new_Tsq=Tmp_sq+gap2 if new_Tsq==.           /**Third Rule**/
drop gap_prev sign_gap ratio2 ind Tmp_sq_prev
save "${MP_CA_data}/gravity_mp/`method'/parameters_interim_Tmp_`factor'.dta", replace
*/

local adjfactor=0.01
gen sign_gap=1
replace sign_gap=-1 if gap<0
gen gap2=gap*`adjfactor'
gen gap3=Tmp_sq*`adjfactor'*sign_gap

gen a1=abs(gap2)
gen a2=abs(gap3)
egen gap_min=rowmin(a1 a2)
replace gap_min=gap_min*sign_gap
drop a1 a2 gap2 gap3 
gen ratio=abs(gap)/Tmp_sq

gen ind=0
replace ind=1 if (gap<0 & gap_prev>=0) | (gap>0 & gap_prev<=0) /*Just passed the zero line (from one side to the next, regardless of the side) */


*UPDATE: (Notice to not update when the gap is too small relative to the size of the productivity parameter) 
*------------------------------------------
gen new_Tsq=.
replace new_Tsq=Tmp_sq if ratio<0.05                /**First Rule**/
replace new_Tsq=Tmp_sq_prev if new_Tsq==. & ind==1  /**Second Rule**/
replace new_Tsq=Tmp_sq+gap_min if new_Tsq==.        /**Third Rule**/
drop ratio sign_gap
save "${MP_CA_data}/gravity_mp/`method'/parameters_interim_Tmp_`factor'.dta", replace




*============================================================================
*Step 7: Reshape (to prepare the system of equation) and calculate a new set of T's
*============================================================================
use "${MP_CA_data}/gravity_mp/`method'/parameters_interim_`method'_equation_gs_`factor'.dta", clear
gen a="_"
egen ind=concat(sector_mp a isiccodereporter)

keep sector_mp g ind isiccodepartner
reshape wide g, i(ind) j(isiccodepartner) 
split ind , p(_)
rename ind3 isiccodereporter
replace isiccodereporter=ind2 if isiccodereporter==""
drop ind1 ind2
drop ind

destring isiccodereporter, replace
order sector_mp isiccodereporter
sort sector_mp isiccodereporter

merge 1:1 isiccodereporter sector_mp using "${MP_CA_data}/gravity_mp/`method'/parameters_interim_Tmp_`factor'.dta", keepusing(Tmp_sq T_trade_reg gap gap_min new_Tsq)
drop _merge
sort sector_mp isiccodereporter
format %9.2fc new_Tsq
save "${MP_CA_data}/gravity_mp/`method'/parameters_interim_`method'_equation_gs2_`factor'.dta", replace


*Now, calculate the regression and save the betas; then use it to run the bilateral MP regression again. 
*-----------------------------------------------------------------
local sector2 S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 
disp "`sector2'"
local num_countries=32

foreach s of local sector2 {
clear all
use "${MP_CA_data}/gravity_mp/`method'/parameters_interim_`method'_equation_gs2_`factor'.dta", clear
display "`s'"
reg new_Tsq g1-g826 if sector_mp=="`s'", noconstant robust

*Saving the coefficients
*----------------------------------------------
matrix b = e(b)
svmat b
keep b1-b`num_countries'
keep if b1!=.
gen A=1
reshape long b, i(A) j(coef)
drop A
gen sector_mp="`s'"
save "${MP_CA_data}/gravity_mp/`method'/parameters_gT_`s'_`factor'.dta", replace
}
*

*Append across sectors 
*-------------------------------------------------------
clear all
set obs 1
foreach s of local sector2 {
append using "${MP_CA_data}/gravity_mp/`method'/parameters_gT_`s'_`factor'.dta"
}
drop if coef==.
rename b T_mp_ori


*Merging the country codes with the coef using "gravity_trade/country_coef_codes.dta"
*--------------------------------------------------------
merge m:1 coef using "${MP_CA_data}/countrycode_match_gravity_coef.dta", keepusing(isiccodereporter) update
drop if _merge==2 
drop _merge

merge 1:1 sector_mp isiccodereporter using  "${MP_CA_data}/gravity_mp/`method'/parameters_interim_`method'_equation_gs2_`factor'.dta", keepusing(new_Tsq gap)
keep if _merge==3
drop _merge
rename T_mp_ori T_beta
rename new_Tsq Tmp_sq
gen isiccodepartner=isiccodereporter
save "${MP_CA_data}/gravity_mp/`method'/parameters_gT_interim_`type'_`factor'_last.dta", replace



********************************************************************
*For storage only (T's):
*--------------------------------------------------------------------------
clear all
use "${MP_CA_data}/gravity_mp/`method'/parameters_gT_master_`type'_`factor'.dta", clear
merge 1:1 sector_mp isiccodereporter using "${MP_CA_data}/gravity_mp/`method'/parameters_gT_interim_`type'_`factor'_last.dta", keepusing(T_beta Tmp_sq gap)
drop _merge
foreach var in T_beta Tmp_sq gap {
display "`var'"
rename `var' `var'_`num'
}
save, replace
********************************************************************



