*******************************************************************************
*University of Michigan
*Department of Economics
*Vanessa Alviarez
*Comparative Advantage
*Last Update: August 2017 AER
*******************************************************************************

*==============================================================================
*MODULE 1: Gravity MP
*TITLE: Gravity Equation (9 sectors/0307. Restricted country sample)
*DESCRIPTION: Performs the gravity equation in order to estimate the desired parameters (at 9 sectors and in a restricted sample. More importantly, it does calculations from the beginning).  
*Complete procedure: preparing the data set for gravity. Gravity equation. Parameters 
*==============================================================================

*------------------------------------------------------------------
*First create a dataset form
*------------------------------------------------------------------
clear all
set more off 
cd "K:\Dropbox\Dropbox (UBC-Umich)\MNC_CA_AER"
do "MP_CA_directory.do"
cd "${MP_CA_outcome}"

*Method reg means that the T's were originally calculated under this method
local method reg 
local theta=6
use "mp/mp_trade_origin_location_sectors_mp.dta", clear

drop if sector_mp=="S_NT"
local num_countries=32
drop exp1-imp`num_countries'
tabulate isiccodereporter, gen(imp)
tabulate isiccodepartner, gen(exp)

display "`num'"
local method reg
local theta=6
display "`method'"
local type m
display "`type'"


keep depvar1_reg depvar1_poisson origin location sector_mp isiccodereporter isiccodepartner exp1-exp`num_countries' ln_dist contig colony comlang_off RTA

merge m:1 isiccodereporter sector_mp using "gravity_mp/`method'/parameters_gT_interim_`type'.dta", keepusing(T_beta) 
drop _merge
rename T_beta T_beta_location
replace T_beta_location=ln(T_beta_location)

merge m:1 isiccodepartner sector_mp using "gravity_mp/`method'/parameters_gT_interim_`type'.dta", keepusing(T_beta) 
drop _merge
rename T_beta T_beta_origin
replace T_beta_origin=ln(T_beta_origin)
save "gravity_mp/`method'/database_interim.dta", replace


*-------------------------------------------------------------------
local sector2 S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 
disp "`sector2'"
local theta=6
local num_countries=32

foreach s of local sector2 {

display _newline(2) "Regression sector_`s'"
clear all
use "gravity_mp/`method'/database_interim.dta" if sector_mp=="`s'", clear

constraint 1 T_beta_origin=1
constraint 2 T_beta_location=-1

*Running the poisson regressions
*----------------------------------------------
cnsreg depvar1_reg T_beta_origin T_beta_location exp2-exp`num_countries' ln_dist contig colony comlang_off RTA, vce(robust) constraint(1 2) 
predict xb_`method', xb
gen resid_`method'_ln=depvar1_reg-xb_`method'

keep resid_`method'_ln sector_mp isiccodereporter isiccodepartner  
save "gravity_mp/`method'\resid_interim_`method'_`s'.dta", replace


*----------------------------------------------
*Saving the coefficients for gravity variables 
*----------------------------------------------
matrix b = e(b)
svmat b
local last=`num_countries'-1+2+6
keep b1-b`last'
keep if b1!=.
gen A=1
reshape long b, i(A) j(coef)
drop A
gen sector="`s'"

preserve 
keep if coef>=3 & coef<=`num_countries'-1+2
save "gravity_mp/`method'/xfe_interim_`method'_`s'.dta", replace

restore
keep if coef>=`num_countries'-1+2+1
save "gravity_mp/`method'/barriers_interim_`method'_`s'.dta", replace
clear all
}
*
*--------------------------------------------------------------------------
clear all
set more off 
cd "K:\Dropbox\Dropbox (UBC-Umich)\MNC_CA_AER"
do "MP_CA_directory.do"
cd "${MP_CA_outcome}"

local sector2 S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 
disp "`sector2'"

foreach val in resid xfe barriers {
clear all
set obs 1
gen x=.	
   
 foreach s of local sector2 {
 append using "gravity_mp/`method'/`val'_interim_`method'_`s'.dta"
 erase "gravity_mp/`method'/`val'_interim_`method'_`s'.dta"
 compress 
   }
drop if _n==1
drop x
save "gravity_mp/`method'/`val'_interim_`method'.dta", replace
}
*
 
    
*============================================================================
*Step 5: MP_barriers
*============================================================================
clear all
set more off 
cd "K:\Dropbox\Dropbox (UBC-Umich)\MNC_CA_AER"
do "MP_CA_directory.do"
cd "${MP_CA_outcome}"


local sector2 S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 
disp "`sector2'"

clear all 
use "gravity_mp/`method'/barriers_interim_`method'.dta", clear
reshape wide b, i(sector) j(coef) 
local num_countries=32


*Renaming the coefficients (ln_dist contig colony comlang_off RTA)
*-----------------------------------------------
local last=`num_countries'-1+2+1
rename b`last' beta_dist
local last=`last'+1
rename b`last' border
local last=`last'+1
rename b`last' colony
local last=`last'+1
rename b`last' language
local last=`last'+1
rename b`last' rta
local last=`last'+1
rename b`last' cte

foreach var in beta_dist border colony language rta cte {
gen `var'_theta=`var'/(-`theta')
}
*
drop beta_dist  border colony language rta cte
save "gravity_mp/`method'/barriers_interim_`method'_theta.dta", replace


*============================================================================
*Step 6: Importer and Exporter Fixed Effect
*============================================================================  
clear all
set more off 
cd "K:\Dropbox\Dropbox (UBC-Umich)\MNC_CA_AER"
do "MP_CA_directory.do"
cd "${MP_CA_outcome}"

local sector2 S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 
disp "`sector2'"

use "gravity_mp/`method'/xfe_interim_`method'.dta", clear
replace coef=coef-1
rename b xfe


*Adding USA (brutal force)
*-------------------------------------------------------
foreach var in S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37  {
local new = _N + 1
set obs `new' 
replace coef=1 if coef==.
replace sector="`var'" if sector==""
replace xfe=0 if xfe==. & coef==1
}
sort sector coef

*************************************************************************
*---------------------------------------------------------   
*Calculating the export barriers term (to calculate trade barriers later) 
*Note it is always calculated the same way, the issue is to wich side of the trasanction we do attribute this additional cost 
*---------------------------------------------------------
by sector, sort: egen a=median(xfe)
replace xfe=a if xfe==0 & coef!=1
drop a
gen exp_barr_theta=-(1/`theta')*(xfe)


*Merging the country codes with the coef using "gravity_trade/country_coef_codes.dta"
*--------------------------------------------------------
merge m:1 coef using "input/countrycode_match_gravity_coef.dta", keepusing(isiccodereporter) update
drop if _merge==2 
drop _merge
gen isiccodepartner=isiccodereporter

save "gravity_mp/`method'/parameters_interim_`method'_xfe.dta", replace


*============================================================================
****ERROR TERM***** (now we can count, we have the exporter and importer fixed effect 
*============================================================================
*We have to construct or d's vector 

use location origin isiccodereporter isiccodepartner sector_mp ln_dist contig colony comlang_off RTA depvar1_mp using "mp/mp_trade_origin_location_sectors_mp.dta", clear

*Include the error termn*
*-------------------------------------
merge 1:1 isiccodereporter isiccodepartner sector_mp using "gravity_mp/`method'/resid_interim_`method'.dta"
keep if _merge==3
drop _merge

*Include the betas for the "distance" variables (with each theta respectively)
*-------------------------------------
gen sector=sector_mp
merge m:1 sector using "gravity_mp/`method'/barriers_interim_`method'_theta.dta", keepusing(beta_dist_theta border_theta colony_theta language_theta rta_theta cte_theta)
keep if _merge==3
drop _merge


*----------------------------------------------------------------------
*Include the exporter and importer barriers* (but we call it always EXPORT BARRIERS)
*----------------------------------------------------------------------

*It is S, but we matched it with the partner! (good) Why? (becasue that is where we need it to be for the construction of the adjustment factor)
merge m:1 isiccodepartner sector using "gravity_mp/`method'/parameters_interim_`method'_xfe.dta", keepusing(exp_barr_theta)
drop if _merge==2
drop _merge

foreach var in exp_barr_theta {
rename `var' `var'_partner
}
*
foreach y in partner {
replace exp_barr_theta_`y'=0 if isiccode`y'==1 & exp_barr_theta_`y'==.
}
*

*Calculating the dij matrix* (D_`method'_`s'_partner is the trade barriers calculated with exporter effect and D_`method'_`s'_reporter is the trade barrirer calculated with importer effect) 
*-------------------------------------
gen resid_`method'_ln_theta=resid_`method'_ln/(-`theta')

foreach var in partner  {
gen D_`method'_theta_`var'=cte_theta + beta_dist_theta*ln_dist + border_theta*contig + colony_theta*colony+ language_theta*comlang_off + rta_theta*RTA + exp_barr_theta_`var' + resid_`method'_ln_theta
replace D_`method'_theta_`var'=exp(D_`method'_theta_`var')
sum D_`method'_theta_`var', d
*New
*-------------------
replace D_`method'_theta_`var'=0 if depvar1_mp==0
replace D_`method'_theta_`var'=1.40 if D_`method'_theta_`var'<1.40 & depvar1_mp!=0
}
save "gravity_mp/`method'/parameters_interim_`method'_transition.dta", replace

***Notice, we are calling it always D_partner****

*ONLY BARRERAS to MP*
*--------------------------------------------------------------------
clear all
use "gravity_mp/`method'/parameters_interim_`method'_transition.dta", clear
keep origin location isiccodereporter isiccodepartner sector_mp D_`method'_theta_partner 
/*
foreach var in D_`method'_theta_partner {
gen `var'_ind=`var'
replace `var'_ind=. if `var'_ind<1
by sector_mp isiccodepartner, sort: egen a=mean(`var'_ind) 
replace `var'=a if `var'<1
drop a `var'_ind

*New matrix
*----------------------
replace `var'=1.40 if `var'<1.40
}
*
*/
save "gravity_mp/`method'/parameters_interim_`method'_dmatrix.dta", replace


 
*--------------------------------------------------------------------------------
*********************************************************************************
*--------------------------------------------------------------------------------


*-------------------------------------------------------------------------------
*Calculate the T_sq now before arranging the g's
*-------------------------------------------------------------------------------
clear all
local method reg 
local theta=6
use  "gravity_mp/`method'/parameters_interim_`method'_dmatrix.dta", clear

fillin isiccodepartner isiccodereporter sector
drop _fillin
foreach var in D_`method'_theta_partner  {
replace `var'=1 if isiccodepartner==isiccodereporter
}
* 
foreach var in D_`method'_theta_partner  {
replace `var'=1000 if `var'==.
replace `var'=1000 if `var'==0
}
* 
by isiccodepartner, sort: egen a=mode(origin)
replace origin=a if origin==""
drop a
by isiccodereporter, sort: egen a=mode(location)
replace location=a if location==""
drop a

sort sector_mp isiccodereporter isiccodepartner
keep origin location sector_mp isiccodereporter isiccodepartner D_`method'_theta_partner

rename D_`method'_theta_partner g
replace g=g^(-`theta')
save "gravity_mp/`method'/parameters_interim_`method'_equation_gs.dta", replace



*NOW Bring the last set the T_betas (indeed the ones used to calculate the regression) 
*---------------------------------------
merge m:1 sector_mp isiccodepartner using "gravity_mp/`method'/parameters_gT_interim_`type'.dta", keepusing(T_beta)
drop if _merge==2
drop _merge
sort sector_mp isiccodereporter
format %9.2fc T_beta

gen a=g*T_beta
by isiccodereporter sector_mp, sort: egen Tmp_sq=total(a)
drop a

by isiccodereporter sector_mp, sort: gen a=_n==1
keep if a==1
drop a
drop origin isiccodepartner
drop T_beta
drop g


*Now bring the teachnology of TRADE to each importer 
*----------------------------------------------------
merge m:1 sector_mp isiccodereporter using "gravity_mp/`method'/parameters_gT_interim_`type'.dta", keepusing(T_beta T_trade_reg)
keep if _merge==3
drop _merge
format %9.1fc Tmp_sq T_beta T_trade_reg 
order location sector_mp isiccodereporter T_beta Tmp_sq T_trade_reg



*CALCULATE THE GAP IN LEVELS 
*-----------------------------------------
merge 1:1 sector_mp isiccodereporter using "gravity_mp/`method'/parameters_gT_interim_`type'.dta", keepusing(gap Tmp_sq_m)
drop if _merge==2
drop _merge
rename gap gap_prev
rename Tmp_sq_m Tmp_sq_prev
gen gap=T_trade_reg-Tmp_sq


*Notice: The gap for m is 0.01 and x is 0.005
*-------------------------------------------------------
gen gap2=gap*0.01
gen ratio=1*Tmp_sq
gen gap_abs=abs(gap)
gen gap2_abs=abs(gap2)
gen ratio2=gap_abs/Tmp_sq
gen sign_gap=1
replace sign_gap=-1 if gap2<0

gen ind=0
replace ind=1 if (gap<0 & gap_prev>0) | (gap>0 & gap_prev<0)
*Just passed the zero line (from one side to the next, regardless of the side) 


*------------------------------------------
*RULES: 
*------------------------------------------
gen new_Tsq=.
*First Rule
replace new_Tsq=Tmp_sq if ratio2<0.1
*Second Rule
replace new_Tsq=Tmp_sq_prev if new_Tsq==. & ind==1
*Third Rule
gen gap3=gap2
replace gap3=ratio*(sign_gap) if gap2_abs>ratio
replace new_Tsq=Tmp_sq+gap3 if new_Tsq==. 

/*
*-----------------------------------------
gen new_Tsq=Tmp_sq if ratio2<0.1 
*gen new_Tsq=Tmp_sqprevio que no existe if  ind==1


*gap2_abs<=ratio (means that the DELTA is lower than the size of the T_mp itself
*gap2_abs>ratio (this is if adding the gap will imply an increase of more thn 100 percent in T_mp, 
*then we impose the same T_mp + a fix percent of itself = now is 100 percent of itself)

replace new_Tsq=Tmp_sq+gap2 if gap2_abs<=ratio & ratio2>0.1 & ind==0
replace new_Tsq=Tmp_sq+(ratio*(sign_gap)) if gap2_abs>ratio & ratio2>0.1 & ind==0
*For small new_Tsq (Hungry)
*replace new_Tsq=Tmp_sq*1.20 if T_beta<100 | (isiccodereporter==348 & sector=="S29_33")
*replace new_Tsq=Tmp_sq*1.20 if (isiccodereporter==348 & sector=="S29_33") 
*-----------------------------------------
*/
drop sign_gap ratio2 ratio gap_abs ind gap_prev gap3 Tmp_sq_prev
save "gravity_mp/`method'/parameters_interim_Tmp.dta", replace


*---------------------------------------------------------
*Reshape (to prepare the system of equation) 
*---------------------------------------------------------
use "gravity_mp/`method'/parameters_interim_`method'_equation_gs.dta", clear
gen a="_"
egen ind=concat(sector_mp a isiccodereporter)

keep sector_mp g ind isiccodepartner
reshape wide g, i(ind) j(isiccodepartner) 
split ind , p(_)
rename ind3 isiccodereporter
replace isiccodereporter=ind2 if isiccodereporter==""
drop ind1 ind2
drop ind

destring isiccodereporter, replace
order sector_mp isiccodereporter
sort sector_mp isiccodereporter

merge 1:1 isiccodereporter sector_mp using "gravity_mp/`method'/parameters_interim_Tmp.dta", keepusing(Tmp_sq T_trade_reg gap gap2 new_Tsq)
drop _merge
sort sector_mp isiccodereporter
format %9.2fc new_Tsq
save "gravity_mp/`method'/parameters_interim_`method'_equation_gs2.dta", replace


*-----------------------------------------------------------------
*Now, I have to calculate the regression save the betas 
*Then I will use it to run the bilateral MP regression again. 
*-----------------------------------------------------------------
local sector2 S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 
disp "`sector2'"
local num_countries=32

foreach s of local sector2 {
clear all
use "gravity_mp/`method'/parameters_interim_`method'_equation_gs2.dta", clear
display "`s'"
reg new_Tsq g1-g826 if sector_mp=="`s'", noconstant robust

*Saving the coefficients
*----------------------------------------------
matrix b = e(b)
svmat b
keep b1-b`num_countries'
keep if b1!=.
gen A=1
reshape long b, i(A) j(coef)
drop A
gen sector_mp="`s'"
save "gravity_mp/`method'/parameters_gT_`s'.dta", replace
}
*

*Append across sectors 
*-------------------------------------------------------
clear all
set obs 1
foreach s of local sector2 {
append using "gravity_mp/`method'/parameters_gT_`s'.dta"
}
drop if coef==.
rename b T_mp_ori


*Merging the country codes with the coef using "gravity_trade/country_coef_codes.dta"
*--------------------------------------------------------
merge m:1 coef using "input/countrycode_match_gravity_coef.dta", keepusing(isiccodereporter) update
drop if _merge==2 
drop _merge

merge 1:1 sector_mp isiccodereporter using  "gravity_mp/`method'/parameters_interim_`method'_equation_gs2.dta"
keep if _merge==3
drop _merge
rename T_mp_ori T_beta

******HUNGARY******
*merge 1:1 sector_mp isiccodereporter using "gravity_mp/`method'/parameters_gT_master.dta", keepusing(T_beta_1)
*replace T_beta=T_beta_1 if isiccodereporter==348 & sector_mp=="S29_33"
rename Tmp_sq Tmp_sq_m
gen isiccodepartner=isiccodereporter
save "gravity_mp/`method'/parameters_gT_interim_`type'.dta", replace



