*************************************************************************
*University of British Columbia
*Sauder School of Business  
*Vanessa Alviarez
*Multinationals and Comparative Advantage
*Journal of International Economics
*************************************************************************


*=====================================================================
*Construct the dataset for the regressions and figures in the paper
*=====================================================================


*Bring alternative measures of productivity
*--------------------------------------------------------------------
clear all
use "${MP_CA_data}/mp_dataset_ori_loc_sec.dta", clear
keep location sector_mp isiccodereporter
replace isiccodereporter=1 if location=="USA"
duplicates drop 
tempfile temp0
save `temp0', replace

use "${MP_CA_data}/mp_dataset_ori_loc_sec.dta", clear
keep origin sector_mp isiccodepartner
replace isiccodepartner=1 if origin=="USA"
rename origin location 
rename isiccodepartner isiccodereporter
duplicates drop 
tempfile temp1
save `temp1', replace

append using `temp0'
duplicates drop 
gen origin=location 
gen isiccodepartner=isiccodereporter
order location origin isiccodereporter isiccodepartner sector_mp

*Reveal Comparative Advantage RCA in 2010 (PARTNER/REPORTER)
local list0 TFP_costinot TFP_GGDC_priceindex rca_prod_rel
merge 1:1 isiccodepartner sector_mp using  "${MP_CA_data}/Costinot_RTA_TFP.dta", keepusing(`list0')
drop if _merge==2
drop _merge

*Bring the GGDC productivity dataset (PARTNER/REPORTER)
local list0 tfp_max
replace isiccodepartner=840 if isiccodepartner==1
merge m:1 isiccodepartner sector_mp using "${MP_CA_data}/GGDC_TFP_multifactor_sectorbase_1.dta", keepusing(`list0')
drop if _merge==2
drop _merge
replace isiccodepartner=1 if isiccodepartner==840


*Bring the T from trade (PARTNER/REPORTER)
local method poisson
display "`method'"
local list0 T_rel_theta_2 T_rel_theta_3 
*merge m:1  isiccodepartner sector_mp using "${MP_CA_data}/`method'/parameters_sector9_`method'_1_Tsq.dta", keepusing(`list0')
merge m:1  isiccodepartner sector_mp using "${MP_CA_data}/gravity_trade/`method'/parameters_sector9_`method'_1_Tsq_withcapital.dta", keepusing(`list0')
drop if _merge==2
drop _merge

*Rename the variables 
rename rca_prod_rel tfp_rca
rename TFP_costinot tfp_costinot
rename TFP_GGDC_priceindex tfp_ggdcp
rename tfp_max tfp_ggdc
rename T_rel_theta_2 tfp_trade_theta2
rename T_rel_theta_3 tfp_trade_theta3


*Bring adjusted factor and calculated adjusted productivities (the one in LZ and the one from Costinot) 
*----------------------------------------------------------
local method reg
display "`method'"
merge m:1 sector_mp isiccodereporter using "${MP_CA_data}/gravity_trade/`method'/TFP_adjustfactor_LZ.dta", keepusing(adjust_LZ)
drop if _merge==2
drop _merge

merge m:1 sector_mp isiccodereporter using "${MP_CA_data}/gravity_trade/`method'/TFP_adjustfactor_costinot.dta", keepusing(adjust_costinot)
drop if _merge==2
drop _merge


*Note: maybe we can get to the master file the productivities already arranged (I am not sure here what will be best) 
*-------------------------------------------------------
label var location "Declaring country"
label var origin "Investing country"
label var isiccodereporter "isocode location country"
label var isiccodepartner "isocode origin country"
label var sector_mp "sector"
label var tfp_ggdcp "GGDC (inverse of producers prices)"
label var tfp_costinot "TFP (Costinot et al, 2011)"
label var tfp_rca "TFP measured by Revealead Comparative Advantage"  
label var tfp_ggdc "TFP GGDC database" 
label var tfp_trade_theta2 "Gravity based productivity, theta=6" 
label var tfp_trade_theta3 "Gravity based productivity, sectoral theta (from Caliendo and Parro, 2015)"  
label var adjust_LZ  "Adjustment_Levchenko and Zhang, 2016" 
label var adjust_costinot "Adjustment_Costinot et al, 2011" 

compress
save "${MP_CA_data}/productivity_dataset_complete.dta", replace
*-------------------------------------------------------


*=====================================================================
*Taxes and labor-capital ratio variables
*=====================================================================
clear all
use "${MP_CA_data}/productivity_dataset_complete.dta", clear
keep location origin isiccodereporter isiccodepartner sector_mp
duplicates drop 


*Bring the tax data (Prof. DAMODARAN)
*--------------------------------------------------------------------
merge 1:1 sector_mp location using "${MP_CA_data}/tax_rates_damodaran_sector.dta", keepusing(tax_effect_weight)
drop if _merge==2
drop _merge
rename tax_effect_weight tax_weighted


*Labor capital intensity and abundance
*------------------------------------------------------------------------
merge m:1 isiccodepartner using "${MP_CA_data}/labor_capital_decade.dta", keepusing(labor_rel capital_rel L K)
drop if _merge==2 
drop _merge


*H-O forces. Factor intensities and adjusted capital to labor ratio (LK_sector_int)
*-----------------------------
merge m:1 sector_mp using "${MP_CA_data}/NBER data factor intensities_average_weights.dta"
drop if _merge==2
drop _merge

gen ln_KL=ln(K/L)
gen LK_sector_int=ln_KL*int_KL_weights
gen LK_sector_int2=ln((K/L)*int_KL_weights) 

*-------------------------------------------------------
label var location "Declaring country"
label var origin "Investing country"
label var isiccodereporter "isocode location country"
label var isiccodepartner "isocode origin country"
label var sector_mp "sector"
label var tax_weighted "tax rates sector-country (Prof. Damodaran)"
label var L "Labor endowment"
label var K "Capital endowment"
label var labor_rel "Labor, relative to US"
label var capital_rel "Capital, relative to US" 
label var int_KL_weights "Kj/Lj, from NBER data factor intensities" 
label var ln_KL "Kn/Ln, log capital labor"
label var LK_sector_int "Factor endowments x factor intensities: ln(Kn/Ln) x (Kj/Lj)"
label var LK_sector_int2 "Factor endowments x factor intensities: ln[Kn/Ln) x (Kj/Lj)]"

compress
save "${MP_CA_data}/taxes_lk_dataset_complete.dta", replace
*-------------------------------------------------------



*=====================================================================
*Bilateral variables (also taxes and labor-capital ratio) 
*=====================================================================
clear all
use "${MP_CA_data}/mp_dataset_ori_loc_sec.dta", clear
keep location origin isiccodereporter isiccodepartner sector_mp
duplicates drop 


*Let's bring bilateral variables
*------------------------------------------------------------------------
merge m:m origin location using "${MP_CA_data}/gravity_trade_dataset_1.dta", keepusing(ln_distance dist CU RTA religion comlang_off contig comcol colony) update
drop if _merge==2
drop _merge

by origin location sector_mp, sort: gen a=_n==1
tab a
drop a

merge 1:1 origin location sector_mp using "${MP_CA_data}/gravity_trade_dataset_1.dta", keepusing(tariff_avg) update
drop if _merge==2
drop _merge


*-------------------------------------------------------
label var location "Declaring country"
label var origin "Investing country"
label var isiccodereporter "isocode location country"
label var isiccodepartner "isocode origin country"
label var sector_mp "sector"


label var comlang_off "common language dummy"
label var colony "former colony dummy"
label var contig "border dummy"
label var tariff_avg "average effective tariff"
label var religion "common religion dummy"
label var RTA "regional trade agreement dummy"
label var CU "common currency dummy"
label var ln_distance "log of distance"


compress
save "${MP_CA_data}/bilateral_dataset_complete.dta", replace
*-------------------------------------------------------










*===============================================================================
*Exporting some variable to Matlab  (Fit of the model) 
*===============================================================================
clear all
use  "${MP_CA_data}/mp_dataset_ori_loc_sec.dta", clear


*Inward MP as a fraction of Output (Manuf)
preserve
keep location origin isiccodereporter isiccodepartner sector_mp mp_sales_ols sales_ls
drop if sector_mp=="S_NT"
duplicates drop 
collapse (sum) mp_sales_l=mp_sales_ols, by(location isiccodereporter) 
replace isiccodereporter=1 if isiccodereporter==840
sort isiccodereporter
rename mp_sales_l mp_sales_l_manuf
save "${MP_CA_data}/temp0.dta", replace
restore


*Inward MP as a fraction of Output (All sectors)
preserve
keep location origin isiccodereporter isiccodepartner sector_mp mp_sales_ols 
duplicates drop 
collapse (sum) mp_sales_l=mp_sales_ols, by(location isiccodereporter) 
replace isiccodereporter=1 if isiccodereporter==840
sort isiccodereporter
save "${MP_CA_data}/temp1.dta", replace
restore


*Outward MP as a fraction of Output  (Manuf)
preserve
keep location origin isiccodereporter isiccodepartner sector_mp mp_sales_ols 
drop if sector_mp=="S_NT"
duplicates drop 
collapse (sum) mp_sales_o=mp_sales_ols, by(origin isiccodepartner) 
replace isiccodepartner=1 if isiccodepartner==840
sort isiccodepartner
rename isiccodepartner isiccodereporter
rename mp_sales_o mp_sales_o_manuf
save "${MP_CA_data}/temp2.dta", replace
restore


*Outward MP as a fraction of Output  (All sec)
preserve
keep location origin isiccodereporter isiccodepartner sector_mp mp_sales_ols 
duplicates drop 
collapse (sum) mp_sales_o=mp_sales_ols, by(origin isiccodepartner) 
replace isiccodepartner=1 if isiccodepartner==840
sort isiccodepartner
rename isiccodepartner isiccodereporter
save "${MP_CA_data}/temp3.dta", replace
restore


*Manufactured Imports relative to output
preserve
keep location isiccodereporter sector_mp imports_ls 
drop if sector_mp=="S_NT"
by sector_mp isiccodereporter, sort: gen a=_n==1
keep if a==1
drop a
collapse (sum) imports_l=imports_ls, by(location isiccodereporter) 
replace isiccodereporter=1 if isiccodereporter==840
sort isiccodereporter
save "${MP_CA_data}/temp4.dta", replace
restore

*Total Output (manuf)
preserve
keep location isiccodereporter sector_mp sales_ls 
drop if sector_mp=="S_NT"
by sector_mp isiccodereporter, sort: gen a=_n==1
keep if a==1
drop a
collapse (sum) sales_l=sales_ls, by(location isiccodereporter) 
replace isiccodereporter=1 if isiccodereporter==840
sort isiccodereporter
rename sales_l sales_l_manuf
save "${MP_CA_data}/temp5.dta", replace
restore

*Total Output (All economy)
preserve
keep location isiccodereporter sector_mp sales_ls
by sector_mp isiccodereporter, sort: gen a=_n==1
keep if a==1
drop a
collapse (sum) sales_l=sales_ls, by(location isiccodereporter) 
replace isiccodereporter=1 if isiccodereporter==840
sort isiccodereporter
save "${MP_CA_data}/temp6.dta", replace
restore


*Merging the files 
use "${MP_CA_data}/temp5.dta", clear
merge 1:1 isiccodereporter using "${MP_CA_data}/temp6.dta", keepusing(sales_l) 
drop _merge
merge 1:1 isiccodereporter using "${MP_CA_data}/temp0.dta", keepusing(mp_sales_l_manuf) 
drop _merge
merge 1:1 isiccodereporter using "${MP_CA_data}/temp1.dta", keepusing(mp_sales_l) 
drop _merge
merge 1:1 isiccodereporter using "${MP_CA_data}/temp2.dta", keepusing(mp_sales_o_manuf) 
drop _merge
merge 1:1 isiccodereporter using "${MP_CA_data}/temp3.dta", keepusing(mp_sales_o) 
drop _merge
merge 1:1 isiccodereporter using "${MP_CA_data}/temp4.dta", keepusing(imports_l) 
drop _merge


*Sending this to Matlab
gen MP_share_inward_manuf=mp_sales_l_manuf/sales_l_manuf
gen MP_share_outward_manuf=mp_sales_o_manuf/sales_l_manuf
gen MP_share_inward=mp_sales_l/sales_l
gen MP_share_outward=mp_sales_o/sales_l
gen imports_loc_manuf=imports_l/sales_l_manuf
gen imports_loc=imports_l/sales_l

save "${MP_CA_data}/mp_inward_outward_share", replace
order isiccodereporter imports_loc_manuf imports_loc MP_share_inward_manuf MP_share_outward_manuf MP_share_inward  MP_share_outward 
outsheet isiccodereporter imports_loc_manuf imports_loc MP_share_inward_manuf MP_share_outward_manuf MP_share_inward  MP_share_outward  using "${MP_CA_matlab}/mp_inward_outward_share", comma nonames nolabel replace

forvalues i=1(1)6 {
erase "${MP_CA_data}/temp`i'.dta"
}
*
