*************************************************************************
*University of British Columbia
*Sauder School of Business  
*Vanessa Alviarez
*Multinationals and Comparative Advantage
*Journal of International Economics
*************************************************************************


*=======================================================================
*TITLE: Section 2 in "Mutinational Production and Comparative Advantage"
*DESCRIPTION: It reproduces Table 1, Table 2, Table A.1 (appendix), Table A.2 (appendix)
*=======================================================================
clear all
set more off 
cd "L:/Dropbox (UBC-Umich)/MNC_CA/Data and Replication Files" 
*change to users directory*/
do "MP_CA_directory.do"


*=====================================================================
*Preparing dataset for regressions
*=====================================================================
clear all
use "${MP_CA_data}/mp_dataset_ori_loc_sec.dta", clear 


*Bring bilateral variables 
*--------------------------------------------
merge m:1 sector_mp isiccodereporter isiccodepartner using "${MP_CA_data}/bilateral_dataset_complete.dta"
drop if _merge==2
drop _merge


*Bring productivity variables
*--------------------------------------------
merge m:1 sector_mp isiccodepartner using "${MP_CA_data}/productivity_dataset_complete.dta", keepusing(tfp_ggdcp tfp_trade_theta2 tfp_trade_theta3 adjust_LZ adjust_costinot)
drop if _merge==2
drop _merge

foreach var in tfp_ggdcp tfp_trade_theta2 tfp_trade_theta3 adjust_LZ adjust_costinot {
display "`var'"
rename `var' `var'_par
}
*

merge m:1 sector_mp isiccodereporter using "${MP_CA_data}/productivity_dataset_complete.dta", keepusing(tfp_ggdcp tfp_trade_theta2 tfp_trade_theta3 adjust_LZ adjust_costinot)
drop if _merge==2
drop _merge

foreach var in tfp_ggdcp tfp_trade_theta2 tfp_trade_theta3 adjust_LZ adjust_costinot {
display "`var'"
rename `var' `var'_rep
}
*

*Bring capital/labor ratios and tax variables
*--------------------------------------------
merge m:1 sector_mp isiccodepartner using "${MP_CA_data}/taxes_lk_dataset_complete.dta", keepusing(L K int_KL_weights tax_weighted) 
drop if _merge==2
drop _merge
rename tax_weighted tax

foreach var in L K int_KL_weights tax {
display "`var'"
rename `var' `var'_par
}
*
merge m:1 sector_mp isiccodereporter using "${MP_CA_data}/taxes_lk_dataset_complete.dta", keepusing(L K int_KL_weights tax_weighted) 
drop if _merge==2
drop _merge
rename tax_weighted tax

foreach var in L K int_KL_weights tax {
display "`var'"
rename `var' `var'_rep
}
*

compress
save "${MP_CA_data}/regression_dataset.dta", replace 





*=====================================================================
*Getting the variables of interest ready before running regressions
*=====================================================================
clear all
use "${MP_CA_data}/regression_dataset.dta", clear


*Let's construct DV for sales, employment and number of enterprises
*------------------------------------------------------------------------
gen TURN_rel=mp_sales_ols/sales_ls
gen EMP_rel=mp_emp_ols/sales_ls
gen NOE_rel=mp_num_firms_ols/sales_ls

gen TURN_rel2=mp_sales_ls/sales_ls
gen EMP_rel2=mp_emp_ls/sales_ls
gen NOE_rel2=mp_num_firms_ls/sales_ls

gen ln_TURN_rel=ln(TURN_rel)
gen ln_EMP_rel=ln(EMP_rel)
gen ln_NOE_rel=ln(NOE_rel)
gen ln_mp_share_sales_ols=ln(mp_share_sales_ols)

gen ln_TURN_rel2=ln(TURN_rel2)
gen ln_EMP_rel2=ln(EMP_rel2)
gen ln_NOE_rel2=ln(NOE_rel2)


*Adjusted (non gravity based) productivities (GGDC)
*------------------------------------------------------------------------
foreach var in tfp_ggdcp {
gen `var'_par_adj=`var'_par*adjust_costinot_par
gen `var'_rep_adj=`var'_rep*adjust_costinot_rep
}
*

*Transforming some variables of interest 
*---------------------------------------------------------------------
gen ln_tfp_ggdcp_rep_adj=ln(tfp_ggdcp_rep_adj)
gen ln_tfp_ggdcp_par_adj=ln(tfp_ggdcp_par_adj)
gen ln_tfp_ggdcp_ratio_adj=ln(tfp_ggdcp_rep_adj/tfp_ggdcp_par_adj)

gen ln_tfp_trade_rep=ln(tfp_trade_theta2_rep)
gen ln_tfp_trade_par=ln(tfp_trade_theta2_par)
gen ln_tfp_trade_ratio=ln(tfp_trade_theta2_rep/tfp_trade_theta2_par)

gen LK_sector_int_par=ln((K_par/L_par))*int_KL_weights_par
gen LK_sector_int_rep=ln((K_rep/L_rep))*int_KL_weights_rep


*Creating FE dummies
*---------------------------------------------------------------------
set matsize 10000
egen loc_ori=concat(location origin)
egen loc_sec=concat(location sector)
egen ori_sec=concat(origin sector)

by location sector_mp, sort: gen ind_loc=_n==1
by origin sector_mp, sort: gen ind_ori=_n==1

compress
tempfile temp0
save `temp0'


*=====================================================================
*Running the regressions (Table 1, Table A.1, etc) 
*=====================================================================

*-----------------------------------------------------------
*Table 1: Columns (1), (2) and (3)  
*-----------------------------------------------------------
use `temp0', clear
local dep_var_sale TURN_rel
local dep_var_emp EMP_rel
local dep_var_noe NOE_rel
local ind_var ln_tfp_trade_ratio
local method ppml


*SALES
qui xi: `method' `dep_var_sale' `ind_var' i.location i.origin i.sector_mp ln_dist comlang_off colony contig  RTA,  cluster (loc_ori)  
est store m1_sales, title(Sales)
estout m1_sales, keep(ln_tfp_trade_ratio) cells(b(star fmt(3)) se(par fmt(2)) t p ) legend label varlabels(_cons constant) stats(N r2, fmt(0 3) label(N R-sqr))

qui  xi: `method' `dep_var_sale' `ind_var' i.loc_ori i.sector_mp tariff_avg LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m2_sales, title(Sales)

qui  xi: `method' `dep_var_sale' `ind_var' i.loc_ori i.sector_mp tariff_avg tax_rep LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m3_sales, title(Sales)


*EMPLOYMENT 
qui  xi: `method' `dep_var_emp' `ind_var' i.location i.origin i.sector_mp ln_dist comlang_off colony contig  RTA,  cluster (loc_ori)  
est store m1_emp, title(Employment)

qui xi: `method' `dep_var_emp' `ind_var' i.loc_ori i.sector_mp tariff_avg LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m2_emp, title(Employment)

qui xi: `method' `dep_var_emp' `ind_var' i.loc_ori i.sector_mp tariff_avg tax_rep LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m3_emp, title(Employment)


*NUMBER OF FIRMS
qui  xi: `method' `dep_var_noe' `ind_var' i.location i.origin i.sector_mp ln_dist comlang_off colony contig  RTA,  cluster (loc_ori)  
est store m1_num, title(N_firms)

qui  xi: `method' `dep_var_noe' `ind_var' i.loc_ori i.sector_mp tariff_avg LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m2_num, title(N_firms)

qui  xi: `method' `dep_var_noe' `ind_var' i.loc_ori i.sector_mp tariff_avg tax_rep LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m3_num, title(N_firms)



*-----------------------------------------------------------
*Table 1: Columns (4), (5) and (6)  
*-----------------------------------------------------------
use `temp0', clear

local dep_var_sale TURN_rel
local dep_var_emp EMP_rel
local dep_var_noe NOE_rel
local ind_var ln_tfp_ggdcp_ratio_adj
local method ppml

*SALES
qui xi: `method' `dep_var_sale' `ind_var' i.location i.origin i.sector_mp ln_dist comlang_off colony contig  RTA,  cluster (loc_ori)  
est store m4_sales, title(Sales)

qui xi: `method' `dep_var_sale' `ind_var' i.loc_ori i.sector_mp tariff_avg LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m5_sales, title(Sales)

qui xi: `method' `dep_var_sale' `ind_var' i.loc_ori i.sector_mp tariff_avg tax_rep LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m6_sales, title(Sales)


*EMPLOYMENT
qui xi: `method' `dep_var_emp' `ind_var' i.location i.origin i.sector_mp ln_dist comlang_off colony contig  RTA,  cluster (loc_ori)  
est store m4_emp, title(Employment)

qui xi: `method' `dep_var_emp' `ind_var' i.loc_ori i.sector_mp tariff_avg LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m5_emp, title(Employment)
  
qui xi: `method' `dep_var_emp' `ind_var' i.loc_ori i.sector_mp tariff_avg tax_rep LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m6_emp, title(Employment)


*NUMBER OF FIRMS
qui xi: `method' `dep_var_noe' `ind_var' i.location i.origin i.sector_mp ln_dist comlang_off colony contig  RTA,  cluster (loc_ori)  
est store m4_num, title(N_firms)

qui xi: `method' `dep_var_noe' `ind_var' i.loc_ori i.sector_mp tariff_avg LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m5_num, title(N_firms)

qui xi: `method' `dep_var_noe' `ind_var' i.loc_ori i.sector_mp tariff_avg tax_rep LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m6_num, title(N_firms)



*Combining columns for Table 1: 
*-------------------------------------------------------------
estout m1_sales m2_sales m3_sales m4_sales m5_sales m6_sales, keep(ln_tfp_trade_ratio ln_tfp_ggdcp_ratio_adj) cells(b(star fmt(3)) se(par fmt(2)) t p ) starlevels( * 0.10 ** 0.05 *** 0.010) legend label varlabels(_cons constant) stats(N r2, fmt(0 3) label(N R-sqr))
estout m1_emp m2_emp m3_emp m4_emp m5_emp m6_emp, keep(ln_tfp_trade_ratio ln_tfp_ggdcp_ratio_adj) cells(b(star fmt(3)) se(par fmt(2)) t p ) starlevels( * 0.10 ** 0.05 *** 0.010) legend label varlabels(_cons constant) stats(N r2, fmt(0 3) label(N R-sqr))
estout m1_num m2_num m3_num m4_num m5_num m6_num, keep(ln_tfp_trade_ratio ln_tfp_ggdcp_ratio_adj) cells(b(star fmt(3)) se(par fmt(2)) t p ) starlevels( * 0.10 ** 0.05 *** 0.010) legend label varlabels(_cons constant) stats(N r2, fmt(0 3) label(N R-sqr))






*-----------------------------------------------------------
*Table 2 Panel (a): Columns (1)-(6)  
*-----------------------------------------------------------
use `temp0', clear

local dep_var_sale TURN_rel
*local dep_var_sale mp_share_sales_ols
local dep_var_emp EMP_rel
local dep_var_noe NOE_rel
local ind_var ln_tfp_trade_par
local method ppml


*SALES
qui xi: `method' `dep_var_sale' `ind_var' i.loc_sec  i.origin LK_sector_int_par ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m1_sales, title(Sales)

qui xi: `method' `dep_var_sale' `ind_var' i.loc_sec  i.origin tariff_avg LK_sector_int_par ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m2_sales, title(Sales)

qui xi: `method' `dep_var_sale' `ind_var' i.loc_sec  i.origin tax_par tariff_avg LK_sector_int_par ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m3_sales, title(Sales)

*EMPLOYMENT
qui xi: `method' `dep_var_emp' `ind_var' i.loc_sec  i.origin LK_sector_int_par ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m1_emp, title(Employment)

qui xi: `method' `dep_var_emp' `ind_var' i.loc_sec  i.origin tariff_avg LK_sector_int_par ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m2_emp, title(Employment)

qui xi: `method' `dep_var_emp' `ind_var' i.loc_sec  i.origin tax_par tariff_avg LK_sector_int_par ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m3_emp, title(Employment)


*NUMBER OF FIRMS
qui xi: `method' `dep_var_noe' `ind_var' i.loc_sec  i.origin LK_sector_int_par ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m1_num, title(N_firms)

qui xi: `method' `dep_var_noe' `ind_var' i.loc_sec  i.origin tariff_avg LK_sector_int_par ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m2_num, title(N_firms)

qui xi: `method' `dep_var_noe' `ind_var' i.loc_sec  i.origin tax_par tariff_avg LK_sector_int_par ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m3_num, title(N_firms)



*-----------------------------------------------------------
*Table 2 Panel (b): Columns (1)-(6)  
*-----------------------------------------------------------
use `temp0', clear

local dep_var_sale TURN_rel
local dep_var_emp EMP_rel
local dep_var_noe NOE_rel
local ind_var ln_tfp_trade_rep
local method ppml

*SALES
qui xi: `method' `dep_var_sale' `ind_var' i.ori_sec  i.location LK_sector_int_rep ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m4_sales, title(Sales)

qui xi: `method' `dep_var_sale' `ind_var' i.ori_sec  i.location tariff_avg LK_sector_int_rep ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m5_sales, title(Sales)

qui xi: `method' `dep_var_sale' `ind_var' i.ori_sec  i.location tax_rep tariff_avg LK_sector_int_rep ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m6_sales, title(Sales)


*EMPLOYMENT
qui xi: `method' `dep_var_emp' `ind_var' i.ori_sec  i.location LK_sector_int_rep ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m4_emp, title(Employment)

qui xi: `method' `dep_var_emp' `ind_var' i.ori_sec  i.location tariff_avg LK_sector_int_rep ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m5_emp, title(Employment)

qui xi: `method' `dep_var_emp' `ind_var' i.ori_sec  i.location tax_rep tariff_avg LK_sector_int_rep ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m6_emp, title(Employment)


*NUMBER OF FIRMS
qui xi: `method' `dep_var_noe' `ind_var' i.ori_sec  i.location LK_sector_int_rep ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m4_num, title(N_firms)

qui xi: `method' `dep_var_noe' `ind_var' i.ori_sec  i.location tariff_avg LK_sector_int_rep ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m5_num, title(N_firms)

qui xi: `method' `dep_var_noe' `ind_var' i.ori_sec  i.location tax_rep tariff_avg LK_sector_int_rep ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m6_num, title(N_firms)



*Combining columns for Table 2: 
*-------------------------------------------------------------
estout m1_sales m2_sales m3_sales m1_emp m2_emp m3_emp m1_num m2_num  m3_num, keep(ln_tfp_trade_par) cells(b(star fmt(3)) se(par fmt(2)) t p ) starlevels( * 0.10 ** 0.05 *** 0.010) legend label varlabels(_cons constant) stats(N r2, fmt(0 3) label(N R-sqr))
estout m4_sales m5_sales m6_sales m4_emp m5_emp m6_emp m4_num m5_num m6_num, keep(ln_tfp_trade_rep) cells(b(star fmt(3)) se(par fmt(2)) t p ) starlevels( * 0.10 ** 0.05 *** 0.010) legend label varlabels(_cons constant) stats(N r2, fmt(0 3) label(N R-sqr))






*-----------------------------------------------------------
*Figure 1 and Table A3 in the Appendix: Sectoral MP and Productivity 
*-----------------------------------------------------------
use `temp0', clear

local dep_var_sale ln_TURN_rel2
local dep_var_emp ln_EMP_rel2
local dep_var_noe ln_NOE_rel2
local ind_var ln_tfp_trade_rep
local method reg
keep if ind_loc==1


*SALES
qui xi: `method' `dep_var_sale' `ind_var' LK_sector_int_rep i.location  i.sector_mp
dfbeta `ind_var'
xi: `method' `dep_var_sale' `ind_var' LK_sector_int_rep  i.location i.sector_mp if abs(_dfbeta_1)< 2/sqrt(e(N)), vce(robust)
est table, keep(`ind_var' ) b se t p stats(N r2)
est store m1_sales, title(Sales)
drop _dfbeta_1

*Including taxes
qui xi: `method' `dep_var_sale' `ind_var' tax_rep LK_sector_int_rep i.location  i.sector_mp
dfbeta `ind_var'

qui xi: `method' `dep_var_sale' `ind_var' tax_rep LK_sector_int_rep  i.location i.sector_mp if abs(_dfbeta_1)< 2/sqrt(e(N)), vce(robust)
est table, keep(`ind_var' ) b se t p stats(N r2)
est store m2_sales, title(Sales)
avplot `ind_var', xlabel(, format(%5.0f)) ylabel(, format(%5.0f)) legend(off) graphregion(fcolor(white)) msize(medium) mcolor(blue) msymbol(circle_hollow) mlabel(location) mlabsize(vsmall) xtitle("Productivity") ytitle("Inward MP Share") 
drop _dfbeta_1
graph export "figures/negative_unilateral_sales_1.png", as(png) replace


*EMPLOYMENT 
use `temp0', clear

local dep_var_sale ln_TURN_rel2
local dep_var_emp ln_EMP_rel2
local dep_var_noe ln_NOE_rel2
local ind_var ln_tfp_trade_rep
local method reg
keep if ind_loc==1

qui xi: `method' `dep_var_emp' `ind_var' LK_sector_int_rep i.location  i.sector_mp
dfbeta `ind_var'

qui xi: `method' `dep_var_emp' `ind_var' LK_sector_int_rep  i.location i.sector_mp if abs(_dfbeta_1)< 2/sqrt(e(N)), vce(robust)
est table, keep(`ind_var' ) b se t p stats(N r2)
est store m1_emp, title(Employment)
drop _dfbeta_1

*Including taxes
qui xi: `method' `dep_var_emp' `ind_var' tax_rep LK_sector_int_rep i.location  i.sector_mp
dfbeta `ind_var'

qui xi: `method' `dep_var_emp' `ind_var' tax_rep LK_sector_int_rep  i.location i.sector_mp if abs(_dfbeta_1)< 2/sqrt(e(N)), vce(robust)
est table, keep(`ind_var' ) b se t p stats(N r2)
est store m2_emp, title(Employment)
avplot `ind_var', xlabel(, format(%5.0f)) ylabel(, format(%5.0f)) legend(off) graphregion(fcolor(white)) msize(medium) mcolor(blue) msymbol(circle_hollow) mlabel(location) mlabsize(vsmall) xtitle("Productivity") ytitle("Inward MP Share") 
drop _dfbeta_1
graph export "figures/negative_unilateral_emp_1.png", as(png) replace



*NUMBER OF FIRMS 
use `temp0', clear

local dep_var_sale ln_TURN_rel2
local dep_var_emp ln_EMP_rel2
local dep_var_noe ln_NOE_rel2
local ind_var ln_tfp_trade_rep
local method reg
keep if ind_loc==1

qui xi: `method' `dep_var_noe' `ind_var' LK_sector_int_rep i.location  i.sector_mp
dfbeta `ind_var'

qui xi: `method' `dep_var_noe' `ind_var' LK_sector_int_rep  i.location i.sector_mp if abs(_dfbeta_1)< 2/sqrt(e(N)), vce(robust)
est table, keep(`ind_var' ) b se t p stats(N r2)
est store m1_num, title(N_firms)
drop _dfbeta_1

*Including taxes
qui xi: `method' `dep_var_noe' `ind_var' tax_rep LK_sector_int_rep i.location  i.sector_mp
dfbeta `ind_var'

qui xi: `method' `dep_var_noe' `ind_var' tax_rep LK_sector_int_rep  i.location i.sector_mp if abs(_dfbeta_1)< 2/sqrt(e(N)), vce(robust)
est table, keep(`ind_var' ) b se t p stats(N r2)
est store m2_num, title(N_firms)
avplot `ind_var', xlabel(, format(%5.0f)) ylabel(, format(%5.0f)) legend(off) graphregion(fcolor(white)) msize(medium) mcolor(blue) msymbol(circle_hollow) mlabel(location) mlabsize(vsmall) xtitle("Productivity") ytitle("Inward MP Share") 
drop _dfbeta_1
graph export "figures/negative_unilateral_num_1.png", as(png) replace


*------------------------------------------
*Table In the appendix: (Motivation)
*------------------------------------------
estout m1_sales m2_sales m1_emp m2_emp m1_num m2_num, keep(ln_tfp_trade_rep) cells(b(star fmt(3)) se(par fmt(2)) t p ) starlevels( * 0.10 ** 0.05 *** 0.010) legend label varlabels(_cons constant) stats(N r2, fmt(0 3) label(N R-sqr))







*------------------------------------------------------------------------------
************                     APPENDIX                 ********************* 
*------------------------------------------------------------------------------


*-----------------------------------------------------------
*Table appendix A.1 (OLS): Columns (1), (2) and (3)  
*-----------------------------------------------------------
use `temp0', clear
local dep_var_sale ln_TURN_rel
local dep_var_emp ln_EMP_rel
local dep_var_noe ln_NOE_rel
local ind_var ln_tfp_trade_ratio
local method reg


*SALES
qui xi: `method' `dep_var_sale' `ind_var' i.location i.origin i.sector_mp ln_dist comlang_off colony contig  RTA,  cluster (loc_ori)  
est store m1_sales, title(Sales)
estout m1_sales, keep(ln_tfp_trade_ratio) cells(b(star fmt(3)) se(par fmt(2)) t p ) legend label varlabels(_cons constant) stats(N r2, fmt(0 3) label(N R-sqr))

qui  xi: `method' `dep_var_sale' `ind_var' i.loc_ori i.sector_mp tariff_avg LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m2_sales, title(Sales)

qui  xi: `method' `dep_var_sale' `ind_var' i.loc_ori i.sector_mp tariff_avg tax_rep LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m3_sales, title(Sales)


*EMPLOYMENT 
qui  xi: `method' `dep_var_emp' `ind_var' i.location i.origin i.sector_mp ln_dist comlang_off colony contig  RTA,  cluster (loc_ori)  
est store m1_emp, title(Employment)

qui xi: `method' `dep_var_emp' `ind_var' i.loc_ori i.sector_mp tariff_avg LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m2_emp, title(Employment)

qui xi: `method' `dep_var_emp' `ind_var' i.loc_ori i.sector_mp tariff_avg tax_rep LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m3_emp, title(Employment)


*NUMBER OF FIRMS
qui  xi: `method' `dep_var_noe' `ind_var' i.location i.origin i.sector_mp ln_dist comlang_off colony contig  RTA,  cluster (loc_ori)  
est store m1_num, title(N_firms)

qui  xi: `method' `dep_var_noe' `ind_var' i.loc_ori i.sector_mp tariff_avg LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m2_num, title(N_firms)

qui  xi: `method' `dep_var_noe' `ind_var' i.loc_ori i.sector_mp tariff_avg tax_rep LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m3_num, title(N_firms)



*-----------------------------------------------------------
*Table appendix A.1 (OLS): Columns (4), (5) and (6)  
*-----------------------------------------------------------
use `temp0', clear

local dep_var_sale ln_TURN_rel
local dep_var_emp ln_EMP_rel
local dep_var_noe ln_NOE_rel
local ind_var ln_tfp_ggdcp_ratio_adj
local method reg

*SALES
qui xi: `method' `dep_var_sale' `ind_var' i.location i.origin i.sector_mp ln_dist comlang_off colony contig  RTA,  cluster (loc_ori)  
est store m4_sales, title(Sales)

qui xi: `method' `dep_var_sale' `ind_var' i.loc_ori i.sector_mp tariff_avg LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m5_sales, title(Sales)

qui xi: `method' `dep_var_sale' `ind_var' i.loc_ori i.sector_mp tariff_avg tax_rep LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m6_sales, title(Sales)


*EMPLOYMENT
qui xi: `method' `dep_var_emp' `ind_var' i.location i.origin i.sector_mp ln_dist comlang_off colony contig  RTA,  cluster (loc_ori)  
est store m4_emp, title(Employment)

qui xi: `method' `dep_var_emp' `ind_var' i.loc_ori i.sector_mp tariff_avg LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m5_emp, title(Employment)
  
qui xi: `method' `dep_var_emp' `ind_var' i.loc_ori i.sector_mp tariff_avg tax_rep LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m6_emp, title(Employment)


*NUMBER OF FIRMS
qui xi: `method' `dep_var_noe' `ind_var' i.location i.origin i.sector_mp ln_dist comlang_off colony contig  RTA,  cluster (loc_ori)  
est store m4_num, title(N_firms)

qui xi: `method' `dep_var_noe' `ind_var' i.loc_ori i.sector_mp tariff_avg LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m5_num, title(N_firms)

qui xi: `method' `dep_var_noe' `ind_var' i.loc_ori i.sector_mp tariff_avg tax_rep LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m6_num, title(N_firms)



*Combining columns for Table 1 (appendix, OLS): 
*-------------------------------------------------------------
estout m1_sales m2_sales m3_sales m4_sales m5_sales m6_sales, keep(ln_tfp_trade_ratio ln_tfp_ggdcp_ratio_adj) cells(b(star fmt(3)) se(par fmt(2)) t p ) starlevels( * 0.10 ** 0.05 *** 0.010) legend label varlabels(_cons constant) stats(N r2, fmt(0 3) label(N R-sqr))
estout m1_emp m2_emp m3_emp m4_emp m5_emp m6_emp, keep(ln_tfp_trade_ratio ln_tfp_ggdcp_ratio_adj) cells(b(star fmt(3)) se(par fmt(2)) t p ) starlevels( * 0.10 ** 0.05 *** 0.010) legend label varlabels(_cons constant) stats(N r2, fmt(0 3) label(N R-sqr))
estout m1_num m2_num m3_num m4_num m5_num m6_num, keep(ln_tfp_trade_ratio ln_tfp_ggdcp_ratio_adj) cells(b(star fmt(3)) se(par fmt(2)) t p ) starlevels( * 0.10 ** 0.05 *** 0.010) legend label varlabels(_cons constant) stats(N r2, fmt(0 3) label(N R-sqr))





*=====================================================================================================
*Table A.1 Mean of the ratio
*=====================================================================================================


*Table 1 (appendix, PPML): Columns (1), (2) and (3)  
*-----------------------------------------------------------
use `temp0', clear
local dep_var_sale mp_share_sales_ols
local ind_var ln_tfp_trade_ratio
local method ppml

*SALES
qui xi: `method' `dep_var_sale' `ind_var' i.location i.origin i.sector_mp ln_dist comlang_off colony contig  RTA,  cluster (loc_ori)  
est store m1b_sales, title(Sales)

qui  xi: `method' `dep_var_sale' `ind_var' i.loc_ori i.sector_mp tariff_avg LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m2b_sales, title(Sales)

qui  xi: `method' `dep_var_sale' `ind_var' i.loc_ori i.sector_mp tariff_avg tax_rep LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m3b_sales, title(Sales)




*Table 1 (appendix, PPML): Columns (4), (5) and (6)  
*-----------------------------------------------------------
use `temp0', clear
local dep_var_sale mp_share_sales_ols
local ind_var ln_tfp_ggdcp_ratio_adj
local method ppml

*SALES
qui xi: `method' `dep_var_sale' `ind_var' i.location i.origin i.sector_mp ln_dist comlang_off colony contig  RTA,  cluster (loc_ori)  
est store m4b_sales, title(Sales)

qui xi: `method' `dep_var_sale' `ind_var' i.loc_ori i.sector_mp tariff_avg LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m5b_sales, title(Sales)

qui xi: `method' `dep_var_sale' `ind_var' i.loc_ori i.sector_mp tariff_avg tax_rep LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m6b_sales, title(Sales)



*Combining columns for Table 1 (appendix): 
*-------------------------------------------------------------
estout m1b_sales m2b_sales m3b_sales m4b_sales m5b_sales m6b_sales, keep(ln_tfp_trade_ratio ln_tfp_ggdcp_ratio_adj) cells(b(star fmt(3)) se(par fmt(2)) t p ) starlevels( * 0.10 ** 0.05 *** 0.010) legend label varlabels(_cons constant) stats(N r2, fmt(0 3) label(N R-sqr))




*Table 1 (appendix, OLS): Columns (1), (2) and (3)  
*-----------------------------------------------------------
use `temp0', clear
local dep_var_sale ln_mp_share_sales_ols
local ind_var ln_tfp_trade_ratio
local method reg

*SALES
qui xi: `method' `dep_var_sale' `ind_var' i.location i.origin i.sector_mp ln_dist comlang_off colony contig  RTA,  cluster (loc_ori)  
est store m1b_sales, title(Sales)

qui  xi: `method' `dep_var_sale' `ind_var' i.loc_ori i.sector_mp tariff_avg LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m2b_sales, title(Sales)

qui  xi: `method' `dep_var_sale' `ind_var' i.loc_ori i.sector_mp tariff_avg tax_rep LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m3b_sales, title(Sales)




*Table 1 (appendix, OLS): Columns (4), (5) and (6)  
*-----------------------------------------------------------
use `temp0', clear
local dep_var_sale ln_mp_share_sales_ols
local ind_var ln_tfp_ggdcp_ratio_adj
local method reg

*SALES
qui xi: `method' `dep_var_sale' `ind_var' i.location i.origin i.sector_mp ln_dist comlang_off colony contig  RTA,  cluster (loc_ori)  
est store m4b_sales, title(Sales)

qui xi: `method' `dep_var_sale' `ind_var' i.loc_ori i.sector_mp tariff_avg LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m5b_sales, title(Sales)

qui xi: `method' `dep_var_sale' `ind_var' i.loc_ori i.sector_mp tariff_avg tax_rep LK_sector_int_rep LK_sector_int_par,  cluster (loc_ori)  
est store m6b_sales, title(Sales)



*Combining columns for Table 1 (appendix): 
*-------------------------------------------------------------
estout m1b_sales m2b_sales m3b_sales m4b_sales m5b_sales m6b_sales, keep(ln_tfp_trade_ratio ln_tfp_ggdcp_ratio_adj) cells(b(star fmt(3)) se(par fmt(2)) t p ) starlevels( * 0.10 ** 0.05 *** 0.010) legend label varlabels(_cons constant) stats(N r2, fmt(0 3) label(N R-sqr))





*======================================================================================
*TABLE A.4 APPENDIX 
*======================================================================================


*-----------------------------------------------------------
*Table A.4 Panel (a): Columns (1)-(6)  OLS
*-----------------------------------------------------------
use `temp0', clear

local dep_var_sale ln_TURN_rel
local dep_var_emp ln_EMP_rel
local dep_var_noe ln_NOE_rel
local ind_var ln_tfp_trade_par
local method reg


*SALES
qui xi: `method' `dep_var_sale' `ind_var' i.loc_sec  i.origin LK_sector_int_par ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m1_sales, title(Sales)

qui xi: `method' `dep_var_sale' `ind_var' i.loc_sec  i.origin tariff_avg LK_sector_int_par ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m2_sales, title(Sales)

qui xi: `method' `dep_var_sale' `ind_var' i.loc_sec  i.origin tax_par tariff_avg LK_sector_int_par ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m3_sales, title(Sales)

*EMPLOYMENT
qui xi: `method' `dep_var_emp' `ind_var' i.loc_sec  i.origin LK_sector_int_par ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m1_emp, title(Employment)

qui xi: `method' `dep_var_emp' `ind_var' i.loc_sec  i.origin tariff_avg LK_sector_int_par ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m2_emp, title(Employment)

qui xi: `method' `dep_var_emp' `ind_var' i.loc_sec  i.origin tax_par tariff_avg LK_sector_int_par ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m3_emp, title(Employment)


*NUMBER OF FIRMS
qui xi: `method' `dep_var_noe' `ind_var' i.loc_sec  i.origin LK_sector_int_par ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m1_num, title(N_firms)

qui xi: `method' `dep_var_noe' `ind_var' i.loc_sec  i.origin tariff_avg LK_sector_int_par ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m2_num, title(N_firms)

qui xi: `method' `dep_var_noe' `ind_var' i.loc_sec  i.origin tax_par tariff_avg LK_sector_int_par ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m3_num, title(N_firms)




*-----------------------------------------------------------
*Table A.4 Panel (b): Columns (1)-(6)  OLS
*-----------------------------------------------------------
use `temp0', clear

local dep_var_sale ln_TURN_rel
local dep_var_emp ln_EMP_rel
local dep_var_noe ln_NOE_rel
local ind_var ln_tfp_trade_rep
local method reg

*SALES
qui xi: `method' `dep_var_sale' `ind_var' i.ori_sec  i.location LK_sector_int_rep ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m4_sales, title(Sales)

qui xi: `method' `dep_var_sale' `ind_var' i.ori_sec  i.location tariff_avg LK_sector_int_rep ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m5_sales, title(Sales)

qui xi: `method' `dep_var_sale' `ind_var' i.ori_sec  i.location tax_rep tariff_avg LK_sector_int_rep ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m6_sales, title(Sales)


*EMPLOYMENT
qui xi: `method' `dep_var_emp' `ind_var' i.ori_sec  i.location LK_sector_int_rep ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m4_emp, title(Employment)

qui xi: `method' `dep_var_emp' `ind_var' i.ori_sec  i.location tariff_avg LK_sector_int_rep ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m5_emp, title(Employment)

qui xi: `method' `dep_var_emp' `ind_var' i.ori_sec  i.location tax_rep tariff_avg LK_sector_int_rep ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m6_emp, title(Employment)


*NUMBER OF FIRMS
qui xi: `method' `dep_var_noe' `ind_var' i.ori_sec  i.location LK_sector_int_rep ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m4_num, title(N_firms)

qui xi: `method' `dep_var_noe' `ind_var' i.ori_sec  i.location tariff_avg LK_sector_int_rep ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m5_num, title(N_firms)

qui xi: `method' `dep_var_noe' `ind_var' i.ori_sec  i.location tax_rep tariff_avg LK_sector_int_rep ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m6_num, title(N_firms)



*Combining columns for Table 2: 
*-------------------------------------------------------------
estout m1_sales m2_sales m3_sales m1_emp m2_emp m3_emp m1_num m2_num  m3_num, keep(ln_tfp_trade_par) cells(b(star fmt(3)) se(par fmt(2)) t p ) starlevels( * 0.10 ** 0.05 *** 0.010) legend label varlabels(_cons constant) stats(N r2, fmt(0 3) label(N R-sqr))
estout m4_sales m5_sales m6_sales m4_emp m5_emp m6_emp m4_num m5_num m6_num, keep(ln_tfp_trade_rep) cells(b(star fmt(3)) se(par fmt(2)) t p ) starlevels( * 0.10 ** 0.05 *** 0.010) legend label varlabels(_cons constant) stats(N r2, fmt(0 3) label(N R-sqr))





*-----------------------------------------------------------
*Table 2 Panel (a): Columns (1)-(6)  (mean of the ratio) 
*-----------------------------------------------------------
use `temp0', clear

local dep_var_sale ln_mp_share_sales_ols
local ind_var ln_tfp_trade_par
local method reg


*SALES
qui xi: `method' `dep_var_sale' `ind_var' i.loc_sec  i.origin LK_sector_int_par ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m1_sales, title(Sales)

qui xi: `method' `dep_var_sale' `ind_var' i.loc_sec  i.origin tariff_avg LK_sector_int_par ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m2_sales, title(Sales)

qui xi: `method' `dep_var_sale' `ind_var' i.loc_sec  i.origin tax_par tariff_avg LK_sector_int_par ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m3_sales, title(Sales)


*-----------------------------------------------------------
*Table 2 Panel (b): Columns (1)-(6)  (mean of the ratio) 
*-----------------------------------------------------------
use `temp0', clear

local dep_var_sale ln_mp_share_sales_ols
local ind_var ln_tfp_trade_rep
local method reg

*SALES
qui xi: `method' `dep_var_sale' `ind_var' i.ori_sec  i.location LK_sector_int_rep ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m4_sales, title(Sales)

qui xi: `method' `dep_var_sale' `ind_var' i.ori_sec  i.location tariff_avg LK_sector_int_rep ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m5_sales, title(Sales)

qui xi: `method' `dep_var_sale' `ind_var' i.ori_sec  i.location tax_rep tariff_avg LK_sector_int_rep ln_dist comlang_off colony contig,  cluster (loc_ori)  
est store m6_sales, title(Sales)



*Combining columns for Table 2: 
*-------------------------------------------------------------
estout m1_sales m2_sales m3_sales m4_sales m5_sales m6_sales, keep(ln_tfp_trade_par ln_tfp_trade_rep) cells(b(star fmt(3)) se(par fmt(2)) t p ) starlevels( * 0.10 ** 0.05 *** 0.010) legend label varlabels(_cons constant) stats(N r2, fmt(0 3) label(N R-sqr))





