*************************************************************************
*University of British Columbia
*Sauder School of Business  
*Vanessa Alviarez
*Multinationals and Comparative Advantage
*Journal of International Economics
**************************************************************************



*=======================================================================
*TITLE: Section 4 in "Mutinational Production and Comparative Advantage"
*DESCRIPTION: Graphs using estimated productivities 
*=======================================================================
clear all
set more off 
cd "L:/Dropbox (UBC-Umich)/MNC_CA/Data and Replication Files" 
do "MP_CA_directory.do" /*change to users directory*/


*-------------------------------------------------------------------
*Table 1 in the paper. Relative Productivity, by Country and Industry
*-------------------------------------------------------------------
local method poisson 
local type m
local factor wc
local theta=6
use "${MP_CA_data}/gravity_mp/`method'/parameters_gT_master_`type'_`factor'_final.dta", clear
merge m:1 isiccodereporter using "${MP_CA_data}/countrycode_match_gravity_coef.dta", keepusing(location)
drop if _merge==2
drop _merge

gen Tus=T_mp_abs if isiccodereporter==1
by sector_mp, sort: egen T_US=max(Tus) 
drop Tus
gen T=(T_mp_abs/T_US)^(1/`theta')
keep sector_mp location isiccodereporter T 
reshape wide T, i(location isiccodereporter) j(sector_mp) string 

rename TS15_16 Food
rename TS17_19 Textile
rename TS20_22 Wood_Paper
rename TS23_25 Chemicals
rename TS26 Minerals
rename TS27_28 Metals
rename TS29_33 Machinery
rename TS34_35 Transport
rename TS36_37 Other_Manuf_nec
rename TS_NT Non_Tradables
sort isiccodereporter
format %9.3fc Food Textile Wood_Paper Chemicals Minerals Metals Machinery Transport Other_Manuf_nec Non_Tradables
save "${MP_CA_main}/tables/Estimated Ts_by Country_Industry_`method'_`type'_`factor'.dta", replace



*-------------------------------------------------------------------
*Figure 2 in the paper: Effective and Fundamental Productivities
*-------------------------------------------------------------------
clear all
local type m
local method poisson 
local factor wc
local theta=6
use "${MP_CA_data}/gravity_mp/`method'/parameters_gT_master_`type'_`factor'.dta", clear

keep sector_mp isiccodereporter T_beta_1001 Tmp_sq_1001

merge m:1 isiccodereporter using "${MP_CA_data}/countrycode_match_gravity_coef.dta", keepusing(location reporter) 
drop if _merge==2 
drop _merge
keep if location=="USA" | location=="GBR" |  location=="SVK" | location=="POL" | location=="EST" | location=="JPN"  | location=="FRA"

*Relative to the US
gen ref=T_beta_1001 if isiccodereporter==1
by sector_mp, sort: egen ref2=max(ref) 
drop ref

gen T_local=(T_beta_1001/ref2)^(1/`theta')
gen T_effec=(Tmp_sq_1001/ref2)^(1/`theta')

gsort location T_local
global titlesyx 

local l FRA
local l2 France
display "`l'"
preserve
keep if location=="`l'" 
egen rank=rank(T_local),  field
twoway (connected T_local rank, msize(medium) lcolor(red) mcolor(red) msymbol(circle_hollow)) (connected T_effec rank, connect(ascending) sort(rank)  msize(medium) lcolor(blue) mcolor(blue)  msymbol(square_hollow)), $titlesyx legend(label(1 "T Fundamental") label(2 "T Effective") size(vsmall) nobox) title("`l2'", size(Medium)) xlabel(1(1)9) yscale(range(0.8 1.3)) xtitle("")  ylabel(.8(.10)1.3)  scale(*1) graphregion(color(white)) name(`l', replace)
restore

local l GBR
local l2 United Kingdom
display "`l'"
preserve
keep if location=="`l'" 
egen rank=rank(T_local),  field
twoway (connected T_local rank, msize(medium) lcolor(red) mcolor(red) msymbol(circle_hollow)) (connected T_effec rank, connect(ascending) sort(rank)  msize(medium) lcolor(blue) mcolor(blue)  msymbol(square_hollow)), $titlesyx title("`l2'", size(Medium)) xlabel(1(1)9) yscale(range(0.8 1.3)) xtitle("") ylabel(.8(.10)1.3) legend(off) scale(*1) graphregion(color(white)) name(`l', replace)
restore

local l SVK
local l2 Slovakia
display "`l'"
preserve
keep if location=="`l'" 
egen rank=rank(T_local),  field
twoway (connected T_local rank, msize(medium) lcolor(red) mcolor(red) msymbol(circle_hollow)) (connected T_effec rank, connect(ascending) sort(rank)  msize(medium) lcolor(blue) mcolor(blue)  msymbol(square_hollow)), $titlesyx title("`l2'", size(Medium)) xlabel(1(1)9) yscale(range(0.5 1.1)) xtitle("") ylabel(.5(.10)1.1) legend(off) scale(*1) graphregion(color(white)) name(`l', replace)
restore

local l POL
local l2 Poland
display "`l'"
preserve
keep if location=="`l'" 
egen rank=rank(T_local),  field
twoway (connected T_local rank, msize(medium) lcolor(red) mcolor(red) msymbol(circle_hollow)) (connected T_effec rank, connect(ascending) sort(rank)  msize(medium) lcolor(blue) mcolor(blue)  msymbol(square_hollow)), $titlesyx title("`l2'", size(Medium)) xlabel(1(1)9) yscale(range(0.5 1.1)) xtitle("") ylabel(.5(.10)1.1) legend(off) scale(*1) graphregion(color(white)) name(`l', replace)
restore

local l EST
local l2 Estonia
display "`l'"
preserve
keep if location=="`l'" 
egen rank=rank(T_local),  field
twoway (connected T_local rank, msize(medium) lcolor(red) mcolor(red) msymbol(circle_hollow)) (connected T_effec rank, connect(ascending) sort(rank)  msize(medium) lcolor(blue) mcolor(blue)  msymbol(square_hollow)), $titlesyx title("`l2'", size(Medium)) xlabel(1(1)9) yscale(range(0.5 1)) xtitle("") ylabel(.5(.10)1) legend(off) scale(*1) graphregion(color(white)) name(`l', replace)
restore

local l JPN
local l2 Japan
display "`l'"
preserve
keep if location=="`l'" 
egen rank=rank(T_local),  field
twoway (connected T_local rank, msize(medium) lcolor(red) mcolor(red) msymbol(circle_hollow)) (connected T_effec rank, connect(ascending) sort(rank)  msize(medium) lcolor(blue) mcolor(blue)  msymbol(square_hollow)), $titlesyx title("`l2'", size(Medium)) xlabel(1(1)9) yscale(range(0.8 1.3)) xtitle("") ylabel(.8(.10)1.3) legend(off) scale(*1) graphregion(color(white))name(`l', replace)
restore

*graph combine
grc1leg FRA GBR SVK POL EST JPN,  col(2)  graphregion(color(white)) ysize(20) xsize(12.0)  l2("Relative Productivity", size(small)) b2("Sectors sorted by Fundamental T", size(small))  legendfrom(FRA)  ring(6)
graph export "figures/figure2_effect_vs_fund.png", replace





*-------------------------------------------------------------------
*Figure 3 in the paper: Multinational Production and Sectoral Productivity
*-------------------------------------------------------------------
clear all
local set1 location isiccodereporter sector_mp mp_sales_ls sales_ls
use `set1' using "${MP_CA_data}/regression_dataset.dta", clear
duplicates drop 
drop if sector_mp=="S_NT"

local type m
local method poisson 
local factor wc
replace isiccodereporter=1 if isiccodereporter==840
merge 1:1 sector_mp isiccodereporter using "${MP_CA_data}/gravity_mp/`method'/parameters_gT_master_`type'_`factor'.dta", keepusing(T_beta_1001 Tmp_sq_1001)
drop _merge
rename T_beta_1001 T_beta
rename Tmp_sq_1001 Tmp_sq


local method poisson
gen a=T_beta if isiccodereporter==1
by sector_mp, sort: egen max_US=max(a) 
drop a
gen T_mp=(T_beta/max_US)
gen T_trade=(Tmp_sq/max_US)

gen a=ln(mp_sales_ls/sales_ls)
gen b=ln(T_mp)
gen c=ln(T_trade)
gen d=ln(T_trade/T_mp)

*figure1
xi: reg a b i.isiccodereporter i.sector_mp
dfbeta b
xi: reg a b i.isiccodereporter i.sector_mp if abs(_dfbeta_1)< 2/sqrt(e(N)) 
avplot b, xlabel(, format(%5.0f)) ylabel(, format(%5.0f)) legend(off) graphregion(fcolor(white)) msize(medlarge) mcolor(eltblue) msymbol(circle_hollow) mlabel() xtitle("Fundamental Productivity") ytitle("Inward MP Share") 
drop _dfbeta_1
graph export "figures/negative_output_model.png", as(png) replace

*figure 2
xi: reg a d i.isiccodereporter i.sector_mp
dfbeta d
xi: reg a d i.isiccodereporter i.sector_mp if  abs(_dfbeta_1)< 2/sqrt(e(N)) 
avplot d, xlabel(, format(%5.0f)) ylabel(, format(%5.0f)) legend(off) graphregion(fcolor(white)) msize(medlarge) mcolor(eltblue) msymbol(circle_hollow) mlabel() xtitle("Effective Productivity/Fundamental Productivity") ytitle("Inward MP Share") 
drop _dfbeta_1
graph export "figures/positive_output_model.png", as(png) replace





*-------------------------------------------------------------------
*Figure 4 in the paper: Estimated Multinational Production Barriers
*-------------------------------------------------------------------
clear all
use "${MP_CA_data}/gravity_mp/poisson/parameters_gs_master_m_wc_final.dta"
keep sector_mp2 isiccodepartner isiccodereporter g_final sector_mp g_m

merge 1:1 isiccodepartner isiccodereporter sector_mp using "${MP_CA_data}/gravity_trade/reg/parameters_sector9_reg_dmatrix_matlab_wc.dta"
drop if isiccodepartner==isiccodereporter
tab _merge
tab sector_mp if _merge==1
drop _merge
order isiccodepartner isiccodereporter origin location sector_mp sector_mp2 d g_final g_m

by isiccodepartner, sort: egen a=mode(origin), maxmode
replace origin=a if origin==""
drop a

by isiccodereporter, sort: egen a=mode(location), maxmode
replace location=a if location==""
drop a
format %9.3fc d g_final g_m
rename g_final g 


*Figure 4 (left panel / g & d by sector): Estimated Multinational Production Barriers
*-------------------------------------------------
gen d2=d
replace d2=10 if d==.
graph box g d2 if g_m<1000 & d2<1000, over( sector_mp, label(labsize(small)) ) graphregion(fcolor(white)) legend(region(lwidth(none)) label(1 "g") label(2 "d")) box(1, fintensity(20)) box(2, fintensity(70)) 
graph export "figures/gsbysector.png", as(png) replace

*** The reason why conditioning by g_m<1000 & d2<1000, is that we are requiring that both MP and trade to be possible
table sector_mp if g_m<1000 , c(mean g)
table origin if g_m<1000 , c(mean g)
table location if g_m<1000 , c(mean g)

*** To compare the median for MP and trade when both exists on a given sector
sum g d if g_m<1000 & d2<1000
sum g d if g_m<1000 & d2<1000, d
table sector_mp if g_m<1000 & d2<1000, c(p50 g)
table sector_mp if g_m<1000 & d2<1000, c(p50 d2)
save "temp1.dta", replace



*Figure 4 (right panel / g & d by sector): Estimated Multinational Production Barriers
*-------------------------------------------------
rename isiccodepartner p 
rename isiccodereporter isiccodepartner
rename p isiccodereporter
rename g g_inv
rename d d_ind 
save "temp2.dta", replace

clear all
use "temp1.dta", clear
merge 1:1 isiccodepartner isiccodereporter sector_mp using "temp2.dta"
drop _merge
gen dum=0
replace dum=1 if (location=="DEU" | location=="ESP" | location=="FRA" | location=="ITA" | location=="JPN" | location=="LTU" | location=="LVA" | location=="POL" | location=="PRT" | location=="USA")

*--- Figures g by selected country
graph box g g_inv if g<10 & g_inv<10 & g!=. & g_inv!=. & dum==1 & sector_mp!="S_NT", over(location, label(labsize(small))) graphregion(fcolor(white)) box(1, fintensity(20)) box(2, fintensity(70)) legend(region(lwidth(none)) label(1 "g{sub:location}") label(2 "g{sub:source}"))
graph export "figures/gsbycountry.png", as(png) replace


*--- Figures d by selected country
graph box d d_ind if d<10 & d_ind<10 & d!=. & d_ind!=. & dum==1 & sector_mp!="S_NT", over(location, label(labsize(small))) graphregion(fcolor(white)) box(1, fintensity(20)) box(2, fintensity(70)) legend(region(lwidth(none)) label(1 "d{sub:location}") label(2 "d{sub:source}")) 
graph export "figures/figures_appendix/dsbycountry.png", as(png) replace










