*************************************************************************
*University of British Columbia
*Sauder School of Business  
*Vanessa Alviarez
*Multinationals and Comparative Advantage
*Journal of International Economics
**************************************************************************


*=======================================================================
*TITLE: Section 4 in "Mutinational Production and Comparative Advantage"
*DESCRIPTION: Productivity parameters, trade and MP costs 
*=======================================================================
clear all
set more off 
cd "L:\Dropbox (UBC-Umich)\MNC_CA\Data and Replication Files" /*change to users directory*/
do "MP_CA_directory.do"


*----------------------------------------------------------------------
*NOTE: for each country-sector pair, we implement the following fixed point procedure: 
*----------------------------------------------------------------------
*1) Get the T_sq from the trade gravity equation 
*2.1) Estimate the bilateral-sector MP barriers (g's) and the FIRST SET of fundamental productivities (T)
*2.2) Use the set of T's and g's to calculate a set of T_sq's (mp) 
**********************LOOP****************
*3) Calculate the differece DELTA=(Tsq trade - Tsq mp) and adjust 
*         Tsq_mp (updated) = Tsq mp + (0.01)*DELTA
*4) Use the updated [Tsq_mp (updated)] and use the system of equations Tsq=g*T to calculate (Ts). 
*5) Use the calculated Ts in step 5 and run a constrained MP gravity equation, (alpha=beta=1) to estimate the MP barriers (g). 
*6) With the g's and the T's (from 4) calculate a new set of Tsq. 
*7) Iration: step 3-6 until the difference between Tsq_trade and Tsq_mp is small enough. 
**********************LOOP****************
*8) Finally for non-tradables we use our estimates from the MP gravity equation, and convert them to absolute levels by multiplying them by the US productivity in this sectr


*STEP 1: Calculate the trade gravity equation through Poisson. Get the Tsq and the d's 
*STEP 2: Calculate the MP gravity equation through Poisson. Get the g's, and the "initial" set of T's (relative) 
*STEP 3: With the g's and the T's calculate the Tsq mp. Then update Ts (mp) by adding 0.01 of the differece between Tsq (trade)- Tsq (mp). 
*STEP 4: Use the system of equations Tsq=g*T to calculate (Ts). 
*STEP 5: Calculate the MP gravity equation (to obtaing MP barriers, g) through Poisson without constant and restricting the coefficients to be equals (1) and (-1) (Using the Ts from step 4) 
*STEP 6: With the T's and the last set of g's calculate the Tsq and repeat 



*===============================================================================
*STEP 1: Calculate the trade gravity equation through Poisson (with) constant  
*===============================================================================


************************* TRADE GRAVITY ************************


*Testing the database 
*---------------------------------------------------------------------------
clear all
use "${MP_CA_data}/mp_dataset_complete.dta", clear 


*Bring bilateral variables 
*--------------------------------------------
merge m:1 sector_mp isiccodereporter isiccodepartner using "${MP_CA_data}/bilateral_dataset_complete.dta"
drop if _merge==2
drop _merge
******************gen mp_triplet=mp_share_sales_ols
gen mp_triplet=mp_sales_ols
local num_countries=32


*Making the gravity database suitable for running the gravity equation (9 sectors/decade) 
*----------------------------------------------------
local ommited=840
display "`ommited'"
replace isiccodereporter=1 if isiccodereporter==`ommited' 
replace isiccodepartner=1 if isiccodepartner==`ommited'  


*Dependent variables for trade and MP
*----------------------------------------------
gen tradevalue=trade_nls
replace tradevalue=0 if tradevalue==.
gen depvar1_trade=tradevalue/Xnn
gen ln_depvar1_trade=ln(depvar1_trade)
gen depvar1_reg=ln_depvar1_trade
gen depvar1_poisson=depvar1_trade

replace mp_triplet=0 if mp_triplet==.
gen depvar1_mp=mp_triplet/Ynn
gen ln_depvar1_mp=ln(depvar1_mp)
compress


*Sector, exporter and importer dummies
*----------------------------------------------------
tabulate isiccodepartner, gen(exp)
tabulate isiccodereporter, gen(imp)
levelsof sector_mp, local(sector2) 

*Save file
save "${MP_CA_data}/mp_trade_origin_location_sectors.dta", replace


*Creating a unisectoral data
*----------------------------------------------------
clear all
use sector_mp location isiccodereporter exports_ls imports_ls Xn Xnn absor absor_rel Xn_rel sales_ls mp_sales_ls mp_emp_ls mp_num_firms_ls using "${MP_CA_data}/mp_trade_origin_location_sectors.dta", clear
sort location sector_mp
duplicates drop location sector_mp, force 
save "${MP_CA_data}/mp_trade_location_sectors.dta", replace



*Running the gravity equation 
*----------------------------------------------------
local sector2 S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 
disp "`sector2'"


foreach method in poisson reg {
foreach s of local sector2 {

display _newline(2) "Regression sector_`s'_`method'"
use "${MP_CA_data}/mp_trade_origin_location_sectors.dta" if sector_mp=="`s'", clear

*Running the poisson regressions
*----------------------------------------------
`method' depvar1_`method' imp2-imp`num_countries' exp2-exp`num_countries' ln_dist contig comlang_off colony RTA, vce(robust) 

predict xb_`method', xb
gen resid_`method'=depvar1_trade-xb_`method'
gen resid_`method'_ln=ln_depvar1_trade-xb_`method'

keep resid_`method' resid_`method'_ln sector_mp isiccodereporter isiccodepartner  
save "${MP_CA_data}/gravity_trade/`method'/resid_sector9_`method'_`s'.dta", replace



*Saving the coefficients
*----------------------------------------------
matrix b = e(b)
svmat b
local last=((`num_countries'-1)*2)+6
display "`last'"
keep b1-b`last'
keep if b1!=.
gen A=1
reshape long b, i(A) j(coef)
drop A
gen sector="`s'"
preserve 
keep if coef<=`num_countries'-1
save "${MP_CA_data}/gravity_trade/`method'/mfe_sector9_`method'_`s'.dta", replace
restore
preserve
keep if coef>=`num_countries' & coef<=(`num_countries'-1)*2
save "${MP_CA_data}/gravity_trade/`method'/xfe_sector9_`method'_`s'.dta", replace
restore
keep if coef>=((`num_countries'-1)*2)+1
save "${MP_CA_data}/gravity_trade/`method'/barriers_sector9_`method'_`s'.dta", replace
}
}
*


*Appending parameters across different sectors: 
*---------------------------------------------
local sector2 S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 
disp "`sector2'"
foreach method in poisson reg {

foreach val in resid mfe xfe barriers {
clear all
set obs 1
gen x=.	
   
foreach s of local sector2 {
append using "${MP_CA_data}/gravity_trade/`method'/`val'_sector9_`method'_`s'.dta"
erase "${MP_CA_data}/gravity_trade/`method'/`val'_sector9_`method'_`s'.dta"
compress 
}
*
drop if _n==1
drop x
save "${MP_CA_data}/gravity_trade/`method'/`val'_sector9_`method'.dta", replace
}
}
*  


*Computing the trade barriers
*----------------------------------------------------
local sector2 S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 
disp "`sector2'"

foreach method in poisson reg {


use "${MP_CA_data}/gravity_trade/`method'/barriers_sector9_`method'.dta", clear
reshape wide b, i(sector) j(coef) 


*--------------------------  THETA  ------------------------------*
*EK
gen theta_1=8.28

*Costinot el al
gen theta_2=6

*Caliendo and Parro estimates (at the sectoral level)  
*----------------------------------------------------------
gen theta_3=.
replace theta_3=2.62 if sector=="S15_16"
replace theta_3=8.01 if sector=="S17_19"
replace theta_3=15.70 if sector=="S20_22"
replace theta_3=27.01 if sector=="S23_25"
replace theta_3=2.41 if sector=="S26"
replace theta_3=5.41 if sector=="S27_28"
replace theta_3=5.71 if sector=="S29_33"
replace theta_3=1.42 if sector=="S34_35"
replace theta_3=3.98 if sector=="S36_37"
replace theta_3=5 if sector=="S_NT"
*5 is the average across (in the CP NAFTA paper)
*--------------------------  THETA  ------------------------------*


*Renaming the coefficients (ln_dist contig colony comlang_off RTA)
*-----------------------------------------------
local last=((`num_countries'-1)*2)+1
rename b`last' beta_dist
local last=`last'+1
rename b`last' border
local last=`last'+1
rename b`last' colony
local last=`last'+1
rename b`last' language
local last=`last'+1
rename b`last' rta
local last=`last'+1
rename b`last' cte


foreach y in theta_1 theta_2 theta_3 {
foreach var in beta_dist  border colony language rta cte {
gen `var'_`y'=`var'/(-`y')
}
}
*
drop beta_dist border colony language rta cte
drop theta_1 theta_2 theta_3
save "${MP_CA_data}/gravity_trade/`method'/barriers_sector9_`method'_theta.dta", replace


*-------------------------------------------------------------------------
*Arraging the isocode data
*-------------------------------------------------------------------------
clear all
use "${MP_CA_data}/countrycode_match.dta", clear
drop isocode

merge m:1 location using "${MP_CA_data}/countrycode_match1.dta", keepusing(location2)
rename location2 isocode
keep if _merge==3
drop _merge
do "${MP_CA_do}/sample_countries.do"
drop isocode

merge m:1 origin using "${MP_CA_data}/countrycode_match1.dta", keepusing(location2)
rename location2 isocode
keep if _merge==3
drop _merge
do "${MP_CA_do}/sample_countries.do"
drop isocode
sort location origin 

local ommited=840
display "`ommited'"
replace isiccodepartner=1 if isiccodepartner==`ommited'  
replace isiccodereporter=1 if isiccodereporter==`ommited'  
sort isiccodereporter
gen coef=_n

save "${MP_CA_data}/countrycode_match_gravity_coef.dta", replace
*-------------------------------------------------------------------------



*-------------------------------------------------------------------------
*Arraging the Importer and Exporter Fixed Effect
*-------------------------------------------------------------------------
local sector2 S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 S_NT
disp "`sector2'"

use "${MP_CA_data}/gravity_trade/`method'/xfe_sector9_`method'.dta", clear
replace coef=coef-(`num_countries'-1)
rename b xfe
merge 1:1 coef sector using "${MP_CA_data}/gravity_trade/`method'/mfe_sector9_`method'.dta", keep(3) nogen
rename b mfe
replace coef=coef+1




*Adding USA 
*-------------------------------------------------------
foreach var in S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37  {
local new = _N + 1
set obs `new' 
replace coef=1 if coef==.
replace sector="`var'" if sector==""
replace xfe=0 if xfe==. & coef==1
replace mfe=0 if mfe==. & coef==1
}
*


*--------------------------  THETA  ------------------------------*
gen theta_1=8.28
gen theta_2=6.00

*Caliendo and Parro estimates (at the sectoral level) 
gen theta_3=.
replace theta_3=2.62 if sector=="S15_16"
replace theta_3=8.01 if sector=="S17_19"
replace theta_3=15.70 if sector=="S20_22"
replace theta_3=27.01 if sector=="S23_25"
replace theta_3=2.41 if sector=="S26"
replace theta_3=5.41 if sector=="S27_28"
replace theta_3=5.71 if sector=="S29_33"
replace theta_3=1.42 if sector=="S34_35"
replace theta_3=3.98 if sector=="S36_37"
replace theta_3=5 if sector=="S_NT"
*--------------------------  THETA  ------------------------------*


*For the few cases in which they are not available
by sector, sort: egen a=median(mfe)
replace mfe=a if mfe==.
drop a
by sector, sort: egen a=median(xfe)
replace xfe=a if xfe==.
drop a


foreach var in theta_1 theta_2 theta_3 {
gen exp_barr_`var'=-(1/`var')*(mfe+xfe)
}
*

*Calculating S's
*---------------------------------------------------------
gen S_xfe=exp(xfe)
gen S_mfe=exp(-mfe)
order coef sector xfe mfe S_xfe S_mfe


*Merging the country codes with the coef using "gravity_trade/country_coef_codes.dta"
*--------------------------------------------------------
merge m:1 coef using "${MP_CA_data}/countrycode_match_gravity_coef.dta", keepusing(isiccodereporter) 
drop if _merge==2 
drop _merge
gen isiccodepartner=isiccodereporter
save "${MP_CA_data}/gravity_trade/`method'/parameters_sector9_`method'_xfe_mfe.dta", replace


*============================================================================
****ERROR TERM***** (now we can count, we have the exporter and importer fixed effect 
*============================================================================
*We have to construct or d's vector 
use location origin isiccodereporter isiccodepartner sector_mp ln_dist contig colony comlang_off RTA depvar1_trade using "${MP_CA_data}/mp_trade_origin_location_sectors.dta", clear
drop if sector_mp=="S_NT"


*Include the error term*
*-------------------------------------
merge 1:1 isiccodereporter isiccodepartner sector_mp using "${MP_CA_data}/gravity_trade/`method'/resid_sector9_`method'.dta"
keep if _merge==3
drop _merge


*Include the betas for the "distance" variables (with each theta respectively)
*-------------------------------------
gen sector=sector_mp
merge m:1 sector using "${MP_CA_data}/gravity_trade/`method'/barriers_sector9_`method'_theta.dta", keepusing(beta_dist_theta_1 beta_dist_theta_2 beta_dist_theta_3 border_theta_1 border_theta_2 border_theta_3 cte_theta_1 cte_theta_2 cte_theta_3 colony_theta_1 colony_theta_2 colony_theta_3 language_theta_1 language_theta_2 language_theta_3 rta_theta_1 rta_theta_2 rta_theta_3)
keep if _merge==3
drop _merge


*----------------------------------------------------------------------
*Include the exporter and importer barriers* (but we call it always EXPORT BARRIERS)
*----------------------------------------------------------------------
merge m:1 isiccodereporter sector using "${MP_CA_data}/gravity_trade/`method'/parameters_sector9_`method'_xfe_mfe.dta", keepusing(S_mfe S_xfe exp_barr_theta_1 exp_barr_theta_2 exp_barr_theta_3)
drop if _merge==2
drop _merge

foreach var in exp_barr_theta_1 exp_barr_theta_2 exp_barr_theta_3 S_mfe S_xfe {
rename `var' `var'_reporter
}
*

*It is S, but we matched it with the partner (this is becasue that is where we need it to be for the construction of the adjustment factor)
merge m:1 isiccodepartner sector using "${MP_CA_data}/gravity_trade/`method'/parameters_sector9_`method'_xfe_mfe.dta", keepusing(S_mfe S_xfe exp_barr_theta_1 exp_barr_theta_2 exp_barr_theta_3)
drop if _merge==2
drop _merge

foreach var in exp_barr_theta_1 exp_barr_theta_2 exp_barr_theta_3 S_mfe S_xfe {
rename `var' `var'_partner
}
*

*----------------------------------------------------------------------
merge m:m sector using "${MP_CA_data}/gravity_trade/`method'/parameters_sector9_`method'_xfe_mfe.dta", keepusing(theta_1 theta_2 theta_3)
drop if _merge==2
drop _merge

foreach y in reporter partner {
replace exp_barr_theta_1_`y'=0 if isiccode`y'==1 & exp_barr_theta_1_`y'==.
replace exp_barr_theta_2_`y'=0 if isiccode`y'==1 & exp_barr_theta_2_`y'==.
replace exp_barr_theta_3_`y'=0 if isiccode`y'==1 & exp_barr_theta_3_`y'==.
}
*

*Calculating the dij matrix* (D_`method'_`s'_partner is the trade barriers calculated with exporter effect and D_`method'_`s'_reporter is the trade barrirer calculated with importer effect) 
*-------------------------------------
foreach y in theta_1 theta_2 theta_3 {
gen resid_`method'_ln_`y'=resid_`method'_ln/(-`y')
gen resid_`method'_`y'=resid_`method'/(-`y')
}
*
foreach var in partner reporter {
foreach s in theta_1 theta_2 theta_3 {
gen D_`method'_`s'_`var'=cte_`s' + beta_dist_`s'*ln_dist + border_`s'*contig + colony_`s'*colony +language_`s'*comlang_off + rta_`s'*RTA + exp_barr_`s'_`var' + resid_`method'_ln_`s'
replace D_`method'_`s'_`var'=exp(D_`method'_`s'_`var')
sum D_`method'_`s'_`var', d
replace D_`method'_`s'_`var'=0 if depvar1_trade==0
replace D_`method'_`s'_`var'=1.3 if D_`method'_`s'_`var'<1 & depvar1_trade!=0 /*(less than 1% of the observations) */
}
}
save "${MP_CA_data}/gravity_trade/`method'/transit.dta", replace



*-------------------------------------------------------------------------
*Productivity correction factor* (which needs the D's and the S_mfe) 
*-------------------------------------------------------------------------


*-------------------------------------------------------------------------
*Adjustment for all countries (Levchenko and Zhang method)
*-------------------------------------------------------------------------
gen S_rel=S_mfe_partner/S_mfe_reporter
replace S_rel=S_mfe_partner if isiccodereporter==1

foreach s in theta_2 {
gen a=S_rel*(D_`method'_`s'_partner)^(-`s')
by location sector, sort: egen b=total(a)
gen ind=1/(b+1)
gen ind2=ind if isiccodereporter==1
by sector, sort: egen a_max=max(ind2)
gen adjust_LZ=(ind/a_max)^(1/`s')
drop a b ind ind2 a_max
}
by isiccodereporter sector, sort: gen ind=_n==1
keep if ind==1
keep sector isiccodereporter location adjust_LZ
gen isiccodepartner=isiccodereporter
gen sector_mp=sector
save "${MP_CA_data}/gravity_trade/`method'/TFP_adjustfactor_LZ.dta", replace


*-------------------------------------------------------------------------
*Adjustment for all countries (Costinot method)
*-------------------------------------------------------------------------
clear all
use "${MP_CA_data}/gravity_trade/`method'/transit.dta", clear

by isiccodereporter sector, sort: gen a=_n==1
keep if a==1
drop a
merge 1:1 sector_mp location using "${MP_CA_data}/mp_trade_location_sectors.dta", keepusing(absor_rel absor)
drop if _merge==2
drop _merge

foreach s in theta_2 {
gen adjust_costinot=(absor_rel)^(1/`s')
}
keep sector_mp isiccodereporter isiccodepartner adjust_costinot
save "${MP_CA_data}/gravity_trade/`method'/TFP_adjustfactor_costinot.dta", replace




*-------------------------------------------------------------------------
*Bringing US technology 
*-------------------------------------------------------------------------
clear all
use "${MP_CA_data}/gravity_trade/`method'/transit.dta", clear
merge m:1 sector_mp using  "${MP_CA_data}/TFP_2_US.dta", keepusing(TFP_exp)
drop if _merge==2
drop _merge
rename TFP_exp TFP_US
*-------------------------------------------------------------------------

*See equation in Appendix E.1.1 in the paper
foreach s in theta_1 theta_2 theta_3 {
display "`s'"
gen a=S_mfe_partner*(D_`method'_`s'_partner)^(-`s') if isiccodereporter==1
by sector, sort: egen b=total(a)
replace b=b+1
gen Tsq_usa_`s'=(TFP_US^(`s'))/b
format %9.1fc Tsq_usa_`s'
drop a b 
}
*
sort sector location origin
save "${MP_CA_data}/gravity_trade/`method'/parameters_sector9_`method'_transition.dta", replace

keep if location=="USA"
duplicates drop sector_mp, force
keep sector_mp TFP_US Tsq_usa_theta_1 Tsq_usa_theta_2 Tsq_usa_theta_3
save "${MP_CA_data}/gravity_trade/`method'/parameters_sector9_`method'_Tusa.dta", replace


*--------------------------------------------------------------------
*ONLY TRADE BARRIERS*
*--------------------------------------------------------------------
clear all
use "${MP_CA_data}/gravity_trade/`method'/parameters_sector9_`method'_transition.dta", clear
keep origin location isiccodereporter isiccodepartner sector_mp D_`method'_theta_1_partner D_`method'_theta_2_partner D_`method'_theta_3_partner D_`method'_theta_1_reporter D_`method'_theta_2_reporter D_`method'_theta_3_reporter
save "${MP_CA_data}/gravity_trade/`method'/parameters_sector9_`method'_dmatrix.dta", replace


*Prepare to be send to MATLAB
*--------------------------------------------------
gen sector_mp2=.
replace sector_mp2=1 if sector_mp=="S15_16"
replace sector_mp2=2 if sector_mp=="S17_19"
replace sector_mp2=3 if sector_mp=="S20_22"
replace sector_mp2=4 if sector_mp=="S23_25"
replace sector_mp2=5 if sector_mp=="S26"
replace sector_mp2=6 if sector_mp=="S27_28"
replace sector_mp2=7 if sector_mp=="S29_33"
replace sector_mp2=8 if sector_mp=="S34_35"
replace sector_mp2=9 if sector_mp=="S36_37"
replace sector_mp2=10 if sector_mp=="S_NT"

sort sector_mp isiccodereporter isiccodepartner  
keep isiccodereporter isiccodepartner sector_mp2 D_`method'_theta_1_partner D_`method'_theta_2_partner D_`method'_theta_3_partner D_`method'_theta_1_reporter D_`method'_theta_2_reporter D_`method'_theta_3_reporter
foreach var in D_`method'_theta_1_partner D_`method'_theta_2_partner D_`method'_theta_3_partner D_`method'_theta_1_reporter D_`method'_theta_2_reporter D_`method'_theta_3_reporter {
replace `var'=0 if `var'==.
}
order sector_mp2 isiccodereporter isiccodepartner  D_`method'_theta_1_partner D_`method'_theta_2_partner D_`method'_theta_3_partner D_`method'_theta_1_reporter D_`method'_theta_2_reporter D_`method'_theta_3_reporter
sort sector_mp isiccodereporter isiccodepartner  
outsheet sector_mp2 isiccodereporter isiccodepartner D_`method'_theta_1_partner D_`method'_theta_2_partner D_`method'_theta_3_partner D_`method'_theta_1_reporter D_`method'_theta_2_reporter D_`method'_theta_3_reporter using "${MP_CA_matlab}/trade_cost_sector9_`method'", comma nonames nolabel replace



*--------------------------------------------------------------------
*NOW LET'S GET THE TSQ
*--------------------------------------------------------------------
clear all
use  "${MP_CA_data}/gravity_trade/`method'/parameters_sector9_`method'_xfe_mfe.dta", clear 


*Non-tradable prices 
*-----------------------------
*It is append because it is for non-tradable
append using "${MP_CA_data}/prices_nontradable.dta"
replace isiccodereporter=isiccodepartner
replace sector=sector_mp if sector==""

merge m:1 isiccodereporter using "${MP_CA_data}/countrycode_match_gravity_coef.dta", keepusing(coef) update
drop if _merge==1
drop if coef==.
drop _merge
drop origin partner 

foreach var in theta_1 theta_2 theta_3 {
gen prices_rel_`var'=P_nt if sector_mp=="S_NT"
}
*
drop P_nt P_t GDP_tradable_sum P_tnt_world P_nt_world P_t_world
sort coef sector
merge m:1 coef using "${MP_CA_data}/countrycode_match_gravity_coef.dta", keepusing(isiccodereporter) update
drop if _merge==2 
drop _merge

replace isiccodepartner=isiccodereporter
replace sector_mp=sector if sector_mp==""


*Gamma's 
*-----------------------------
merge m:1 sector_mp using "${MP_CA_data}/gamma_9sectors_supply.dta"
drop if _merge==2
drop _merge


*Relative Prices* (pnj/pusj=(absor_rel to US*(1/Sn))^(1/theta)
*---------------------------------------------------------
*Bring the absorb relative to US from the main dataset
merge 1:1 isiccodereporter sector_mp using "${MP_CA_data}/mp_trade_location_sectors.dta", keepusing(absor_rel absor)
drop if _merge==2 
drop _merge


*Calculate the prices (for each set of thetas) 
foreach var in theta_1 theta_2 theta_3 {
replace prices_rel_`var'=((absor_rel)*(1/S_mfe))^((1/`var')) if sector_mp!="S_NT"
}
*

*Bring wages, rate of return of capital, alpha's and beta's 
*---------------------------------------------------------


*Beta's and alpha's
*-----------------------------
merge m:1 sector_mp using "${MP_CA_data}/alpha_beta_9sectors.dta", keepusing(alpha_mean beta_mean beta_median alpha_median)
drop if _merge==2
drop _merge


*Wages and return of capital
*-----------------------------
*merge m:1 isiccodepartner using "${MP_CA_data}/wages_0307.dta", keepusing(wage_rel wage)
merge m:1 isiccodepartner using "${MP_CA_data}/wages_rcapital_comb.dta", keepusing(r1_rel pl_krel0312 wage_rel wagerel0312)
drop r1_rel wage_rel
rename pl_krel0312 r1_rel
rename wagerel0312 wage_rel
drop if _merge==2 
drop _merge

merge m:1 isiccodepartner using "${MP_CA_data}/labor_capital_decade.dta", keepusing( labor_rel capital_rel L K)
drop if _merge==2 
drop _merge

*merge m:1 isiccodepartner using "${MP_CA_data}/rental_0307.dta", keepusing(r1_rel r1)
*drop if _merge==2 
*drop _merge


*Share of expenditure in tradables
*-----------------------------
merge m:1 isiccodepartner using "${MP_CA_data}/prices_nontradable_3.dta", keepusing(GDP_tradable_sum)
drop if _merge==2 
drop _merge

foreach var in theta_1 theta_2 theta_3 {
by sector_mp, sort: egen `var'_2=mean(`var')
drop `var'
rename `var'_2 `var'
}
*


*Prepare to be send to MATLAB
*--------------------------------------------------
gen sector_mp2=.
replace sector_mp2=1 if sector=="S15_16"
replace sector_mp2=2 if sector=="S17_19"
replace sector_mp2=3 if sector=="S20_22"
replace sector_mp2=4 if sector=="S23_25"
replace sector_mp2=5 if sector=="S26"
replace sector_mp2=6 if sector=="S27_28"
replace sector_mp2=7 if sector=="S29_33"
replace sector_mp2=8 if sector=="S34_35"
replace sector_mp2=9 if sector=="S36_37"
replace sector_mp2=10 if sector=="S_NT"
sort sector_mp2 isiccodereporter 

order sector_mp2 isiccodereporter  wage_rel wage r1_rel r1 L K labor_rel capital_rel
outsheet sector_mp2 isiccodereporter wage_rel wage r1_rel r1 L K labor_rel capital_rel using "${MP_CA_matlab}/KL_wages_return", comma nonames nolabel replace
outsheet sector_mp2 isiccodereporter GDP_tradable_sum using "${MP_CA_matlab}/si_rep_par", comma nonames nolabel replace
*Note: si is the share of expenditure on traded goods


*Wages and rate of return of capital
preserve
keep isiccodepartner wage wage_rel r1 r1_rel L K labor_rel capital_rel
duplicates drop 
outsheet isiccodepartner wage wage_rel r1 r1_rel L K labor_rel capital_rel using "${MP_CA_matlab}/w_r_L_K", comma nonames nolabel replace
restore

*Si (share of expenditure on traded goods)
preserve
keep isiccodereporter GDP_tradable_sum
rename GDP_tradable_sum si
duplicates drop 
outsheet isiccodereporter si using "${MP_CA_matlab}/si", comma nonames nolabel replace
restore

*Alpha and beta
preserve
keep sector_mp2 alpha_mean beta_mean beta_median alpha_median
duplicates drop 
outsheet sector_mp2 alpha_mean beta_mean beta_median alpha_median using "${MP_CA_matlab}/alpha_beta", comma nonames nolabel replace
restore

*Gamma
preserve
use "${MP_CA_data}/gamma_9sectors_supply.dta", clear
drop sector_mp 
outsheet supply_S15_16 supply_S17_19 supply_S20_22 supply_S23_25 supply_S26 supply_S27_28 supply_S29_33 supply_S34_35 supply_S36_37 supply_S_NT using "${MP_CA_matlab}/gamma_9sectors", comma nonames nolabel replace
restore


sort coef sector_mp
format xfe mfe S_xfe S_mfe exp_barr_theta_1 exp_barr_theta_2 exp_barr_theta_3 absor_rel prices_rel_theta_1 prices_rel_theta_2 prices_rel_theta_3 r1_rel r1 %9.2fc
format supply_S15_16 supply_S17_19 supply_S20_22 supply_S23_25 supply_S26 supply_S27_28 supply_S29_33 supply_S34_35 supply_S36_37 supply_S_NT %9.2fc
order coef sector isiccodereporter sector_mp xfe mfe S_xfe S_mfe exp_barr_theta_1 exp_barr_theta_2 exp_barr_theta_3 absor_rel prices_rel_theta_1 prices_rel_theta_2 prices_rel_theta_3 
 
  
*H-O forces. Bring factor intensities and adjusted capital to labor ratio (LK_sector_int)
*-----------------------------
merge m:1 sector_mp using "${MP_CA_data}/NBER data factor intensities_average_weights.dta"
drop if _merge==2
drop _merge

gen ln_KL=ln(K/L)
gen ln_int_KL_weights=ln(int_KL_weights)

gen ln_LK_sector_int=ln_KL*ln_int_KL_weights
gen LK_sector_int=ln_KL*int_KL_weights

sum int_KL_weights ln_KL LK_sector_int, d


*----------------------------------------------------------------------------
*Saving the files 
*----------------------------------------------------------------------------
save "${MP_CA_data}/gravity_trade/`method'/parameters_sector9_`method'_1.dta", replace



*----------------------------------------------------------------------------
*Generating cost parameters  (WITHOUT CAPITAL) 
*----------------------------------------------------------------------------
clear all
use "${MP_CA_data}/gravity_trade/`method'/parameters_sector9_`method'_1.dta", clear
gen cost_1=(wage_rel)^(beta_median)
gen cost_2=1
format cost_1 cost_2 %9.4fc

foreach y in theta_1 theta_2 theta_3 {
local sector2 S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 S_NT
foreach var of local sector2 {
gen price_`var'=prices_rel_`y'^(supply_`var'*(1-beta_median))
}
*

local sector2 S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 S_NT
foreach var of local sector2 {
bysort isiccodereporter: gen double product = price_`var'[1]
by isiccodereporter: replace product = product[_n-1] * price_`var' if _n > 1
by isiccodereporter: replace product = product[_N] if sector_mp=="`var'"
drop price_`var'
rename product  price_`var'
format price_`var' %9.4fc
}
*
gen cost_3=.
local sector2 S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 S_NT
foreach var of local sector2 {
replace cost_3=price_`var' if sector_mp=="`var'"
drop price_`var' 
}
format cost_3 %9.4fc
gen cost_total_`y'=cost_1*cost_2*cost_3
drop cost_3
}
save "${MP_CA_data}/gravity_trade/`method'/parameters_sector9_`method'_cost_nocapital.dta", replace


*----------------------------------------------------------------------------
*Calculating the Technology Parameters  (for Tradables) 
*----------------------------------------------------------------------------
foreach y in theta_1 theta_2 theta_3 {
gen T_`y'=S_mfe*(cost_total_`y')^`y'
replace T_`y'=1 if isiccodepartner==1
}
*
foreach y in theta_1 theta_2 theta_3 {
gen Tx_`y'=S_xfe*(cost_total_`y')^`y'
replace Tx_`y'=1 if isiccodepartner==1
}


*----------------------------------------------------------------------------
*Bring the US productivity to make all other productivities absolute values
*----------------------------------------------------------------------------
merge m:1 sector_mp using "${MP_CA_data}/gravity_trade/`method'/parameters_sector9_`method'_Tusa.dta", keepusing(Tsq_usa_theta_1 Tsq_usa_theta_2 Tsq_usa_theta_3)


*Making it in levels for US 
*-----------------------------------------------------
foreach y in theta_1 theta_2 theta_3 {

*T absolute
*---------------------
gen Tx_abs_`y'=Tx_`y'*Tsq_usa_`y'
gen T_abs_`y'=T_`y'*Tsq_usa_`y'
rename Tx_`y' Tx_rel_`y'
rename T_`y' T_rel_`y'
}
*
keep coef sector_mp sector_mp2 isiccodereporter T_abs_theta_1  T_abs_theta_2  T_abs_theta_3  Tx_abs_theta_1  Tx_abs_theta_2  Tx_abs_theta_3 T_rel_theta_1 T_rel_theta_2 T_rel_theta_3 Tx_rel_theta_1 Tx_rel_theta_2 Tx_rel_theta_3 Tsq_usa_theta_1 Tsq_usa_theta_2 Tsq_usa_theta_3   
order coef sector_mp sector_mp2 isiccodereporter T_abs_theta_1  T_abs_theta_2  T_abs_theta_3  Tx_abs_theta_1  Tx_abs_theta_2  Tx_abs_theta_3 T_rel_theta_1 T_rel_theta_2 T_rel_theta_3 Tx_rel_theta_1 Tx_rel_theta_2 Tx_rel_theta_3 Tsq_usa_theta_1 Tsq_usa_theta_2 Tsq_usa_theta_3   
gen isiccodepartner=isiccodereporter
save "${MP_CA_data}/gravity_trade/`method'/parameters_sector9_`method'_1_Tsq_nocapital.dta", replace

*keep sector_mp2 isiccodereporter  TFP_US TFP_US_adjust2_theta_1 TFP_US_adjust2_theta_2 TFP_US_adjust2_theta_3 TFP_US_adjust1_theta_1 TFP_US_adjust1_theta_2 TFP_US_adjust1_theta_3  T_rel_theta_1 T_rel_theta_2 T_rel_theta_3 T_level_adjust2_theta_1 T_level_adjust2_theta_2 T_level_adjust2_theta_3 T_level_adjust1_theta_1 T_level_adjust1_theta_2 T_level_adjust1_theta_3 Tx_rel_theta_1 Tx_rel_theta_2 Tx_rel_theta_3  Tx_level_adjust2_theta_1 Tx_level_adjust2_theta_2 Tx_level_adjust2_theta_3 Tx_level_adjust1_theta_1 Tx_level_adjust1_theta_2 Tx_level_adjust1_theta_3 
drop isiccodepartner
order sector_mp2 isiccodereporter T_rel_theta_1 T_rel_theta_2 T_rel_theta_3 T_abs_theta_1 T_abs_theta_2 T_abs_theta_3 Tx_abs_theta_1 Tx_abs_theta_2 Tx_abs_theta_3 
sort sector_mp2 isiccodereporter  
outsheet sector_mp2 isiccodereporter T_rel_theta_1 T_rel_theta_2 T_rel_theta_3 T_abs_theta_1 T_abs_theta_2 T_abs_theta_3 using "${MP_CA_matlab}/trade_T_sector9_`method'_nocapital", comma nonames nolabel replace

sort sector_mp2 isiccodereporter  
outsheet sector_mp2 isiccodereporter Tx_rel_theta_1 Tx_rel_theta_2 Tx_rel_theta_3 Tx_abs_theta_1 Tx_abs_theta_2 Tx_abs_theta_3 using "${MP_CA_matlab}/trade_Tx_sector9_`method'_nocapital", comma nonames nolabel replace

}
*

*Checking (trade)
*------------------------------- 
local method reg
use "${MP_CA_data}/gravity_trade/`method'/parameters_sector9_`method'_dmatrix.dta", clear
sum D_`method'_theta_2_partner if D_`method'_theta_2_partner!=0, d
table sector if D_`method'_theta_2_partner!=0, c(mean D_`method'_theta_2_partner)





















*===============================================================================*
*STEP 2: Calculate the MP gravity equation through Poisson constant   
*===============================================================================*


************************* MP GRAVITY ************************
clear all
set more off 
use "${MP_CA_data}/mp_trade_origin_location_sectors.dta", clear

replace mp_triplet=0 if mp_triplet==.
replace depvar1_mp=0 if depvar1_mp==.

drop depvar1_reg depvar1_poisson
gen depvar1_reg=ln_depvar1_mp
gen depvar1_poisson=depvar1_mp

sort origin location sector_mp 
order origin location sector_mp  tradevalue mp_triplet Ynn Xnn
format %9.2fc tradevalue mp_triplet Ynn Xnn

save "${MP_CA_data}/mp_trade_origin_location_sectors_mp.dta", replace


*----------------------------------------------------------------------
local sector2 S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 S_NT
disp "`sector2'"
local num_countries=32

foreach method in poisson reg {
foreach s of local sector2 {

display _newline(2) "Regression sector_`s'"
use "${MP_CA_data}/mp_trade_origin_location_sectors_mp.dta" if sector_mp=="`s'", clear


*Running the poisson regressions
*----------------------------------------------
`method' depvar1_`method' imp2-imp`num_countries' exp2-exp`num_countries' ln_dist contig colony comlang_off RTA, vce(robust) 
predict xb_`method', xb
gen resid_`method'=depvar1_mp-xb_`method'
gen resid_`method'_ln=ln_depvar1_mp-xb_`method'

keep resid_`method' resid_`method'_ln sector_mp isiccodereporter isiccodepartner  
save "${MP_CA_data}/gravity_mp/`method'/resid_sector9_`method'_`s'.dta", replace


*Saving the coefficients
*----------------------------------------------
matrix b = e(b)
svmat b
local last=((`num_countries'-1)*2)+6
keep b1-b`last'
keep if b1!=.
gen A=1
reshape long b, i(A) j(coef)
drop A
gen sector="`s'"
preserve 
keep if coef<=`num_countries'-1
save "${MP_CA_data}/gravity_mp/`method'/mfe_sector9_`method'_`s'.dta", replace
restore
preserve
keep if coef>=`num_countries' & coef<=(`num_countries'-1)*2
save "${MP_CA_data}/gravity_mp/`method'/xfe_sector9_`method'_`s'.dta", replace
restore
keep if coef>=((`num_countries'-1)*2)+1
save "${MP_CA_data}/gravity_mp/`method'/barriers_sector9_`method'_`s'.dta", replace
}
}
*

*----------------------------------------------------------------------------------
clear all
set more off 

local sector2 S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 S_NT
disp "`sector2'"
foreach method in poisson reg {

foreach val in resid mfe xfe barriers {
clear all
set obs 1
gen x=.	
   
foreach s of local sector2 {
append using "${MP_CA_data}/gravity_mp/`method'/`val'_sector9_`method'_`s'.dta"
erase "${MP_CA_data}/gravity_mp/`method'/`val'_sector9_`method'_`s'.dta"
compress 
}
drop if _n==1
drop x
save "${MP_CA_data}/gravity_mp/`method'/`val'_sector9_`method'.dta", replace
}
}
*
      
*---------------------------------------------------------------------------
*MP_barriers
*---------------------------------------------------------------------------
clear all
set more off 
local sector2 S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 S_NT
disp "`sector2'"

foreach method in poisson reg {
display "`method'"
clear all 
use "${MP_CA_data}/gravity_mp/`method'/barriers_sector9_`method'.dta", clear
reshape wide b, i(sector) j(coef) 

*Eaton and Kortum
gen theta_1=8.28

*Costinot 
gen theta_2=6

*Caliendo and Parro estimates (at the sectoral level)  
*----------------------------------------------------------
gen theta_3=.
replace theta_3=2.62 if sector=="S15_16"
replace theta_3=8.01 if sector=="S17_19"
replace theta_3=15.70 if sector=="S20_22"
replace theta_3=27.01 if sector=="S23_25"
replace theta_3=2.41 if sector=="S26"
replace theta_3=5.41 if sector=="S27_28"
replace theta_3=5.71 if sector=="S29_33"
replace theta_3=1.42 if sector=="S34_35"
replace theta_3=3.98 if sector=="S36_37"
replace theta_3=5 if sector=="S_NT"
*5 is the average across (in the CP NAFTA paper)


*Renaming the coefficients (ln_dist contig colony comlang_off RTA)
*-----------------------------------------------
local last=((`num_countries'-1)*2)+1
display "`num_countries'"
display "`last'"
rename b`last' beta_dist
local last=`last'+1
rename b`last' border
local last=`last'+1
rename b`last' colony
local last=`last'+1
rename b`last' language
local last=`last'+1
rename b`last' rta
local last=`last'+1
rename b`last' cte

foreach y in theta_1 theta_2 theta_3 {
foreach var in beta_dist  border colony language rta cte {
gen `var'_`y'=`var'/(-`y')
}
}
*
drop beta_dist  border colony language rta cte
drop theta_1 theta_2 theta_3
save "${MP_CA_data}/gravity_mp/`method'/barriers_sector9_`method'_theta.dta", replace



*---------------------------------------------------------------------------
*Importer and Exporter Fixed Effect
*---------------------------------------------------------------------------  
clear all
set more off 

local sector2 S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 S_NT
disp "`sector2'"

use "${MP_CA_data}/gravity_mp/`method'/xfe_sector9_`method'.dta", clear
replace coef=coef-(`num_countries'-1)
rename b xfe

merge 1:1 coef sector using "${MP_CA_data}/gravity_mp/`method'/mfe_sector9_`method'.dta", keep(3) nogen
rename b mfe
replace coef=coef+1
*twoway kdensity xfe || kdensity mfe


*Is the information available for all years?
*--------------------------------------------------------
tab mfe if mfe==0
tab xfe if xfe==0


*Adding USA (brutal force)
*-------------------------------------------------------
foreach var in S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 S_NT  {
local new = _N + 1
set obs `new' 
replace coef=1 if coef==.
replace sector="`var'" if sector==""
replace xfe=0 if xfe==. & coef==1
replace mfe=0 if mfe==. & coef==1
}
*
*---------------------------------------------------------


*--------------------------  THETA  ------------------------------*
gen theta_1=8.28
gen theta_2=6.00

*Caliendo and Parro estimates (at the sectoral level) 
gen theta_3=.
replace theta_3=2.62 if sector=="S15_16"
replace theta_3=8.01 if sector=="S17_19"
replace theta_3=15.70 if sector=="S20_22"
replace theta_3=27.01 if sector=="S23_25"
replace theta_3=2.41 if sector=="S26"
replace theta_3=5.41 if sector=="S27_28"
replace theta_3=5.71 if sector=="S29_33"
replace theta_3=1.42 if sector=="S34_35"
replace theta_3=3.98 if sector=="S36_37"
replace theta_3=5 if sector=="S_NT"
*5 is the average across (in the CP NAFTA paper)

by sector, sort: egen a=median(mfe)
replace mfe=a if mfe==.
drop a
by sector, sort: egen a=median(xfe)
replace xfe=a if xfe==.
drop a

foreach var in theta_1 theta_2 theta_3 {
gen exp_barr_`var'=-(1/`var')*(mfe+xfe)
}
*--------------------------  THETA  ------------------------------*


*Calculating S's
*---------------------------------------------------------
gen S_xfe=exp(xfe)
gen S_mfe=exp(-mfe)
order coef sector xfe mfe S_xfe S_mfe


*Merging the country codes with the coef using "gravity_trade/country_coef_codes.dta"
*--------------------------------------------------------
merge m:1 coef using "${MP_CA_data}/countrycode_match_gravity_coef.dta", keepusing(isiccodereporter) update
drop if _merge==2 
drop _merge
gen isiccodepartner=isiccodereporter
save "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_xfe_mfe.dta", replace




*----------------------------------------------------------------------------
*********************************ERROR TERM**********************************
*----------------------------------------------------------------------------
use location origin isiccodereporter isiccodepartner sector_mp ln_dist contig colony comlang_off RTA depvar1_mp using "${MP_CA_data}/mp_trade_origin_location_sectors_mp.dta", clear


*Include the error termn*
*-------------------------------------
merge 1:1 isiccodereporter isiccodepartner sector_mp using "${MP_CA_data}/gravity_mp/`method'/resid_sector9_`method'.dta"
keep if _merge==3
drop _merge


*Include the betas for the "distance" variables (with each theta respectively)
*-------------------------------------
gen sector=sector_mp
merge m:1 sector using "${MP_CA_data}/gravity_mp/`method'/barriers_sector9_`method'_theta.dta", keepusing(beta_dist_theta_1 beta_dist_theta_2 beta_dist_theta_3 border_theta_1 border_theta_2 border_theta_3 colony_theta_1 colony_theta_2 colony_theta_3 language_theta_1 language_theta_2 language_theta_3 rta_theta_1 rta_theta_2 rta_theta_3 cte_theta_1 cte_theta_2 cte_theta_3)
keep if _merge==3
drop _merge


*----------------------------------------------------------------------
*Include the exporter and importer barriers* (notice we call it always EXPORT BARRIERS)
*----------------------------------------------------------------------
merge m:1 isiccodereporter sector using "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_xfe_mfe.dta", keepusing(S_mfe S_xfe exp_barr_theta_1 exp_barr_theta_2 exp_barr_theta_3)
drop if _merge==2
drop _merge

foreach var in exp_barr_theta_1 exp_barr_theta_2 exp_barr_theta_3 S_mfe S_xfe {
display "`var'"
rename `var' `var'_reporter
}

merge m:1 isiccodepartner sector using "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_xfe_mfe.dta", keepusing(S_mfe S_xfe exp_barr_theta_1 exp_barr_theta_2 exp_barr_theta_3)
drop if _merge==2
drop _merge

foreach var in exp_barr_theta_1 exp_barr_theta_2 exp_barr_theta_3 S_mfe S_xfe {
display "`var'"
rename `var' `var'_partner
}

*----------------------------------------------------------------------
merge m:m sector using "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_xfe_mfe.dta", keepusing(theta_1 theta_2 theta_3)
drop if _merge==2
drop _merge

foreach y in reporter partner {
display "`y'"
replace exp_barr_theta_1_`y'=0 if isiccode`y'==1 & exp_barr_theta_1_`y'==.
replace exp_barr_theta_2_`y'=0 if isiccode`y'==1 & exp_barr_theta_2_`y'==.
replace exp_barr_theta_3_`y'=0 if isiccode`y'==1 & exp_barr_theta_3_`y'==.
}
*

*Calculating the dij matrix: notice that D_`method'_`s'_partner is the trade barriers calculated with exporter effect and D_`method'_`s'_reporter is the trade barrirer calculated with importer effect) 
*-------------------------------------
foreach y in theta_1 theta_2 theta_3 {
display "`y'"
gen resid_`method'_ln_`y'=resid_`method'_ln/(-`y')
gen resid_`method'_`y'=resid_`method'/(-`y')
}
*

foreach var in partner reporter {
foreach s in theta_1 theta_2 theta_3 {
display "`var'"
display "`s'"
gen D_`method'_`s'_`var'= cte_`s'+ beta_dist_`s'*ln_dist + border_`s'*contig + colony_`s'*colony+ language_`s'*comlang_off + rta_`s'*RTA + exp_barr_`s'_`var' + resid_`method'_ln_`s'
replace D_`method'_`s'_`var'=exp(D_`method'_`s'_`var')
sum D_`method'_`s'_`var', d

*-------------------------------------
replace D_`method'_`s'_`var'=0 if depvar1_mp==0
*Set a lower bound: only 0.01% of the obs are below this threshold
replace D_`method'_`s'_`var'=1.40 if D_`method'_`s'_`var'<1.40 & depvar1_mp!=0
*-------------------------------------
}
}
*
save "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_transition.dta", replace



*--------------------------------------------------
*ONLY BARRERAS to MP* 
*--------------------------------------------------
clear all
use "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_transition.dta", clear
keep origin location isiccodereporter isiccodepartner sector_mp D_`method'_theta_1_partner D_`method'_theta_2_partner D_`method'_theta_3_partner D_`method'_theta_1_reporter D_`method'_theta_2_reporter D_`method'_theta_3_reporter

clear all
use "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_transition.dta", clear
keep origin location isiccodereporter isiccodepartner sector_mp D_`method'_theta_1_partner D_`method'_theta_2_partner D_`method'_theta_3_partner D_`method'_theta_1_reporter D_`method'_theta_2_reporter D_`method'_theta_3_reporter
save "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_dmatrix.dta", replace



*Prepare to be send to MATLAB
*--------------------------------------------------
gen sector_mp2=.
replace sector_mp2=1 if sector_mp=="S15_16"
replace sector_mp2=2 if sector_mp=="S17_19"
replace sector_mp2=3 if sector_mp=="S20_22"
replace sector_mp2=4 if sector_mp=="S23_25"
replace sector_mp2=5 if sector_mp=="S26"
replace sector_mp2=6 if sector_mp=="S27_28"
replace sector_mp2=7 if sector_mp=="S29_33"
replace sector_mp2=8 if sector_mp=="S34_35"
replace sector_mp2=9 if sector_mp=="S36_37"
replace sector_mp2=10 if sector_mp=="S_NT"

sort sector_mp isiccodereporter isiccodepartner  
keep isiccodereporter isiccodepartner sector_mp2 D_`method'_theta_1_partner D_`method'_theta_2_partner D_`method'_theta_3_partner D_`method'_theta_1_reporter D_`method'_theta_2_reporter D_`method'_theta_3_reporter
foreach var in D_`method'_theta_1_partner D_`method'_theta_2_partner D_`method'_theta_3_partner D_`method'_theta_1_reporter D_`method'_theta_2_reporter D_`method'_theta_3_reporter {
display "`var'"
replace `var'=0 if `var'==.
}
order sector_mp2 isiccodereporter isiccodepartner  D_`method'_theta_1_partner D_`method'_theta_2_partner D_`method'_theta_3_partner D_`method'_theta_1_reporter D_`method'_theta_2_reporter D_`method'_theta_3_reporter
sort sector_mp isiccodereporter isiccodepartner  
outsheet sector_mp2 isiccodereporter isiccodepartner D_`method'_theta_1_partner D_`method'_theta_2_partner D_`method'_theta_3_partner D_`method'_theta_1_reporter D_`method'_theta_2_reporter D_`method'_theta_3_reporter using "${MP_CA_data}/mp_cost_sector9_`method'", comma nonames nolabel replace



*----------------------------------------------------------------------------
*Calculating the Technology Parameters (FUNDAMENTALS) (for Tradables) 
*----------------------------------------------------------------------------
clear all
use "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_transition.dta", clear
keep S_mfe_reporter S_xfe_reporter sector_mp isiccodereporter 
duplicates drop isiccodereporter sector_mp, force

rename S_mfe T_mp_rel
rename S_xfe Tx_mp_rel 

sum T_mp_rel Tx_mp_rel, d
gen isiccodepartner=isiccodereporter
save "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_1_Tmp.dta", replace


*Prepare to be send to MATLAB
*--------------------------------------------------
gen sector_mp2=.
replace sector_mp2=1 if sector_mp=="S15_16"
replace sector_mp2=2 if sector_mp=="S17_19"
replace sector_mp2=3 if sector_mp=="S20_22"
replace sector_mp2=4 if sector_mp=="S23_25"
replace sector_mp2=5 if sector_mp=="S26"
replace sector_mp2=6 if sector_mp=="S27_28"
replace sector_mp2=7 if sector_mp=="S29_33"
replace sector_mp2=8 if sector_mp=="S34_35"
replace sector_mp2=9 if sector_mp=="S36_37"
replace sector_mp2=10 if sector_mp=="S_NT"

drop isiccodepartner
order sector_mp2 isiccodereporter T_mp_rel Tx_mp_rel
sort sector_mp2 isiccodereporter  
outsheet sector_mp2 isiccodereporter T_mp_rel  using "${MP_CA_matlab}/mp_T_sector9_`method'", comma nonames nolabel replace

sort sector_mp2 isiccodereporter  
outsheet sector_mp2 isiccodereporter Tx_mp_rel using "${MP_CA_matlab}/mp_Tx_sector9_`method'", comma nonames nolabel replace
}
*


*Checking (MP)
*------------------------------- 
local method poisson
use "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_dmatrix.dta", clear
sum D_`method'_theta_2_partner if D_`method'_theta_2_partner!=0, d
table sector if D_`method'_theta_2_partner!=0, c(mean D_`method'_theta_2_partner)




*********************MP BARRIERS WITHOUT (before) ADJUSTMENT********************

*------------------------------------------------------------------------------
*ALL g's, non adjusted, including non-tradable, m and x.
*------------------------------------------------------------------------------
clear all
set more off 
foreach method in reg poisson {
display "`method'"
local num 1
local theta=6

clear
use  "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_dmatrix.dta", clear
local theta=6
fillin isiccodepartner isiccodereporter sector
drop _fillin

*Diagonal is equal 1 
*---------------------------------
foreach var in D_`method'_theta_1_partner D_`method'_theta_2_partner D_`method'_theta_3_partner D_`method'_theta_1_reporter D_`method'_theta_2_reporter D_`method'_theta_3_reporter {
replace `var'=1 if isiccodepartner==isiccodereporter
}
* 

*Missing are very costly (also zeros)
*---------------------------------
foreach var in D_`method'_theta_1_partner D_`method'_theta_2_partner D_`method'_theta_3_partner D_`method'_theta_1_reporter D_`method'_theta_2_reporter D_`method'_theta_3_reporter {
replace `var'=1000 if `var'==.
replace `var'=1000 if `var'==0
}
* 

*Extending origin and location isocodes
*---------------------------------
merge m:1 isiccodereporter using "${MP_CA_data}/countrycode_match.dta", keepusing(location) update
drop if _merge==2
drop _merge
replace location="USA" if isiccodereporter==1

merge m:1 isiccodepartner using "${MP_CA_data}/countrycode_match.dta", keepusing(origin) update
drop if _merge==2
drop _merge
replace origin="USA" if isiccodepartner==1

sort sector_mp isiccodereporter isiccodepartner
keep origin location sector_mp isiccodereporter isiccodepartner D_`method'_theta_2_reporter D_`method'_theta_2_partner

*PARTNER (FE) ask for Tm (that is why we call it g_m)  
rename D_`method'_theta_2_partner g_m
*REPORTER (FE) ask for Tx (that is why we call it g_x)
rename D_`method'_theta_2_reporter g_x

foreach var in m x {
by sector_mp, sort: sum g_`var' if g_`var'<1000 & g_`var'>1
format  %9.1fc g_`var'
replace g_`var'=g_`var'^(-`theta')
}
save "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_equation_gs_wNT.dta", replace




*Parameters g's [without adjustment] for SOURCE (PARTNER EFFECT), and therefore called it g_m
*AND Reporter g's [without adjustment] for LOCATION (REPORTER EFFECT), and therefore called it g_x
*--------------------------------------------------------------------------
foreach type in m x {
clear all
use "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_equation_gs_wNT.dta", clear

gen sector_mp2=.
replace sector_mp2=1 if sector_mp=="S15_16"
replace sector_mp2=2 if sector_mp=="S17_19"
replace sector_mp2=3 if sector_mp=="S20_22"
replace sector_mp2=4 if sector_mp=="S23_25"
replace sector_mp2=5 if sector_mp=="S26"
replace sector_mp2=6 if sector_mp=="S27_28"
replace sector_mp2=7 if sector_mp=="S29_33"
replace sector_mp2=8 if sector_mp=="S34_35"
replace sector_mp2=9 if sector_mp=="S36_37"
replace sector_mp2=10 if sector_mp=="S_NT"
*We need g (rather than g(-theta)) in Matlab.
replace g_`type'=g_`type'^(-1/`theta')
format %9.4fc g_`type'
sort sector_mp2  isiccodepartner  isiccodereporter
order sector_mp2 isiccodepartner isiccodereporter g_`type'
outsheet sector_mp2 isiccodereporter isiccodepartner g_`type' using "${MP_CA_matlab}/parameters_g_`method'_`type'_final_unadjusted", comma nonames nolabel replace
}
}
*

*************************T's WITHOUT (before) ADJUSTMENT***********************

*------------------------------------------------------------------------------
*T's without adjustment (including non_tradables)  
*------------------------------------------------------------------------------
clear all
set more off 

foreach method in poisson reg {

display "`method'"
local num 1
local theta=6

clear all
use "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_1_Tmp.dta", clear


*Bring the technology (trade) of each partner (and US) HERE I AM USING THE TSQ IN REG (SUBJECT TO CHANGE)
*----------------------------------------------------
merge m:1 sector_mp using "${MP_CA_data}/gravity_trade/reg/parameters_sector9_reg_Tusa.dta", keepusing(Tsq_usa_theta_2)
drop if _merge==2
drop _merge


*****PRODUCTIVITY NON TRADABLE****** (we need this only to be able to go from relative (to US) values, to absolutes, as we have for the rest of sectors)
replace Tsq_usa_theta_2=(3.44*(1.127))^(6) if sector_mp=="S_NT" & Tsq_usa_theta_2==.
*****PRODUCTIVITY NON TRADABLE******

rename T_mp_rel T_mp_rel_m
rename Tx_mp_rel T_mp_rel_x

replace T_mp_rel_m=1 if isiccodepartner==1
replace T_mp_rel_x=1 if isiccodepartner==1

gen T_mp_abs_m=T_mp_rel_m*Tsq_usa_theta_2
gen T_mp_abs_x=T_mp_rel_x*Tsq_usa_theta_2
save "${MP_CA_data}/gravity_mp/`method'/parameters_Tmp_final_unadjusted.dta", replace

foreach type in m x {
clear all
use "${MP_CA_data}/gravity_mp/`method'/parameters_Tmp_final_unadjusted.dta", clear

gen sector_mp2=.
replace sector_mp2=1 if sector_mp=="S15_16"
replace sector_mp2=2 if sector_mp=="S17_19"
replace sector_mp2=3 if sector_mp=="S20_22"
replace sector_mp2=4 if sector_mp=="S23_25"
replace sector_mp2=5 if sector_mp=="S26"
replace sector_mp2=6 if sector_mp=="S27_28"
replace sector_mp2=7 if sector_mp=="S29_33"
replace sector_mp2=8 if sector_mp=="S34_35"
replace sector_mp2=9 if sector_mp=="S36_37"
replace sector_mp2=10 if sector_mp=="S_NT"
sort sector_mp isiccodereporter  

sort sector_mp2 isiccodereporter 
order sector_mp2 isiccodereporter T_mp_abs_`type'  
outsheet sector_mp2 isiccodereporter T_mp_abs_`type' using "${MP_CA_matlab}/parameters_Tmp_`method'_`type'_final_unadjusted", comma nonames nolabel replace
}
}
*




*===============================================================================
*Next steps:
*----------------------------------------------
*STEP 3: With the g's and the T's calculate the Tsq mp. Then update Ts (mp) by adding 0.01 of the differece between Tsq (trade)- Tsq (mp). 
*STEP 4: Use the system of equations Tsq=g*T to calculate (Ts). 
*STEP 5: Calculate the MP gravity equation (to obtaing MP barriers, g) through Poisson without constant and restricting the coefficients to be equals (1) and (-1) (Using the Ts from step 4) 
*STEP 6: With the T's and the last set of g's calculate the Tsq and repeat 
*===============================================================================



*###############################################################################
*===============================================================================
*The loop starts here
*===============================================================================
*I have the g's and the T's from (poisson and OLS) MP.
*Then update Ts (mp) by adding 0.01 of the differece between Tsq (trade)- Tsq (mp).
*Then solve Naive for the system of equations using Ts (mp) ang g's and solve for T's. 
*Then run a constraint OLS and update g's. 
*With the T's and the g's on hand repeat this procedure again. 




*###########################################################################
*PRE ROUND (INITIALIZATION) 
*###########################################################################
clear all
set more off 


*===============================================================================
*Arrange the g's and the T's to compute for the Ts (mp)
*===============================================================================
clear all
foreach method in reg poisson  {

display "`method'"
local num 1
local theta=6

*--------------------------------------------------------------
clear all
use "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_1_Tmp.dta", clear

**********************************************************
*Hungary*
*by isiccodereporter, sort: egen a=median(T_mp_rel)
*replace T_mp_rel=a if T_mp_rel<0.15 & isiccodereporter==348 
*drop a
**********************************************************

save "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_1_Tmp2.dta", replace
*--------------------------------------------------------------


clear all
use  "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_dmatrix.dta", clear
local theta=6


*--------------------------------------------------------------
*LET'S DROP NON-TRADABLE
drop if sector_mp=="S_NT"
*--------------------------------------------------------------
fillin isiccodepartner isiccodereporter sector
drop _fillin
foreach var in D_`method'_theta_1_partner D_`method'_theta_2_partner D_`method'_theta_3_partner D_`method'_theta_1_reporter D_`method'_theta_2_reporter D_`method'_theta_3_reporter {
display "`var'"
replace `var'=1 if isiccodepartner==isiccodereporter
}
* 
foreach var in D_`method'_theta_1_partner D_`method'_theta_2_partner D_`method'_theta_3_partner D_`method'_theta_1_reporter D_`method'_theta_2_reporter D_`method'_theta_3_reporter {
display "`var'"
replace `var'=2000 if `var'==.
replace `var'=1000 if `var'==0
}
* 
by isiccodepartner, sort: egen a=mode(origin)
replace origin=a if origin==""
drop a
by isiccodereporter, sort: egen a=mode(location)
replace location=a if location==""
drop a

sort sector_mp isiccodereporter isiccodepartner
keep origin location sector_mp isiccodereporter isiccodepartner D_`method'_theta_2_reporter D_`method'_theta_2_partner
*NOTE: D_partner goes with Tm, and D_reporter goes with Tx
rename D_`method'_theta_2_partner g_m
rename D_`method'_theta_2_reporter g_x

foreach var in m x {
display "`var'"
replace g_`var'=g_`var'^(-`theta')
format %9.2fc g_`var' 
}
save "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_equation_gs.dta", replace


*Bring the technology of US 
*----------------------------------------------------
merge m:1 sector_mp using "${MP_CA_data}/gravity_trade/`method'/parameters_sector9_`method'_Tusa.dta", keepusing(Tsq_usa_theta_2)
keep if _merge==3
drop _merge


*----------------------------------------------------
*Bring MP technology of each partner ("...\_Tmp2.dta") 
*----------------------------------------------------
sort sector_mp isiccodereporter isiccodepartner
merge m:1 isiccodepartner sector_mp using "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_1_Tmp2.dta"
drop _merge 


*Calculate Tsq from Tmp technology of each partner IN ORDER TO CALCULATE SQ (NOTE: for this one needs first tocalculate the absolute (_abs) technology and also assume that the Tsq_usa==T_usa. Recall that from the regression all productivity paramaters were estimated relative to the U.S.)
*----------------------------------------------------
gen T_mp_abs=T_mp_rel*Tsq_usa_theta_2
gen a=g_m*T_mp_abs
by isiccodereporter sector_mp, sort: egen Tmp_sq=total(a)
drop a

gen Tx_mp_abs=Tx_mp_rel*Tsq_usa_theta_2
gen a=g_x*Tx_mp_abs
by isiccodereporter sector_mp, sort: egen Txmp_sq=total(a)
drop a

sort sector_mp isiccodereporter isiccodepartner
sum Tmp_sq Txmp_sq, d
drop Tx_mp_rel T_mp_rel T_mp_abs Tx_mp_abs


*----------------------------------------------------
*Bring MP technology of each reporter ("...\_Tmp2.dta") 
*------------------------------------------------------
merge m:1 isiccodereporter sector_mp using "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_1_Tmp2.dta"
keep if _merge==3
drop _merge 

gen T_mp_abs=T_mp_rel*Tsq_usa_theta_2
gen Tx_mp_abs=Tx_mp_rel*Tsq_usa_theta_2
*drop Tx_mp_rel T_mp_rel



*------------------------------------------------------
*Bring the technology of TRADE (OLS) (and also transform it to absolute values) (TO EACH REPORTER) 
*------------------------------------------------------
*merge m:1 isiccodereporter sector_mp using "${MP_CA_data}/gravity_trade/reg/parameters_sector9_reg_1_Tsq.dta", keepusing(T_rel_theta_2 Tx_rel_theta_2)
merge m:1 isiccodereporter sector_mp using "${MP_CA_data}/gravity_trade/reg/parameters_sector9_reg_1_Tsq_nocapital.dta", keepusing(T_rel_theta_2 Tx_rel_theta_2)
rename T_rel_theta_2  T_trade_reg_nc
rename Tx_rel_theta_2 Tx_trade_reg_nc
drop if _merge==2
drop _merge 

*Compute the absolute change in technology 
replace T_trade_reg_nc=T_trade_reg_nc*Tsq_usa_theta_2
replace Tx_trade_reg_nc=Tx_trade_reg_nc*Tsq_usa_theta_2


*---------------------------------
*Bring the technology of TRADE (POISSON) (and also transform it to absolute values) (TO EACH REPORTER) 
*---------------------------------
merge m:1 isiccodereporter sector_mp using "${MP_CA_data}/gravity_trade/poisson/parameters_sector9_poisson_1_Tsq_nocapital.dta", keepusing(T_rel_theta_2 Tx_rel_theta_2)
rename T_rel_theta_2  T_trade_poisson_nc
rename Tx_rel_theta_2 Tx_trade_poisson_nc
drop if _merge==2
drop _merge 

*Compute the absolute change in technology 
replace T_trade_poisson_nc=T_trade_poisson_nc*Tsq_usa_theta_2
replace Tx_trade_poisson_nc=Tx_trade_poisson_nc*Tsq_usa_theta_2


*Now we just need to keep the reporter side (since we have already calculated the Tsq)
*--------------------------------------
drop if sector_mp=="S_NT"
by sector_mp isiccodereporter, sort: gen a=_n==1
keep if a==1
drop a
tab sector_mp
drop isiccodepartner
keep sector_mp isiccodereporter Tsq_usa_theta_2 Tmp_sq Txmp_sq T_mp_abs Tx_mp_abs T_trade_reg_nc  Tx_trade_reg_nc  T_trade_poisson_nc Tx_trade_poisson_nc  Tx_mp_rel T_mp_rel
rename T_trade_reg_nc T_trade_reg
rename Tx_trade_reg_nc Tx_trade_reg
rename T_trade_poisson_nc T_trade_poisson
rename Tx_trade_poisson_nc Tx_trade_poisson

rename Tmp_sq Tmp_sq_m
rename Txmp_sq Tmp_sq_x


*---------------------------------
*Let's calculate the GAP in levels (FROM HERE YOU DECIDE IT WILL ALWAYS BE TRADE [using importer FE in the T construction (or an extra cost to the exporter on the trade cost) AND OLS (as estimation method)]
*---------------------------------
gen gap=T_trade_reg-Tmp_sq_m
local adjfactor=0.01

gen sign_gap=1
replace sign_gap=-1 if gap<0

gen gap2=gap*`adjfactor'
gen gap3=Tmp_sq_m*`adjfactor'*sign_gap

gen a1=abs(gap2)
gen a2=abs(gap3)
egen gap_min=rowmin(a1 a2)
replace gap_min=gap_min*sign_gap
drop a1 a2 
drop gap2 gap3
gen ratio=abs(gap)/Tmp_sq_m



*UPDATE: (Notice to not update when the gap is too small relative to the size of the productivity parameter) 
*------------------------------------------
gen new_Tsq=.
replace new_Tsq=Tmp_sq_m if ratio<0.05
replace new_Tsq=Tmp_sq_m+gap_min if new_Tsq==.  
drop ratio sign_gap  


*Rename some variables 
*---------------------------------
rename T_mp_abs T_mp_abs_m
rename Tx_mp_abs T_mp_abs_x

rename T_trade_reg T_trade_reg_m
rename Tx_trade_reg T_trade_reg_x
rename T_trade_poisson T_trade_poisson_m
rename Tx_trade_poisson T_trade_poisson_x

save "${MP_CA_data}/gravity_mp/`method'/parameters_interim_Tmp_nc.dta", replace

}
*





*###########################################################################
*CREATING THE MASTER FILE (before the loop starts)
*###########################################################################
clear all
set more off 

*Note: from here things can be done for each type (M or X, both adjusted) Only after, the non-tradables will be attached
foreach method in reg poisson {
foreach type in m {

local num 1
local theta=6

display "`method'" 
display "`type'"
display "`num'"
display "`theta'"


*---------------------------------------------------------
*PROCEDURE: (Step 4) use the updated [Tsq_mp (updated)] and use the system of equations Tsq=g*T to calculate (Ts). 
*---------------------------------------------------------


*---------------------------------------------------------
*Reshape (to prepare the system of equation) 
*---------------------------------------------------------
clear all
use g_`type' sector_mp isiccodereporter isiccodepartner using "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_equation_gs.dta", clear
gen a="_"
egen ind=concat(sector_mp a isiccodereporter)

keep g_`type' sector_mp ind isiccodepartner
rename g_`type' g 
reshape wide g, i(ind) j(isiccodepartner) 
split ind , p(_)
rename ind3 isiccodereporter
replace isiccodereporter=ind2 if isiccodereporter==""
drop ind1 ind2
drop ind

destring isiccodereporter, replace
order sector_mp isiccodereporter
sort sector_mp isiccodereporter

merge 1:1 isiccodereporter sector_mp using "${MP_CA_data}/gravity_mp/`method'/parameters_interim_Tmp_nc.dta", keepusing(Tmp_sq_`type' T_trade_reg_m T_mp_abs_`type' gap gap_min new_Tsq)
drop _merge
sort sector_mp isiccodereporter
format %9.2fc new_Tsq
compress
save "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_equation_gs2_`type'_nc.dta", replace
sum Tmp_sq_`type' T_mp_abs_`type' T_trade_reg_m new_Tsq



*-----------------------------------------------------------------
*Now, Calculate the regression and save the betas (notice that is very simple 
*Then I will use it to run the bilateral MP regression again. 
*-----------------------------------------------------------------
local sector2 S15_16 S17_19 S20_22 S23_25 S26 S27_28 S29_33 S34_35 S36_37 
disp "`sector2'"
local num_countries=32

foreach s of local sector2 {
clear all
use "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_equation_gs2_`type'_nc.dta", clear
display "`s'"
reg new_Tsq g1-g826 if sector_mp=="`s'", noconstant 


*Saving the coefficients
*----------------------------------------------
matrix b = e(b)
svmat b
local last=`num_countries'
keep b1-b`last'
keep if b1!=.
gen A=1
reshape long b, i(A) j(coef)
drop A
gen sector_mp="`s'"
save "${MP_CA_data}/gravity_mp/`method'/parameters_gT_`s'_nc.dta", replace
}
*

*Append across sectors 
*-------------------------------------------------------
clear all
set obs 1
foreach s of local sector2 {
append using "${MP_CA_data}/gravity_mp/`method'/parameters_gT_`s'_nc.dta"
}
drop if coef==.
rename b T_mp_ori


*Merging the country codes with the coef using "gravity_trade/country_coef_codes.dta"
*--------------------------------------------------------
merge m:1 coef using "${MP_CA_data}/countrycode_match_gravity_coef.dta", keepusing(isiccodereporter) update
drop if _merge==2 
drop _merge

*Calling the file with T's
merge 1:1 sector_mp isiccodereporter using  "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_equation_gs2_`type'_nc.dta", keepusing(Tmp_sq_`type' T_mp_abs_`type' gap gap_min T_trade_reg_m new_Tsq)
keep if _merge==3
drop _merge
rename T_mp_ori T_beta
rename T_mp_abs_`type' T_mp_abs
*We have always use the Tm (for trade, where we used partner FE)
rename T_trade_reg_m T_trade_reg
rename Tmp_sq_`type' Tmp_sq
gen isiccodepartner=isiccodereporter
save "${MP_CA_data}/gravity_mp/`method'/parameters_gT_interim_`type'_nc.dta", replace




*-------------------------------------------------------
*Creating the master file (T's)
*-------------------------------------------------------
local num 1
clear all
use sector_mp isiccodereporter isiccodepartner Tmp_sq T_mp_abs gap gap_min T_trade_reg new_Tsq T_beta using  "${MP_CA_data}/gravity_mp/`method'/parameters_gT_interim_`type'_nc.dta"

foreach var in Tmp_sq T_mp_abs gap gap_min T_trade_reg new_Tsq T_beta {
display "`var'"
rename `var' `var'_`num'
}
save "${MP_CA_data}/gravity_mp/`method'/parameters_gT_master_`type'_nc.dta", replace



*-------------------------------------------------------
*Creating the master file (MP barriers)
*-------------------------------------------------------
local num 1
clear all
use origin location sector_mp isiccodereporter isiccodepartner g_`type' using "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_equation_gs.dta", clear
rename g_`type' g_`num'
compress
save "${MP_CA_data}/gravity_mp/`method'/parameters_gs_master_`type'_nc.dta", replace
}
}
*



*-------------------------------------------------------------------------
*LOOP over step 3-6
*-------------------------------------------------------------------------
*Notice: for the final results on MP we are working with THE FINAL TAKE: poisson / m 
set mat 11000
clear all
set more off 
local theta=6
local method poisson
local type m

display "`theta'"
display "`method'"
display "`type'"
local iterend=1000
local factor nc 

forvalues num =1(1)`iterend' {

display "`num'"
local num=`num'+1
display "`num'"
display "`method'"
display "`type'"

*Go to a loop that uses the last T's and compute the constrained poisson regression and save the g's and prepare for 
*-------------------------------------------------------------------------
include "${MP_CA_do}/gravity mp/`method'/module_g_iteration_`type'.do" 
}
*
*Evaluations of the T's 
*--------------------------------------------------------------------------------
clear all
use "${MP_CA_data}/gravity_mp/`method'/parameters_gT_master_`type'_`factor'.dta", clear


*Evaluations of the g's 
*---------------------------------------
clear all
use "${MP_CA_data}/gravity_mp/`method'/parameters_gs_master_`type'_`factor'.dta", clear
twoway  kdensity g_1 if g_1<10 || kdensity g_999 if g_999<10 
sum g_999




********************************************************************************
*MATLAB 
********************************************************************************


*------------------------------------------------------------------------------
*Final set of T's (m)
*------------------------------------------------------------------------------
foreach method in poisson  {
clear all
local type m
use "${MP_CA_data}/gravity_mp/`method'/parameters_gT_master_`type'_`factor'.dta", clear
format %9.2fc T* gap*


*Choosing the iteration that will take the place of final technology 
*-----------------------------------------------------------
gen T_mp_abs=T_beta_1001
gen T_mp_sq_abs=Tmp_sq_1001


*Now bring the unadjusted (the first one)  
*-----------------------------------------------------------
merge 1:1 isiccodereporter sector_mp using "${MP_CA_data}/gravity_mp/`method'/parameters_Tmp_final_unadjusted.dta", keepusing(T_mp_abs_`type')
drop if _merge==2
drop _merge

replace T_mp_abs=T_mp_abs_`type' if sector_mp=="S_NT"
drop if T_mp_abs==.
format %9.1fc T_mp_abs T_mp_sq_abs
sort sector_mp isiccodereporter  

gen sector_mp2=.
replace sector_mp2=1 if sector_mp=="S15_16"
replace sector_mp2=2 if sector_mp=="S17_19"
replace sector_mp2=3 if sector_mp=="S20_22"
replace sector_mp2=4 if sector_mp=="S23_25"
replace sector_mp2=5 if sector_mp=="S26"
replace sector_mp2=6 if sector_mp=="S27_28"
replace sector_mp2=7 if sector_mp=="S29_33"
replace sector_mp2=8 if sector_mp=="S34_35"
replace sector_mp2=9 if sector_mp=="S36_37"
replace sector_mp2=10 if sector_mp=="S_NT"

keep sector_mp2  sector_mp isiccodereporter T_mp_abs T_mp_sq_abs
sort sector_mp2 isiccodereporter 
order sector_mp2 isiccodereporter T_mp_abs 
save "${MP_CA_data}/gravity_mp/`method'/parameters_gT_master_`type'_`factor'_final.dta", replace
outsheet sector_mp2 isiccodereporter T_mp_abs using "${MP_CA_matlab}/parameters_Tmp_`type'_`method'_final_adjusted_`factor'", comma nonames nolabel replace
}
*

*======================================================================
*Relative Productivity, by Country and Industry
*======================================================================
local method poisson 
local type m
local factor nc
local theta=6
use "${MP_CA_data}/gravity_mp/`method'/parameters_gT_master_`type'_`factor'_final.dta", clear
merge m:1 isiccodereporter using "${MP_CA_data}/countrycode_match_gravity_coef.dta", keepusing(location)
drop if _merge==2
drop _merge

gen Tus=T_mp_abs if isiccodereporter==1
by sector_mp, sort: egen T_US=max(Tus) 
drop Tus
gen T=(T_mp_abs/T_US)^(1/`theta')
keep sector_mp location isiccodereporter T 
reshape wide T, i(location isiccodereporter) j(sector_mp) string 

rename TS15_16 Food
rename TS17_19 Textile
rename TS20_22 Wood_Paper
rename TS23_25 Chemicals
rename TS26 Minerals
rename TS27_28 Metals
rename TS29_33 Machinery
rename TS34_35 Transport
rename TS36_37 Other_Manuf_nec
rename TS_NT Non_Tradables
sort isiccodereporter
format %9.3fc Food Textile Wood_Paper Chemicals Minerals Metals Machinery Transport Other_Manuf_nec Non_Tradables
save "${MP_CA_main}/tables/Estimated Ts_by Country_Industry_`method'_`type'_`factor'.dta", replace





*------------------------------------------------------------------------------
*Final set of d's (FOR TRADE)
*------------------------------------------------------------------------------
local method reg
clear all
use "${MP_CA_data}/gravity_trade/`method'/parameters_sector9_`method'_dmatrix.dta", clear 

keep location origin isiccodereporter isiccodepartner sector_mp D_`method'_theta_2_partner
rename D_`method'_theta_2_partner d
fillin isiccodepartner isiccodereporter sector
drop _fillin
foreach var in d {
display "`var'"
replace `var'=1 if isiccodepartner==isiccodereporter
}
foreach var in d {
replace `var'=1000 if `var'==.
replace `var'=1000 if `var'==0
}
* 
by isiccodepartner, sort: egen a=mode(origin)
replace origin=a if origin==""
drop a
by isiccodereporter, sort: egen a=mode(location)
replace location=a if location==""
drop a

sort sector_mp isiccodereporter isiccodepartner
keep origin location sector_mp isiccodereporter isiccodepartner d

gen sector_mp2=.
replace sector_mp2=1 if sector_mp=="S15_16"
replace sector_mp2=2 if sector_mp=="S17_19"
replace sector_mp2=3 if sector_mp=="S20_22"
replace sector_mp2=4 if sector_mp=="S23_25"
replace sector_mp2=5 if sector_mp=="S26"
replace sector_mp2=6 if sector_mp=="S27_28"
replace sector_mp2=7 if sector_mp=="S29_33"
replace sector_mp2=8 if sector_mp=="S34_35"
replace sector_mp2=9 if sector_mp=="S36_37"
replace sector_mp2=10 if sector_mp=="S_NT"
sort sector_mp2  isiccodepartner  isiccodereporter
order sector_mp2 isiccodepartner isiccodereporter  d  

save "${MP_CA_data}/gravity_trade/`method'/parameters_sector9_`method'_dmatrix_matlab_`factor'.dta", replace 
outsheet sector_mp2 isiccodepartner isiccodereporter  d using "${MP_CA_matlab}/parameters_d_final_`factor'", comma nonames nolabel replace





*------------------------------------------------------------------------------
*Final set of g's (FOR MP)
*------------------------------------------------------------------------------
foreach type in m {

local method poisson
local theta=6
display "`type'"
clear all
use "${MP_CA_data}/gravity_mp/`method'/parameters_gs_master_`type'_`factor'.dta", clear

forvalues i=1(1)1001 {
display "`i'"
replace g_`i'=g_`i'^(-1/`theta')
}
merge 1:1 sector_mp isiccodereporter isiccodepartner using "${MP_CA_data}/gravity_mp/`method'/parameters_sector9_`method'_equation_gs_wNT.dta", keepusing(g_`type')
tab sector_mp if _merge!=3
drop _merge


*Choosing the iteration that will take the place of final MP barriers
*-----------------------------------------------------------
gen g_final=g_1001
replace g_`type'=g_`type'^(-1/`theta')

*Getting Non-Tradable
replace g_final=g_`type' if sector_mp=="S_NT"  

gen sector_mp2=.
replace sector_mp2=1 if sector_mp=="S15_16"
replace sector_mp2=2 if sector_mp=="S17_19"
replace sector_mp2=3 if sector_mp=="S20_22"
replace sector_mp2=4 if sector_mp=="S23_25"
replace sector_mp2=5 if sector_mp=="S26"
replace sector_mp2=6 if sector_mp=="S27_28"
replace sector_mp2=7 if sector_mp=="S29_33"
replace sector_mp2=8 if sector_mp=="S34_35"
replace sector_mp2=9 if sector_mp=="S36_37"
replace sector_mp2=10 if sector_mp=="S_NT"

sort sector_mp2 isiccodepartner isiccodereporter
order sector_mp2 isiccodepartner isiccodereporter g_final 
save "${MP_CA_data}/gravity_mp/`method'/parameters_gs_master_`type'_`factor'_final.dta", replace
outsheet sector_mp2 isiccodereporter isiccodepartner g_final using "${MP_CA_matlab}/parameters_g_`method'_`type'_`factor'_final_adjusted", comma nonames nolabel replace

}
*




